@@ -13,12 +13,11 @@
 
 void basetimeInit(BaseTime *basetime)
 {
-  static const char *func = "basetimeInit";
-
   if ( basetime == NULL )
-    Error(func, "Internal problem! Basetime not allocated.");
+    Error("Internal problem! Basetime not allocated.");
 
-  (*basetime).ncvarid = UNDEFID;
-  (*basetime).ncdimid = UNDEFID;
+  (*basetime).ncvarid       = UNDEFID;
+  (*basetime).ncdimid       = UNDEFID;
   (*basetime).ncvarboundsid = UNDEFID;
+  (*basetime).lwrf          = 0;
 }
