@@ -31,7 +31,6 @@ typedef struct {
 static
 int cgribexGetGridType(int *isec2)
 {
-  /*  static const char *func = "cgribexGetGridType"; */
   int gridtype = 0;
 
   switch (ISEC2_GridType)
@@ -78,7 +77,6 @@ int cgribexGetGridType(int *isec2)
 static
 int cgribexGetIsRotated(int *isec2)
 {
-  /*  static const char *func = "cgribexGetIsRotated"; */
   int isRotated = 0;
 
   if ( ISEC2_GridType == 10 )
@@ -180,7 +178,6 @@ int cgribexGetZaxisHasBounds(int grb_ltype)
 static
 int cgribexGetTimeUnit(int *isec1)
 {
-  static const char *func = "cgribexGetTimeUnit";
   int timeunit = -1;
   static int lprint = TRUE;
 
@@ -196,7 +193,7 @@ int cgribexGetTimeUnit(int *isec1)
     default:
       if ( lprint )
 	{
-	  Message(func, "Time unit %d unsupported", ISEC1_TimeUnit);
+	  Message("Time unit %d unsupported", ISEC1_TimeUnit);
 	  lprint = FALSE;
 	}
     }
@@ -218,7 +215,6 @@ int cgribexTimeIsFC(int *isec1)
 static
 int cgribexGetTsteptype(int timerange)
 {
-  static const char *func = "cgribexGetTsteptype";
   int tsteptype = 0;
   static int lprint = TRUE;
 
@@ -234,7 +230,7 @@ int cgribexGetTsteptype(int timerange)
     default:
       if ( lprint )
 	{
-	  Message(func, "Time range %d unsupported", timerange);
+	  Message("Time range %d unsupported", timerange);
 	  lprint = FALSE;
 	}
     }
@@ -247,7 +243,6 @@ static
 void cgribexAddRecord(int streamID, int param, int *isec1, int *isec2, double *fsec2, double *fsec3,
 		      int *isec4, long recsize, off_t position, int prec, int ztype, int lmv)
 {
-  static const char *func = "cgribexAddRecord";
   int gridtype;
   int zaxistype;
   int gridID = CDI_UNDEFID, varID;
@@ -300,7 +295,7 @@ void cgribexAddRecord(int streamID, int param, int *isec1, int *isec2, double *f
     case GRID_GAUSSIAN:
       {
 	if ( ISEC4_NumValues != ISEC2_NumLon*ISEC2_NumLat )
-	  Error(func, "numberOfPoints (%d) and gridSize (%d) differ!",
+	  Error("numberOfPoints (%d) and gridSize (%d) differ!",
 		ISEC4_NumValues, ISEC2_NumLon*ISEC2_NumLat);
 	grid.size  = ISEC4_NumValues;
 	grid.xsize = ISEC2_NumLon;
@@ -312,6 +307,9 @@ void cgribexAddRecord(int streamID, int param, int *isec1, int *isec2, double *f
 	  {
 	    if ( grid.xsize > 1 )
 	      {
+		if ( ISEC2_ResFlag && ISEC2_LonIncr > 0 )
+		  if ( ISEC2_LonIncr*(grid.xsize-1) > 360000 ) ISEC2_LonIncr = 0;
+
 		if ( ISEC2_ResFlag && ISEC2_LonIncr > 0 )
 		  grid.xinc = ISEC2_LonIncr * 0.001;
 		else
@@ -325,7 +323,7 @@ void cgribexAddRecord(int streamID, int param, int *isec1, int *isec2, double *f
 		    if ( fabs(grid.xinc-xinc) > 0.0 )
 		      {
 			grid.xinc = xinc;
-			if ( CDI_Debug ) Message(func, "set xinc to %g", grid.xinc);
+			if ( CDI_Debug ) Message("set xinc to %g", grid.xinc);
 		      }
 		  }
 	      }
@@ -338,6 +336,9 @@ void cgribexAddRecord(int streamID, int param, int *isec1, int *isec2, double *f
 	  {
 	    if ( grid.ysize > 1 )
 	      {
+		if ( ISEC2_ResFlag && ISEC2_LatIncr > 0 )
+		  if ( ISEC2_LatIncr*(grid.ysize-1) > 180000 ) ISEC2_LatIncr = 0;
+
 		if ( ISEC2_ResFlag && ISEC2_LatIncr > 0 )
 		  grid.yinc = ISEC2_LatIncr * 0.001;
 		else
@@ -389,7 +390,7 @@ void cgribexAddRecord(int streamID, int param, int *isec1, int *isec2, double *f
     case GRID_LCC:
       {
 	if ( ISEC4_NumValues != ISEC2_NumLon*ISEC2_NumLat )
-	  Error(func, "numberOfPoints (%d) and gridSize (%d) differ!",
+	  Error("numberOfPoints (%d) and gridSize (%d) differ!",
 		ISEC4_NumValues, ISEC2_NumLon*ISEC2_NumLat);
 
 	grid.size  = ISEC4_NumValues;
@@ -440,7 +441,7 @@ void cgribexAddRecord(int streamID, int param, int *isec1, int *isec2, double *f
       }
     default:
       {
-	Error(func, "Unsupported grid type: %s", gridNamePtr(gridtype));
+	Error("Unsupported grid type: %s", gridNamePtr(gridtype));
 	break;
       }
     }
@@ -520,7 +521,7 @@ void cgribexAddRecord(int streamID, int param, int *isec1, int *isec2, double *f
   streamptr->nrecs++;
 
   if ( CDI_Debug )
-    Message(func, "varID = %d  param = %d  zaxistype = %d  gridID = %d  levelID = %d",
+    Message("varID = %d  param = %d  zaxistype = %d  gridID = %d  levelID = %d",
 	    varID, param, zaxistype, gridID, levelID);
 }
 
@@ -572,9 +573,8 @@ void cgribexDecodeHeader(int *isec0, int *isec1, int *isec2, double *fsec2,
 }
 
 
-void cgribexScanTimestep1(int streamID)
+int cgribexScanTimestep1(int streamID)
 {
-  static const char *func = "cgribexScanTimestep1";
   int *isec0, *isec1, *isec2, *isec3, *isec4;
   double fsec2[512], fsec3[2], *fsec4 = NULL;
   int lmv = 0;
@@ -602,10 +602,12 @@ void cgribexScanTimestep1(int streamID)
   long unzipsize;
   compvar_t compVar, compVar0;
   stream_t *streamptr;
+  extern int cdiSkipRecords;
+  int nskip = cdiSkipRecords;
 
   streamptr = stream_to_pointer(streamID);
 
-  stream_check_ptr(func, streamptr);
+  stream_check_ptr(__func__, streamptr);
 
   streamptr->curTsID = 0;
 
@@ -619,10 +621,20 @@ void cgribexScanTimestep1(int streamID)
   taxis = &streamptr->tsteps[tsID].taxis;
 
   if ( tsID != 0 )
-    Error(func, "Internal problem! tstepsNewEntry returns %d", tsID);
+    Error("Internal problem! tstepsNewEntry returns %d", tsID);
 
   fileID = streamInqFileID(streamID);
 
+  while ( nskip-- > 0 )
+    {
+      recsize = gribGetSize(fileID);
+      if ( recsize == 0 )
+	Error("Skipping of %d records failed!", cdiSkipRecords);
+
+      recpos  = fileGetPos(fileID);
+      fileSetPos(fileID, recsize, SEEK_CUR);
+    }
+
   nrecs = 0;
   while ( TRUE )
     {
@@ -631,6 +643,9 @@ void cgribexScanTimestep1(int streamID)
 
       if ( recsize == 0 )
 	{
+	  if ( nrecs == 0 )
+	    Error("No GRIB records found!");
+
 	  streamptr->ntsteps = 1;
 	  break;
 	}
@@ -707,7 +722,7 @@ void cgribexScanTimestep1(int streamID)
 		  {
 		    char paramstr[32];
 		    cdiParamToString(param, paramstr, sizeof(paramstr));
-		    Warning(func, "Inconsistent verification time (param=%s level=%d)", paramstr, level1);
+		    Warning("Inconsistent verification time (param=%s level=%d)", paramstr, level1);
 		    warn_time = FALSE;
 		  }
 	    }
@@ -719,7 +734,7 @@ void cgribexScanTimestep1(int streamID)
 		{
 		  char paramstr[32];
 		  cdiParamToString(param, paramstr, sizeof(paramstr));
-		  Warning(func, "Param=%s level=%d already exist, skipped!", paramstr, level1);
+		  Warning("Param=%s level=%d already exist, skipped!", paramstr, level1);
 		  continue;
 		}
 	    }
@@ -729,7 +744,7 @@ void cgribexScanTimestep1(int streamID)
 	{
 	  if (  taxis->numavg && warn_numavg && (taxis->numavg != ISEC1_AvgNum) )
 	    {
-	      Message(func, "Change numavg from %d to %d not allowed!",
+	      Warning("Changing numavg from %d to %d not supported!",
 		      taxis->numavg, ISEC1_AvgNum);
 	      warn_numavg = FALSE;
 	    }
@@ -742,7 +757,7 @@ void cgribexScanTimestep1(int streamID)
       nrecs++;
 
       if ( CDI_Debug )
-	Message(func, "%4d %8d %4d  %8d %8d %6d", nrecs, (int)recpos, param, level1, vdate, vtime);
+	Message("%4d %8d %4d  %8d %8d %6d", nrecs, (int)recpos, param, level1, vdate, vtime);
 
       cgribexAddRecord(streamID, param, isec1, isec2, fsec2, fsec3,
 		       isec4, recsize, recpos, prec, ztype, lmv);
@@ -750,6 +765,8 @@ void cgribexScanTimestep1(int streamID)
 
   streamptr->rtsteps = 1;
 
+  if ( nrecs == 0 ) return (CDI_EUFSTRUCT);
+
   cdiGenVars(streamID);
 
   if ( fcast )
@@ -793,7 +810,7 @@ void cgribexScanTimestep1(int streamID)
     {
       tsID = tstepsNewEntry(streamID);
       if ( tsID != streamptr->rtsteps )
-	Error(func, "Internal error. tsID = %d", tsID);
+	Error("Internal error. tsID = %d", tsID);
 
       streamptr->tsteps[tsID-1].next   = TRUE;
       streamptr->tsteps[tsID].position = recpos;
@@ -810,12 +827,13 @@ void cgribexScanTimestep1(int streamID)
 	    }
 	}
     }
+
+  return (0);
 }
 
 
 int cgribexScanTimestep2(int streamID)
 {
-  static const char *func = "cgribexScanTimestep2";
   int *isec0, *isec1, *isec2, *isec3, *isec4;
   double fsec2[512], fsec3[2], *fsec4 = NULL;
   int lmv = 0;
@@ -843,7 +861,7 @@ int cgribexScanTimestep2(int streamID)
 
   streamptr = stream_to_pointer(streamID);
 
-  stream_check_ptr(func, streamptr);
+  stream_check_ptr(__func__, streamptr);
 
   streamptr->curTsID = 1;
 
@@ -862,7 +880,7 @@ int cgribexScanTimestep2(int streamID)
                                           
   tsID = streamptr->rtsteps;
   if ( tsID != 1 )
-    Error(func, "Internal problem! unexpeceted timestep %d", tsID+1);
+    Error("Internal problem! unexpeceted timestep %d", tsID+1);
 
   taxis = &streamptr->tsteps[tsID].taxis;
 
@@ -956,7 +974,7 @@ int cgribexScanTimestep2(int streamID)
 		(taxis->numavg != ISEC1_AvgNum) )
 	    {
 	  /*
-	      Message(func, "change numavg from %d to %d not allowed!",
+	      Warning("Changing numavg from %d to %d not supported!",
 		      taxis->numavg, ISEC1_AvgNum);
 	  */
 	      warn_numavg = FALSE;
@@ -987,7 +1005,7 @@ int cgribexScanTimestep2(int streamID)
 	{
 	  char paramstr[32];
 	  cdiParamToString(param, paramstr, sizeof(paramstr));
-	  Warning(func, "Param=%s level=%d not defined at timestep 1!", paramstr, level1);
+	  Warning("Param=%s level=%d not defined at timestep 1!", paramstr, level1);
 	  return (CDI_EUFSTRUCT);
 	}
 
@@ -1012,7 +1030,7 @@ int cgribexScanTimestep2(int streamID)
 
 	      if ( memcmp(&datetime, &datetime0, sizeof(DateTime)) != 0 ) break;
 
-	      Warning(func, "Param=%s level=%d already exist, skipped!", paramstr, level1);
+	      Warning("Param=%s level=%d already exist, skipped!", paramstr, level1);
 	      continue;
 	    }
 	  else
@@ -1023,7 +1041,7 @@ int cgribexScanTimestep2(int streamID)
 	}
 
       if ( CDI_Debug )
-	Message(func, "%4d %8d %4d %8d %8d %6d", rindex+1, (int)recpos, param, level1, vdate, vtime);
+	Message("%4d %8d %4d %8d %8d %6d", rindex+1, (int)recpos, param, level1, vdate, vtime);
 
       streamptr->tsteps[tsID].records[recID].size = recsize;
 
@@ -1034,7 +1052,7 @@ int cgribexScanTimestep2(int streamID)
 
       if ( memcmp(&compVar0, &compVar, sizeof(compvar_t)) != 0 )
 	{
-	  Message(func, "tsID = %d recID = %d param = %3d new %3d  level = %3d new %3d",
+	  Message("tsID = %d recID = %d param = %3d new %3d  level = %3d new %3d",
 		  tsID, recID,
 		  streamptr->tsteps[tsID].records[recID].param, param,
 		  streamptr->tsteps[tsID].records[recID].ilevel, level1);
@@ -1078,7 +1096,7 @@ int cgribexScanTimestep2(int streamID)
     {
       tsID = tstepsNewEntry(streamID);
       if ( tsID != streamptr->rtsteps )
-	Error(func, "Internal error. tsID = %d", tsID);
+	Error("Internal error. tsID = %d", tsID);
 
       streamptr->tsteps[tsID-1].next   = TRUE;
       streamptr->tsteps[tsID].position = recpos;
@@ -1093,7 +1111,6 @@ int cgribexScanTimestep2(int streamID)
 
 int cgribexScanTimestep(int streamID)
 {
-  static const char *func = "cgribexScanTimestep";
   int *isec0, *isec1, *isec2, *isec3, *isec4;
   double fsec2[512], fsec3[2], *fsec4 = NULL;
   int lmv = 0;
@@ -1120,16 +1137,16 @@ int cgribexScanTimestep(int streamID)
 
   streamptr = stream_to_pointer(streamID);
 
-  stream_check_ptr(func, streamptr);
+  stream_check_ptr(__func__, streamptr);
 
   vlistID = streamInqVlist(streamID);
 
   if ( CDI_Debug )
     {
-      Message(func, "streamID = %d", streamID);
-      Message(func, "cts = %d", streamptr->curTsID);
-      Message(func, "rts = %d", streamptr->rtsteps);
-      Message(func, "nts = %d", streamptr->ntsteps);
+      Message("streamID = %d", streamID);
+      Message("cts = %d", streamptr->curTsID);
+      Message("rts = %d", streamptr->rtsteps);
+      Message("nts = %d", streamptr->ntsteps);
     }
 
   isec0 = streamptr->record->sec0;
@@ -1181,7 +1198,7 @@ int cgribexScanTimestep(int streamID)
 	  status = gribRead(fileID, gribbuffer, &readsize);
 	  if ( status )
 	    {
-	      Error(func, "Inconsistent timestep %d (GRIB record %d/%d)!\n", tsID+1, rindex+1,
+	      Error("Inconsistent timestep %d (GRIB record %d/%d)!\n", tsID+1, rindex+1,
 		    streamptr->tsteps[tsID].recordSize);
 	      break;
 	    }
@@ -1236,7 +1253,7 @@ int cgribexScanTimestep(int streamID)
 		   (taxis->numavg != ISEC1_AvgNum) )
 		{
 	      /*
-		  Message(func, "Change numavg from %d to %d not allowed!",
+	          Warning("Changing numavg from %d to %d not supported!",
 			  streamptr->tsteps[tsID].taxis.numavg, ISEC1_AvgNum);
 	      */
 		  warn_numavg = FALSE;
@@ -1268,7 +1285,7 @@ int cgribexScanTimestep(int streamID)
 	    {
 	      char paramstr[32];
 	      cdiParamToString(param, paramstr, sizeof(paramstr));
-	      Warning(func, "Param=%s level=%d not available at timestep %d!", paramstr, level1, tsID+1);
+	      Warning("Param=%s level=%d not available at timestep %d!", paramstr, level1, tsID+1);
 
 	      if ( cdiInventoryMode == 1 )
 		return (CDI_EUFSTRUCT);
@@ -1291,7 +1308,7 @@ int cgribexScanTimestep(int streamID)
 		  if ( memcmp(&datetime, &datetime0, sizeof(DateTime)) != 0 ) break;
 		  
 		  if ( CDI_Debug )
-		    Warning(func, "Param=%s level=%d already exist, skipped!", paramstr, level1);
+		    Warning("Param=%s level=%d already exist, skipped!", paramstr, level1);
 
 		  continue;
 		}
@@ -1303,7 +1320,7 @@ int cgribexScanTimestep(int streamID)
 	    }
 
 	  if ( CDI_Debug )
-	    Message(func, "%4d %8d %4d %8d %8d %6d", rindex+1, (int)recpos, param, level1, vdate, vtime);
+	    Message("%4d %8d %4d %8d %8d %6d", rindex+1, (int)recpos, param, level1, vdate, vtime);
 
 	  compVar0.param  = streamptr->tsteps[tsID].records[recID].param;
 	  compVar0.level1 = streamptr->tsteps[tsID].records[recID].ilevel;
@@ -1312,18 +1329,18 @@ int cgribexScanTimestep(int streamID)
 
 	  if ( memcmp(&compVar0, &compVar, sizeof(compvar_t)) != 0 )
 	    {
-	      Message(func, "tsID = %d recID = %d param = %3d new %3d  level = %3d new %3d",
+	      Message("tsID = %d recID = %d param = %3d new %3d  level = %3d new %3d",
 		      tsID, recID,
 		      streamptr->tsteps[tsID].records[recID].param, param,
 		      streamptr->tsteps[tsID].records[recID].ilevel, level1);
-	      Error(func, "Invalid, unsupported or inconsistent record structure");
+	      Error("Invalid, unsupported or inconsistent record structure");
 	    }
 	  
 	  streamptr->tsteps[tsID].records[recID].position = recpos;
 	  streamptr->tsteps[tsID].records[recID].size = recsize;
 
 	  if ( CDI_Debug )
-	    Message(func, "%4d %8d %4d %8d %8d %6d", rindex, (int)recpos, param, level1, vdate, vtime);
+	    Message("%4d %8d %4d %8d %8d %6d", rindex, (int)recpos, param, level1, vdate, vtime);
 
 	  rindex++;
 	}
@@ -1338,7 +1355,7 @@ int cgribexScanTimestep(int streamID)
 	{
 	  char paramstr[32];
 	  cdiParamToString(streamptr->tsteps[tsID].records[recID].param, paramstr, sizeof(paramstr));
-	  Warning(func, "Param=%s level=%d not found at timestep %d!",
+	  Warning("Param=%s level=%d not found at timestep %d!",
 		  paramstr, streamptr->tsteps[tsID].records[recID].ilevel, tsID+1);
 	  return (CDI_EUFSTRUCT);
 	}
@@ -1349,7 +1366,7 @@ int cgribexScanTimestep(int streamID)
 	{
 	  tsID = tstepsNewEntry(streamID);
 	  if ( tsID != streamptr->rtsteps )
-	    Error(func, "Internal error. tsID = %d", tsID);
+	    Error("Internal error. tsID = %d", tsID);
 
 	  streamptr->tsteps[tsID-1].next   = 1;
 	  streamptr->tsteps[tsID].position = recpos;
@@ -1364,7 +1381,7 @@ int cgribexScanTimestep(int streamID)
 
   if ( nrecs > 0 && nrecs < streamptr->tsteps[tsID].nrecs )
     {
-      Warning(func, "Incomplete timestep. Stop scanning at timestep %d.\n", tsID);
+      Warning("Incomplete timestep. Stop scanning at timestep %d.\n", tsID);
       streamptr->ntsteps = tsID;
     }
 
@@ -1375,7 +1392,6 @@ int cgribexScanTimestep(int streamID)
 int cgribexDecode(unsigned char *gribbuffer, int gribsize, double *data, int gridsize,
 		  int unreduced, int *nmiss, int *zip, double missval)
 {
-  static const char *func = "cgribexDecode";
   int status = 0;
 #if  defined  (HAVE_LIBCGRIBEX)
   int iret = 0, iword = 0;
@@ -1420,13 +1436,13 @@ int cgribexDecode(unsigned char *gribbuffer, int gribsize, double *data, int gri
 	  gribsize = gribUnzip(gribbuffer, unzipsize, itmpbuffer, gribsize);
 
 	  if ( gribsize <= 0 )
-	    Error(func, "Decompression problem!\n");
+	    Error("Decompression problem!\n");
 	  
 	  free(itmpbuffer);
 	}
       else
 	{
-	  Error(func, "Decompression for %d not implemented!\n", izip);
+	  Error("Decompression for %d not implemented!\n", izip);
 	}
     }
 
@@ -1453,7 +1469,7 @@ int cgribexDecode(unsigned char *gribbuffer, int gribsize, double *data, int gri
         }
     }
 #else
-  Error(func, "CGRIBEX support not compiled in!");
+  Error("CGRIBEX support not compiled in!");
 #endif
 
   return (status);
@@ -1498,7 +1514,6 @@ void cgribexDefModel(int *isec1, int vlistID, int varID)
 static
 void cgribexDefParam(int *isec1, int param)
 {
-  static const char *func = "cgribexDefParam";
   int pdis, pcat, pnum;
   static int lwarn = TRUE;
 
@@ -1508,7 +1523,7 @@ void cgribexDefParam(int *isec1, int param)
     {
       char paramstr[32];
       cdiParamToString(param, paramstr, sizeof(paramstr));
-      Warning(func, "Can not convert GRIB2 parameter (%s) to GRIB1!", paramstr);
+      Warning("Can not convert GRIB2 parameter (%s) to GRIB1!", paramstr);
       lwarn = FALSE;
     }
     
@@ -1684,8 +1699,8 @@ void cgribexDefTime(int *isec1, int vdate, int vtime, int tsteptype, int numavg,
 static
 void cgribexDefGrid(int *isec1, int *isec2, int *isec4, int gridID)
 {
-  static const char *func = "cgribexDefGrid";
   int gridtype;
+  int lcurvi = FALSE;
   static short lwarn = TRUE;
 
   memset(isec2, 0, 16*sizeof(int));
@@ -1698,8 +1713,9 @@ void cgribexDefGrid(int *isec1, int *isec2, int *isec4, int gridID)
 
   if ( gridtype == GRID_GENERIC )
     {
-      int xsize, ysize;
+      int xsize, ysize, gridsize;
 
+      gridsize = gridInqSize(gridID);
       xsize = gridInqXsize(gridID);
       ysize = gridInqYsize(gridID);
 
@@ -1710,7 +1726,7 @@ void cgribexDefGrid(int *isec1, int *isec2, int *isec4, int gridID)
 	  gridtype = GRID_GAUSSIAN;
 	  gridChangeType(gridID, gridtype);
 	}
-      else if ( (xsize == 1 && ysize == 1) || (xsize == 0 && ysize == 0) )
+      else if ( gridsize == 1 )
 	{
 	  gridtype = GRID_LONLAT;
 	  gridChangeType(gridID, gridtype);
@@ -1726,9 +1742,10 @@ void cgribexDefGrid(int *isec1, int *isec2, int *isec4, int gridID)
       if ( lwarn && gridInqSize(gridID) > 1 )
 	{
 	  lwarn = FALSE;
-	  Warning(func, "Curvilinear grids are unsupported in GRIB1! Created wrong GDS!");
+	  Warning("Curvilinear grids are unsupported in GRIB1! Created wrong GDS!");
 	}
       gridtype = GRID_LONLAT;
+      lcurvi = TRUE;
     }
 
   ISEC2_Reduced = FALSE;
@@ -1746,6 +1763,9 @@ void cgribexDefGrid(int *isec1, int *isec2, int *isec4, int gridID)
 	double xfirst = 0, xlast = 0, xinc = 0;
 	double yfirst = 0, ylast = 0, yinc = 0;
 
+	nlon = gridInqXsize(gridID);
+	nlat = gridInqYsize(gridID);
+
 	if ( gridtype == GRID_GAUSSIAN_REDUCED )
 	  {
 	    ISEC2_Reduced = TRUE;
@@ -1754,7 +1774,6 @@ void cgribexDefGrid(int *isec1, int *isec2, int *isec4, int gridID)
 	  }
 	else
 	  {
-	    nlon = gridInqXsize(gridID);
 	    if ( nlon == 0 )
 	      {
 		nlon = 1;
@@ -1762,12 +1781,14 @@ void cgribexDefGrid(int *isec1, int *isec2, int *isec4, int gridID)
 	    else
 	      {
 		xfirst = gridInqXval(gridID,      0);
-		xlast  = gridInqXval(gridID, nlon-1);
+		if ( lcurvi )
+		  xlast  = gridInqXval(gridID, nlon*nlat-1);
+		else
+		  xlast  = gridInqXval(gridID, nlon-1);
 		xinc   = gridInqXinc(gridID);
 	      }
 	  }
 
-	nlat = gridInqYsize(gridID);
 	if ( nlat == 0 )
 	  {
 	    nlat = 1;
@@ -1775,8 +1796,12 @@ void cgribexDefGrid(int *isec1, int *isec2, int *isec4, int gridID)
 	else
 	  {
 	    yfirst = gridInqYval(gridID,      0);
-	    ylast  = gridInqYval(gridID, nlat-1);
+	    if ( lcurvi )
+	      ylast  = gridInqYval(gridID, nlon*nlat-1);
+	    else
+	      ylast  = gridInqYval(gridID, nlat-1);
 	    yinc   = gridInqYinc(gridID);
+	    if ( yinc < 0 ) yinc = -yinc;
 	  }
 
 	if ( gridtype == GRID_GAUSSIAN || gridtype == GRID_GAUSSIAN_REDUCED )
@@ -1910,8 +1935,8 @@ void cgribexDefGrid(int *isec1, int *isec2, int *isec4, int gridID)
       }
     default:
       {
-	Warning(func, "The CGRIBEX library can not store fields on the used grid!");
-	Error(func, "Unsupported grid type: %s", gridNamePtr(gridtype));
+	Warning("The CGRIBEX library can not store fields on the used grid!");
+	Error("Unsupported grid type: %s", gridNamePtr(gridtype));
       }
     }
 }
@@ -1919,7 +1944,6 @@ void cgribexDefGrid(int *isec1, int *isec2, int *isec4, int gridID)
 static
 void cgribexDefLevel(int *isec1, int *isec2, double *fsec2, int zaxisID, int levelID)
 {
-  static const char *func = "cgribexDefLevel";
   double level;
   int ilevel, zaxistype, ltype;
   static int warning = 1;
@@ -1930,6 +1954,9 @@ void cgribexDefLevel(int *isec1, int *isec2, double *fsec2, int zaxisID, int lev
 
   if ( zaxistype == ZAXIS_GENERIC && ltype == 0 )
     {
+      Message("Changed zaxis type from %s to %s\n",
+	      zaxisNamePtr(zaxistype),
+	      zaxisNamePtr(ZAXIS_PRESSURE));
       zaxistype = ZAXIS_PRESSURE;
       zaxisChangeType(zaxisID, zaxistype);
       zaxisDefUnits(zaxisID, "Pa");
@@ -1974,7 +2001,7 @@ void cgribexDefLevel(int *isec1, int *isec2, double *fsec2, int zaxisID, int lev
 	vctsize = zaxisInqVctSize(zaxisID);
 	if ( vctsize == 0 && warning )
 	  {
-	    Warning(func, "VCT missing. ( param = %d, zaxisID = %d )",
+	    Warning("VCT missing. ( param = %d, zaxisID = %d )",
 		    ISEC1_Parameter, zaxisID);
 	    warning = 0;
 	  }
@@ -1983,7 +2010,7 @@ void cgribexDefLevel(int *isec1, int *isec2, double *fsec2, int zaxisID, int lev
 	    ISEC2_NumVCP = 0;
 	    if ( vct_warning )
 	      {
-		Warning(func, "VCT size of %d is too large (maximum is 255). Set to 0!", vctsize);
+		Warning("VCT size of %d is too large (maximum is 255). Set to 0!", vctsize);
 		vct_warning = 0;
 	      }
 	  }
@@ -2001,7 +2028,7 @@ void cgribexDefLevel(int *isec1, int *isec2, double *fsec2, int zaxisID, int lev
 
 	level = zaxisInqLevel(zaxisID, levelID);
 	if ( level < 0 )
-	  Warning(func, "Pressure level of %f Pa is below zero!", level);
+	  Warning("Pressure level of %f Pa is below zero!", level);
 
 	zaxisInqUnits(zaxisID, units);
 	if ( memcmp(units, "Pa", 2) != 0 ) level *= 100;
@@ -2109,7 +2136,7 @@ void cgribexDefLevel(int *isec1, int *isec2, double *fsec2, int zaxisID, int lev
       }
     default:
       {
-	Error(func, "Unsupported zaxis type: %s", zaxisNamePtr(zaxistype));
+	Error("Unsupported zaxis type: %s", zaxisNamePtr(zaxistype));
 	break;
       }
     }
@@ -2138,15 +2165,9 @@ void cgribexDefaultSec1(int *isec1)
 static
 void cgribexDefaultSec4(int *isec4)
 {
-  isec4[2] = 0;
-  isec4[3] = 0;
-  isec4[4] = 0;
-  isec4[5] = 0;
-  isec4[6] = 0;
-  isec4[7] = 0;
-  isec4[8] = 0;
-  isec4[9] = 0;
-  isec4[10] = 0;
+  long i;
+
+  for ( i = 2; i <= 10; ++i ) isec4[i] = 0;
 }
 #endif
 
@@ -2155,7 +2176,6 @@ size_t cgribexEncode(int varID, int levelID, int vlistID, int gridID, int zaxisI
 		     int vdate, int vtime, int tsteptype, int numavg, 
 		     long datasize, const double *data, int nmiss, unsigned char *gribbuffer, size_t gribbuffersize)
 {
-  static const char *func = "cgribexEncode";
   size_t nbytes = 0;
 #if  defined  (HAVE_LIBCGRIBEX)
   long gribsize;
@@ -2206,11 +2226,11 @@ size_t cgribexEncode(int varID, int levelID, int vlistID, int gridID, int zaxisI
   gribExDP(isec0, isec1, isec2, fsec2, isec3, fsec3, isec4, (double*) data,
 	   datasize, (int *) gribbuffer, gribsize, &iword, "C", &iret);
 
-  if ( iret ) Error(func, "Problem during GRIB encode (errno = %d)!", iret);
+  if ( iret ) Error("Problem during GRIB encode (errno = %d)!", iret);
 
   nbytes = iword*sizeof(int);
 #else
-  Error(func, "CGRIBEX support not compiled in!");
+  Error("CGRIBEX support not compiled in!");
 #endif
 
   return (nbytes);
