@@ -44,10 +44,9 @@ char *tunitNamePtr(int unitID)
   return (name);
 }
 
-
+static
 void taxis_defaults(void)
 {
-  static const char *func = "taxis_defaults";
   char *timeunit;
 
   timeunit = getenv("TIMEUNIT");
@@ -70,7 +69,7 @@ void taxis_defaults(void)
       else if ( strcmp(timeunit, "year") == 0 )
 	DefaultTimeUnit = TUNIT_YEAR;
       else
-	Warning(func, "Unsupported TIMEUNIT %s!", timeunit);
+	Warning("Unsupported TIMEUNIT %s!", timeunit);
     }
 }
 
@@ -118,8 +117,6 @@ static int            _taxisAvail = -1;
 static
 void taxis_list_new(void)
 {
-  static const char *func = "taxis_list_new";
-
   assert(_taxisList == NULL);
 
   _taxisList = (taxisPtrToIdx *) malloc(_taxis_min*sizeof(taxisPtrToIdx));
@@ -128,8 +125,6 @@ void taxis_list_new(void)
 static
 void taxis_list_delete(void)
 {
-  static const char *func = "taxis_list_delete";
-
   if ( _taxisList ) free(_taxisList);
 }
 
@@ -153,7 +148,6 @@ void taxis_init_pointer(void)
 static
 void taxis_list_extend(void)
 {
-  static const char *func = "taxis_list_extend";
   int ntaxis;
   int i;
 
@@ -178,13 +172,12 @@ void taxis_list_extend(void)
       _taxisList[_taxis_min-1].next = -1;
     }
   else
-    Warning(func, "Too many open taxes (limit is %d)!", _taxis_max);
+    Warning("Too many open taxes (limit is %d)!", _taxis_max);
 }
 
-
+static
 taxis_t *taxis_to_pointer(int idx)
 {
-  static const char *func = "taxis_to_pointer";
   taxis_t *taxisptr = NULL;
 
   TAXIS_INIT();
@@ -198,7 +191,7 @@ taxis_t *taxis_to_pointer(int idx)
       TAXIS_UNLOCK();
     }
   else
-    Error(func, "taxis index %d undefined!", idx);
+    Error("taxis index %d undefined!", idx);
 
   return (taxisptr);
 }
@@ -208,7 +201,6 @@ taxis_t *taxis_to_pointer(int idx)
 static
 int taxis_from_pointer(taxis_t *ptr)
 {
-  static const char *func = "taxis_from_pointer";
   int      idx = -1;
 
   if ( ptr )
@@ -228,18 +220,18 @@ int taxis_from_pointer(taxis_t *ptr)
 	  newptr->ptr  = ptr;
       
 	  if ( TAXIS_Debug )
-	    Message(func, "Pointer %p has idx %d from taxis list", ptr, idx);
+	    Message("Pointer %p has idx %d from taxis list", ptr, idx);
 	}
 
       TAXIS_UNLOCK();
     }
   else
-    Error(func, "Internal problem (pointer %p undefined)", ptr);
+    Error("Internal problem (pointer %p undefined)", ptr);
 
   return (idx);
 }
 
-
+static
 void taxis_init_ptr(taxis_t *taxisptr)
 {
   taxisptr->self       = -1;
@@ -260,7 +252,7 @@ void taxis_init_ptr(taxis_t *taxisptr)
   taxisptr->vtime_ub   = 0;
 }
 
-
+static
 void taxis_init_entry(taxis_t *taxisptr)
 {
   taxis_init_ptr(taxisptr);
@@ -271,7 +263,6 @@ void taxis_init_entry(taxis_t *taxisptr)
 static
 taxis_t *taxis_new_entry(void)
 {
-  static const char *func = "taxis_new_entry";
   taxis_t *taxisptr;
 
   taxisptr = (taxis_t *) malloc(sizeof(taxis_t));
@@ -284,7 +275,6 @@ taxis_t *taxis_new_entry(void)
 static
 void taxis_delete_entry(taxis_t *taxisptr)
 {
-  static const char *func = "taxis_delete_entry";
   int idx;
 
   idx = taxisptr->self;
@@ -300,7 +290,7 @@ void taxis_delete_entry(taxis_t *taxisptr)
   TAXIS_UNLOCK();
 
   if ( TAXIS_Debug )
-    Message(func, "Removed idx %d from taxis list", idx);
+    Message("Removed idx %d from taxis list", idx);
 }
 
 static
@@ -341,13 +331,12 @@ void taxis_copy(taxis_t *taxisptr2, taxis_t *taxisptr1)
 }
 
 static
-void taxis_check_ptr(const char *func, taxis_t *taxisptr)
+void taxis_check_ptr(const char *caller, taxis_t *taxisptr)
 {
   if ( taxisptr == NULL )
-    Error(func, "taxis undefined!");
+    Errorc("taxis undefined!");
 }
 
-
 /*
 @Function  taxisCreate
 @Title     Create a Time axis
@@ -374,7 +363,7 @@ int taxisID;
    ...
 taxisID = taxisCreate(TAXIS_RELATIVE);
 taxisDefCalendar(taxisID, CALENDAR_STANDARD);
-taxisDefRdate(taxisID, 19870101);
+taxisDefRdate(taxisID, 19850101);
 taxisDefRtime(taxisID, 120000);
    ...
 @EndSource
@@ -382,28 +371,26 @@ taxisDefRtime(taxisID, 120000);
 */
 int taxisCreate(int taxistype)
 {
-  static const char *func = "taxisCreate";
   int taxisID;
   taxis_t *taxisptr;
 
   if ( CDI_Debug )
-    Message(func, "taxistype: %d", taxistype);
+    Message("taxistype: %d", taxistype);
 
   TAXIS_INIT();
 
   taxisptr = taxis_new_entry();
-  if ( ! taxisptr ) Error(func, "No memory");
+  if ( ! taxisptr ) Error("No memory");
 
   taxisID = taxisptr->self;
   taxisptr->type = taxistype;
 
   if ( CDI_Debug )
-    Message(func, "taxisID: %d", taxisID);
+    Message("taxisID: %d", taxisID);
 
   return (taxisID);
 }
 
-
 /*
 @Function  taxisDestroy
 @Title     Destroy a Time axis
@@ -416,12 +403,11 @@ int taxisCreate(int taxistype)
 */
 void taxisDestroy(int taxisID)
 {
-  static const char *func = "taxisDestroy";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxis_delete_entry(taxisptr);
 }
@@ -429,7 +415,6 @@ void taxisDestroy(int taxisID)
 
 int taxisDuplicate(int taxisID1)
 {
-  static const char *func = "taxisDuplicate";
   int taxisID2;
   taxis_t *taxisptr1;
   taxis_t *taxisptr2;
@@ -437,12 +422,12 @@ int taxisDuplicate(int taxisID1)
   taxisptr1 = taxis_to_pointer(taxisID1);
 
   taxisptr2 = taxis_new_entry();
-  if ( ! taxisptr2 ) Error(func, "No memory");
+  if ( ! taxisptr2 ) Error("No memory");
 
   taxisID2 = taxisptr2->self;
 
   if ( CDI_Debug )
-    Message(func, "taxisID2: %d", taxisID2);
+    Message("taxisID2: %d", taxisID2);
 
   ptaxisCopy(taxisptr2, taxisptr1);
 
@@ -454,17 +439,15 @@ int taxisDuplicate(int taxisID1)
 
 void taxisDefType(int taxisID, int type)
 {
-  static const char *func = "taxisDefType";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxisptr->type = type;
 }
 
-
 /*
 @Function  taxisDefVdate
 @Title     Define the verification date
@@ -481,17 +464,15 @@ The function @func{taxisDefVdate} defines the verification date of a Time axis.
 */
 void taxisDefVdate(int taxisID, int vdate)
 {
-  static const char *func = "taxisDefVdate";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxisptr->vdate = vdate;
 }
 
-
 /*
 @Function  taxisDefVtime
 @Title     Define the verification time
@@ -508,17 +489,15 @@ The function @func{taxisDefVtime} defines the verification time of a Time axis.
 */
 void taxisDefVtime(int taxisID, int vtime)
 {
-  static const char *func = "taxisDefVtime";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxisptr->vtime = vtime;
 }
 
-
 /*
 @Function  taxisDefRdate
 @Title     Define the reference date
@@ -535,17 +514,15 @@ The function @func{taxisDefVdate} defines the reference date of a Time axis.
 */
 void taxisDefRdate(int taxisID, int rdate)
 {
-  static const char *func = "taxisDefRdate";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxisptr->rdate = rdate;
 }
 
-
 /*
 @Function  taxisDefRtime
 @Title     Define the reference time
@@ -562,17 +539,15 @@ The function @func{taxisDefVdate} defines the reference time of a Time axis.
 */
 void taxisDefRtime(int taxisID, int rtime)
 {
-  static const char *func = "taxisDefRtime";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxisptr->rtime = rtime;
 }
 
-
 /*
 @Function  taxisDefCalendar
 @Title     Define the calendar
@@ -591,12 +566,11 @@ The function @func{taxisDefCalendar} defines the calendar of a Time axis.
 */
 void taxisDefCalendar(int taxisID, int calendar)
 {
-  static const char *func = "taxisDefCalendar";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxisptr->calendar = calendar;
 }
@@ -604,24 +578,23 @@ void taxisDefCalendar(int taxisID, int calendar)
 
 void taxisDefTunit(int taxisID, int unit)
 {
-  static const char *func = "taxisDefTunit";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxisptr->unit = unit;
 }
 
+
 void taxisDefNumavg(int taxisID, int numavg)
 {
-  static const char *func = "taxisDefNumavg";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxisptr->numavg = numavg;
 }
@@ -633,12 +606,11 @@ The valid CDI time types are TAXIS_ABSOLUTE and TAXIS_RELATIVE.
 */
 int taxisInqType(int taxisID)
 {
-  static const char *func = "taxisInqType";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   return (taxisptr->type);
 }
@@ -646,12 +618,11 @@ int taxisInqType(int taxisID)
 
 int taxisHasBounds(int taxisID)
 {
-  static const char *func = "taxisHasBounds";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   return (taxisptr->has_bounds);
 }
@@ -659,12 +630,11 @@ int taxisHasBounds(int taxisID)
 
 void taxisDeleteBounds(int taxisID)
 {
-  static const char *func = "taxisDeleteBounds";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxisptr->has_bounds = FALSE;
 }
@@ -672,15 +642,16 @@ void taxisDeleteBounds(int taxisID)
 
 void taxisCopyTimestep(int taxisID2, int taxisID1)
 {
-  static const char *func = "taxisCopyTimestep";
   taxis_t *taxisptr1;
   taxis_t *taxisptr2;
 
   taxisptr1 = taxis_to_pointer(taxisID1);
   taxisptr2 = taxis_to_pointer(taxisID2);
 
-  taxis_check_ptr(func, taxisptr1);
-  taxis_check_ptr(func, taxisptr2);
+  taxis_check_ptr(__func__, taxisptr1);
+  taxis_check_ptr(__func__, taxisptr2);
+
+  TAXIS_LOCK();
 
   taxisptr2->rdate = taxisptr1->rdate;
   taxisptr2->rtime = taxisptr1->rtime;
@@ -695,8 +666,9 @@ void taxisCopyTimestep(int taxisID2, int taxisID1)
       taxisptr2->vdate_ub = taxisptr1->vdate_ub;
       taxisptr2->vtime_ub = taxisptr1->vtime_ub;
     }
-}
 
+  TAXIS_UNLOCK();
+}
 
 /*
 @Function  taxisInqVdate
@@ -716,12 +688,11 @@ The function @func{taxisInqVdate} returns the verification date of a Time axis.
 */
 int taxisInqVdate(int taxisID)
 {
-  static const char *func = "taxisInqVdate";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   return (taxisptr->vdate);
 }
@@ -729,12 +700,11 @@ int taxisInqVdate(int taxisID)
 
 void taxisInqVdateBounds(int taxisID, int *vdate_lb, int *vdate_ub)
 {
-  static const char *func = "taxisInqVdateBounds";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   *vdate_lb = taxisptr->vdate_lb;
   *vdate_ub = taxisptr->vdate_ub;
@@ -743,12 +713,11 @@ void taxisInqVdateBounds(int taxisID, int *vdate_lb, int *vdate_ub)
 
 void taxisDefVdateBounds(int taxisID, int vdate_lb, int vdate_ub)
 {
-  static const char *func = "taxisDefVdateBounds";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxisptr->vdate_lb = vdate_lb;
   taxisptr->vdate_ub = vdate_ub;
@@ -756,7 +725,6 @@ void taxisDefVdateBounds(int taxisID, int vdate_lb, int vdate_ub)
   taxisptr->has_bounds = TRUE;
 }
 
-
 /*
 @Function  taxisInqVtime
 @Title     Get the verification time
@@ -775,12 +743,11 @@ The function @func{taxisInqVtime} returns the verification time of a Time axis.
 */
 int taxisInqVtime(int taxisID)
 {
-  static const char *func = "taxisInqVtime";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   return (taxisptr->vtime);
 }
@@ -788,12 +755,11 @@ int taxisInqVtime(int taxisID)
 
 void taxisInqVtimeBounds(int taxisID, int *vtime_lb, int *vtime_ub)
 {
-  static const char *func = "taxisInqVtimeBounds";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   *vtime_lb = taxisptr->vtime_lb;
   *vtime_ub = taxisptr->vtime_ub;
@@ -802,12 +768,11 @@ void taxisInqVtimeBounds(int taxisID, int *vtime_lb, int *vtime_ub)
 
 void taxisDefVtimeBounds(int taxisID, int vtime_lb, int vtime_ub)
 {
-  static const char *func = "taxisDefVtimeBounds";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   taxisptr->vtime_lb = vtime_lb;
   taxisptr->vtime_ub = vtime_ub;
@@ -834,12 +799,11 @@ The function @func{taxisInqRdate} returns the reference date of a Time axis.
 */
 int taxisInqRdate(int taxisID)
 {
-  static const char *func = "taxisInqRdate";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   if ( taxisptr->rdate == -1 )
     {
@@ -869,12 +833,11 @@ The function @func{taxisInqRtime} returns the reference time of a Time axis.
 */
 int taxisInqRtime(int taxisID)
 {
-  static const char *func = "taxisInqRtime";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   if ( taxisptr->rdate == -1 )
     {
@@ -907,12 +870,11 @@ The valid CDI calendar types are @func{CALENDAR_STANDARD}, @func{CALENDAR_PROLEP
 */
 int taxisInqCalendar(int taxisID)
 {
-  static const char *func = "taxisInqCalendar";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   return (taxisptr->calendar);
 }
@@ -920,12 +882,11 @@ int taxisInqCalendar(int taxisID)
 
 int taxisInqTunit(int taxisID)
 {
-  static const char *func = "taxisInqTunit";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   return (taxisptr->unit);
 }
@@ -933,12 +894,11 @@ int taxisInqTunit(int taxisID)
 
 int taxisInqNumavg(int taxisID)
 {
-  static const char *func = "taxisInqNumavg";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   return (taxisptr->numavg);
 }
@@ -946,12 +906,11 @@ int taxisInqNumavg(int taxisID)
 
 taxis_t *taxisPtr(int taxisID)
 {
-  static const char *func = "taxisPtr";
   taxis_t *taxisptr;
 
   taxisptr = taxis_to_pointer(taxisID);
 
-  taxis_check_ptr(func, taxisptr);
+  taxis_check_ptr(__func__, taxisptr);
 
   return (taxisptr);
 }
@@ -959,7 +918,6 @@ taxis_t *taxisPtr(int taxisID)
 
 void cdiDecodeTimevalue(int timeunit, double timevalue, int *days, int *secs)
 {
-  static const char *func = "cdiDecodeTimevalue";
   static int lwarn = TRUE;
 
   if ( timeunit == TUNIT_MINUTE )
@@ -1003,7 +961,7 @@ void cdiDecodeTimevalue(int timeunit, double timevalue, int *days, int *secs)
     {
       if ( lwarn )
 	{
-	  Warning(func, "timeunit %s unsupported!", tunitNamePtr(timeunit));
+	  Warning("timeunit %s unsupported!", tunitNamePtr(timeunit));
 	  lwarn = FALSE;
 	}
     }
@@ -1012,7 +970,6 @@ void cdiDecodeTimevalue(int timeunit, double timevalue, int *days, int *secs)
 static
 void cdiEncodeTimevalue(int days, int secs, int timeunit, double *timevalue)
 {
-  static const char *func = "cdiEncodeTimevalue";
   static int lwarn = TRUE;
 
   if ( timeunit == TUNIT_SECOND )
@@ -1039,7 +996,7 @@ void cdiEncodeTimevalue(int days, int secs, int timeunit, double *timevalue)
     {
       if ( lwarn )
 	{
-	  Warning(func, "timeunit %s unsupported!", tunitNamePtr(timeunit));
+	  Warning("timeunit %s unsupported!", tunitNamePtr(timeunit));
 	  lwarn = FALSE;
 	}
     }
@@ -1049,7 +1006,6 @@ int days_per_month(int calendar, int year, int month);
 
 void timeval2vtime(double timevalue, taxis_t *taxis, int *vdate, int *vtime)
 {
-  static const char *func = "timeval2vtime";
   int year, month, day, hour, minute, second;
   int rdate, rtime;
   int timeunit;
@@ -1065,6 +1021,9 @@ void timeval2vtime(double timevalue, taxis_t *taxis, int *vdate, int *vtime)
 
   rdate  = (*taxis).rdate;
   rtime  = (*taxis).rtime;
+
+  if ( rdate == 0 && rtime == 0 && DBL_IS_EQUAL(timevalue, 0) ) return;
+
   cdiDecodeDate(rdate, &year, &month, &day);
   cdiDecodeTime(rtime, &hour, &minute, &second);
 
@@ -1090,7 +1049,7 @@ void timeval2vtime(double timevalue, taxis_t *taxis, int *vdate, int *vtime)
 
 	  if ( (NINT(timevalue*10))%10 && lwarn )
 	    {
-	      Warning(func, "Possible wrong calculation of date/time!\n"
+	      Warning("Possible wrong calculation of date/time!\n"
 		      "Non integer time offset unsupported for time unit MONTH and YEAR!");
 	      lwarn = FALSE;
 	    }
@@ -1159,6 +1118,8 @@ double vtime2timeval(int vdate, int vtime, taxis_t *taxis)
       rtime  = (*taxis).vtime;
     }
 
+  if ( rdate == 0 && rtime == 0 && vdate == 0 && vtime == 0 ) return(value);
+
   cdiDecodeDate(rdate, &ryear, &rmonth, &day);
   cdiDecodeTime(rtime, &hour, &minute, &second);
 
@@ -1238,11 +1199,9 @@ void conv_timeval(double timevalue, int *rvdate, int *rvtime)
 
 void splitTimevalue(double timevalue, int timeunit, int *date, int *time)
 {
-  static const char *func = "splitTimevalue";
   int vdate = 0, vtime = 0;
   int hour, minute, second;
   int year, month, day;
-  int daysec;
   static int lwarn = TRUE;
 
   if ( timeunit == TUNIT_SECOND )
@@ -1268,12 +1227,12 @@ void splitTimevalue(double timevalue, int timeunit, int *date, int *time)
     {
       if ( timevalue < -214700 )
 	{
-	  Warning(func, "Year %g out of range, set to -214700", timevalue);
+	  Warning("Year %g out of range, set to -214700", timevalue);
 	  timevalue = -214700;
 	}
       else if ( timevalue > 214700 )
 	{
-	  Warning(func, "Year %g out of range, set to 214700", timevalue);
+	  Warning("Year %g out of range, set to 214700", timevalue);
 	  timevalue = 214700;
 	}
 
@@ -1284,7 +1243,7 @@ void splitTimevalue(double timevalue, int timeunit, int *date, int *time)
     {
       if ( lwarn )
 	{
-	  Warning(func, "timeunit %s unsupported!", tunitNamePtr(timeunit));
+	  Warning("timeunit %s unsupported!", tunitNamePtr(timeunit));
 	  lwarn = FALSE;
 	}
     }
@@ -1306,7 +1265,7 @@ void splitTimevalue(double timevalue, int timeunit, int *date, int *time)
       vdate = cdiEncodeDate(year, month, day);
       vtime = cdiEncodeTime(hour, minute, second);
 
-      Warning(func, "Reset wrong date/time to %4.4d-%2.2d-%2.2d %2.2d:%2.2d:%2.2d!",
+      Warning("Reset wrong date/time to %4.4d-%2.2d-%2.2d %2.2d:%2.2d:%2.2d!",
 	      year, month, day, hour, minute, second);
     }
 
@@ -1371,6 +1330,8 @@ void ptaxisInit(taxis_t *taxisptr)
 
 void ptaxisCopy(taxis_t *dest, taxis_t *source)
 {
+  TAXIS_LOCK();
+
   /* memcpy(dest, source, sizeof(taxis_t)); */
   dest->used       = source->used;  
   dest->type       = source->type;
@@ -1386,4 +1347,6 @@ void ptaxisCopy(taxis_t *dest, taxis_t *source)
   dest->vtime_lb   = source->vtime_lb;
   dest->vdate_ub   = source->vdate_ub;
   dest->vtime_ub   = source->vtime_ub;
+
+  TAXIS_UNLOCK();
 }
