@@ -56,7 +56,7 @@ typedef struct {
   int      vctsize;
   double  *vct;
 }
-ZAXIS;
+zaxis_t;
 
 static int  ZAXIS_Debug = 0;   /* If set to 1, debugging */
 
@@ -89,7 +89,7 @@ static pthread_mutex_t _zaxis_mutex;
 
 typedef struct _zaxisPtrToIdx {
   int idx;
-  ZAXIS *ptr;
+  zaxis_t *ptr;
   struct _zaxisPtrToIdx *next;
 } zaxisPtrToIdx;
 
@@ -98,25 +98,22 @@ static zaxisPtrToIdx *_zaxisList  = NULL;
 static zaxisPtrToIdx *_zaxisAvail = NULL;
 
 
-static void zaxis_list_new(void)
+static
+void zaxis_list_new(void)
 {
-  static const char *func = "zaxis_list_new";
-
   assert(_zaxisList == NULL);
 
   _zaxisList = (zaxisPtrToIdx *) malloc(_zaxis_max*sizeof(zaxisPtrToIdx));
 }
 
-
-static void zaxis_list_delete(void)
+static
+void zaxis_list_delete(void)
 {
-  static const char *func = "zaxis_list_delete";
-
   if ( _zaxisList ) free(_zaxisList);
 }
 
-
-static void zaxis_init_pointer(void)
+static
+void zaxis_init_pointer(void)
 {
   int  i;
   
@@ -133,10 +130,9 @@ static void zaxis_init_pointer(void)
 }
 
 
-ZAXIS *zaxis_to_pointer(int idx)
+zaxis_t *zaxis_to_pointer(int idx)
 {
-  static const char *func = "zaxis_to_pointer";
-  ZAXIS *zaxisptr = NULL;
+  zaxis_t *zaxisptr = NULL;
 
   ZAXIS_INIT
 
@@ -149,16 +145,15 @@ ZAXIS *zaxis_to_pointer(int idx)
       ZAXIS_UNLOCK
     }
   else
-    Error(func, "zaxis index %d undefined!", idx);
+    Error("zaxis index %d undefined!", idx);
 
   return (zaxisptr);
 }
 
-
 /* Create an index from a pointer */
-static int zaxis_from_pointer(ZAXIS *ptr)
+static
+int zaxis_from_pointer(zaxis_t *ptr)
 {
-  static const char *func = "zaxis_from_pointer";
   int      idx = -1;
   zaxisPtrToIdx *newptr;
 
@@ -175,21 +170,21 @@ static int zaxis_from_pointer(ZAXIS *ptr)
 	  newptr->ptr  = ptr;
       
 	  if ( ZAXIS_Debug )
-	    Message(func, "Pointer %p has idx %d from zaxis list", ptr, idx);
+	    Message("Pointer %p has idx %d from zaxis list", ptr, idx);
 	}
       else
-	Warning(func, "Too many open zaxis (limit is %d)!", _zaxis_max);
+	Warning("Too many open zaxis (limit is %d)!", _zaxis_max);
 
       ZAXIS_UNLOCK
     }
   else
-    Error(func, "Internal problem (pointer %p undefined)", ptr);
+    Error("Internal problem (pointer %p undefined)", ptr);
 
   return (idx);
 }
 
-
-static void zaxis_init_entry(ZAXIS *zaxisptr)
+static
+void zaxis_init_entry(zaxis_t *zaxisptr)
 {
   zaxisptr->self        = zaxis_from_pointer(zaxisptr);
 
@@ -209,23 +204,21 @@ static void zaxis_init_entry(ZAXIS *zaxisptr)
   zaxisptr->vct         = NULL;
 }
 
-
-static ZAXIS *zaxis_new_entry(void)
+static
+zaxis_t *zaxis_new_entry(void)
 {
-  static const char *func = "zaxis_new_entry";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
-  zaxisptr = (ZAXIS *) malloc(sizeof(ZAXIS));
+  zaxisptr = (zaxis_t *) malloc(sizeof(zaxis_t));
 
   if ( zaxisptr ) zaxis_init_entry(zaxisptr);
 
   return (zaxisptr);
 }
 
-
-static void zaxis_delete_entry(ZAXIS *zaxisptr)
+static
+void zaxis_delete_entry(zaxis_t *zaxisptr)
 {
-  static const char *func = "zaxis_delete_entry";
   int idx;
 
   idx = zaxisptr->self;
@@ -241,11 +234,11 @@ static void zaxis_delete_entry(ZAXIS *zaxisptr)
   ZAXIS_UNLOCK
 
   if ( ZAXIS_Debug )
-    Message(func, "Removed idx %d from zaxis list", idx);
+    Message("Removed idx %d from zaxis list", idx);
 }
 
-
-static void zaxis_initialize(void)
+static
+void zaxis_initialize(void)
 {
   char *env;
 
@@ -269,23 +262,24 @@ static void zaxis_initialize(void)
   _zaxis_init = TRUE;
 }
 
-
-static void zaxis_copy(ZAXIS *zaxisptr2, ZAXIS *zaxisptr1)
+static
+void zaxis_copy(zaxis_t *zaxisptr2, zaxis_t *zaxisptr1)
 {
   int zaxisID2;
 
   zaxisID2 = zaxisptr2->self;
-  memcpy(zaxisptr2, zaxisptr1, sizeof(ZAXIS));
+  memcpy(zaxisptr2, zaxisptr1, sizeof(zaxis_t));
   zaxisptr2->self = zaxisID2;
 }
 
-
-static void zaxis_check_ptr(const char *func, ZAXIS *zaxisptr)
+static
+void zaxisCheckPtr(const char *caller, int zaxisID, zaxis_t *zaxisptr)
 {
   if ( zaxisptr == NULL )
-    Error(func, "zaxis undefined!");
+    Errorc("zaxis %d undefined!", zaxisID);
 }
 
+#define  zaxis_check_ptr(zaxisID, zaxisptr)  zaxisCheckPtr(__func__, zaxisID, zaxisptr)
 
 int zaxisSize(void)
 {
@@ -329,12 +323,12 @@ Here is an example using @func{zaxisCreate} to create a pressure level Z-axis:
 @Source
 #include "cdi.h"
    ...
-#define  NLEV    5
+#define  nlev    5
    ...
-double levs[NLEV] = {101300, 92500, 85000, 50000, 20000};
+double levs[nlev] = {101300, 92500, 85000, 50000, 20000};
 int zaxisID;
    ...
-zaxisID = zaxisCreate(ZAXIS_PRESSURE, NLEV);
+zaxisID = zaxisCreate(ZAXIS_PRESSURE, nlev);
 zaxisDefLevels(zaxisID, levs);
    ...
 @EndSource
@@ -342,19 +336,18 @@ zaxisDefLevels(zaxisID, levs);
 */
 int zaxisCreate(int zaxistype, int size)
 {
-  static const char *func = "zaxisCreate";
   int ilev;
   int zaxisID;
   double *vals;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   if ( CDI_Debug )
-    Message(func, "zaxistype: %d size: %d ", zaxistype, size);
+    Message("zaxistype: %d size: %d ", zaxistype, size);
 
   ZAXIS_INIT
 
   zaxisptr = zaxis_new_entry();
-  if ( ! zaxisptr ) Error(func, "No memory");
+  if ( ! zaxisptr ) Error("No memory");
 
   zaxisID = zaxisptr->self;
 
@@ -362,7 +355,7 @@ int zaxisCreate(int zaxistype, int size)
   zaxisptr->size = size;
 
   if ( zaxistype > CDI_MaxZaxistype )
-    Error(func, "Internal problem! zaxistype > CDI_MaxZaxistype");
+    Error("Internal problem! zaxistype > CDI_MaxZaxistype");
 
   zaxisDefName(zaxisID, ZaxistypeEntry[zaxistype].name);
   zaxisDefLongname(zaxisID, ZaxistypeEntry[zaxistype].longname);
@@ -378,7 +371,6 @@ int zaxisCreate(int zaxistype, int size)
   return (zaxisID);
 }
 
-
 /*
 @Function  zaxisDestroy
 @Title     Destroy a vertical Z-axis
@@ -391,9 +383,11 @@ int zaxisCreate(int zaxistype, int size)
 */
 void zaxisDestroy(int zaxisID)
 {
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
+
+  zaxis_check_ptr(zaxisID, zaxisptr);
 }
 
 
@@ -415,7 +409,6 @@ void zaxisName(int zaxistype, char *zaxisname)
   strcpy(zaxisname, zaxisNamePtr(zaxistype));
 }
 
-
 /*
 @Function  zaxisDefName
 @Title     Define the name of a Z-axis
@@ -432,15 +425,16 @@ The function @func{zaxisDefName} defines the name of a Z-axis.
 */
 void zaxisDefName(int zaxisID, const char *name)
 {
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
+  zaxis_check_ptr(zaxisID, zaxisptr);
+
   if ( name )
     strcpy(zaxisptr->name, name);
 }
 
-
 /*
 @Function  zaxisDefLongname
 @Title     Define the longname of a Z-axis
@@ -457,15 +451,16 @@ The function @func{zaxisDefLongname} defines the longname of a Z-axis.
 */
 void zaxisDefLongname(int zaxisID, const char *longname)
 {
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
+  zaxis_check_ptr(zaxisID, zaxisptr);
+
   if ( longname )
     strcpy(zaxisptr->longname, longname);
 }
 
-
 /*
 @Function  zaxisDefUnits
 @Title     Define the units of a Z-axis
@@ -482,15 +477,16 @@ The function @func{zaxisDefUnits} defines the units of a Z-axis.
 */
 void zaxisDefUnits(int zaxisID, const char *units)
 {
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
+  zaxis_check_ptr(zaxisID, zaxisptr);
+
   if ( units )
     strcpy(zaxisptr->units, units);
 }
 
-
 /*
 @Function  zaxisInqName
 @Title     Get the name of a Z-axis
@@ -510,14 +506,15 @@ The function @func{zaxisInqName} returns the name of a Z-axis.
 */
 void zaxisInqName(int zaxisID, char *name)
 {
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
+  zaxis_check_ptr(zaxisID, zaxisptr);
+
   strcpy(name, zaxisptr->name);
 }
 
-
 /*
 @Function  zaxisInqLongname
 @Title     Get the longname of a Z-axis
@@ -537,14 +534,15 @@ The function @func{zaxisInqLongname} returns the longname of a Z-axis.
 */
 void zaxisInqLongname(int zaxisID, char *longname)
 {
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
+  zaxis_check_ptr(zaxisID, zaxisptr);
+
   strcpy(longname, zaxisptr->longname);
 }
 
-
 /*
 @Function  zaxisInqUnits
 @Title     Get the units of a Z-axis
@@ -564,22 +562,23 @@ The function @func{zaxisInqUnits} returns the units of a Z-axis.
 */
 void zaxisInqUnits(int zaxisID, char *units)
 {
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
+  zaxis_check_ptr(zaxisID, zaxisptr);
+
   strcpy(units, zaxisptr->units);
 }
 
 
 void zaxisDefPrec(int zaxisID, int prec)
 {
-  static const char *func = "zaxisDefPrec";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   zaxisptr->prec = prec;
 }
@@ -587,12 +586,11 @@ void zaxisDefPrec(int zaxisID, int prec)
 
 int zaxisInqPrec(int zaxisID)
 {
-  static const char *func = "zaxisInqPrec";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   return (zaxisptr->prec);
 }
@@ -600,12 +598,11 @@ int zaxisInqPrec(int zaxisID)
 
 void zaxisDefLtype(int zaxisID, int ltype)
 {
-  static const char *func = "zaxisDefLtype";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   zaxisptr->ltype = ltype;
 }
@@ -613,17 +610,15 @@ void zaxisDefLtype(int zaxisID, int ltype)
 
 int zaxisInqLtype(int zaxisID)
 {
-  static const char *func = "zaxisInqLtype";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   return (zaxisptr->ltype);
 }
 
-
 /*
 @Function  zaxisDefLevels
 @Title     Define the levels of a Z-axis
@@ -640,15 +635,14 @@ The function @func{zaxisDefLevels} defines the levels of a Z-axis.
 */
 void zaxisDefLevels(int zaxisID, const double *levels)
 {
-  static const char *func = "zaxisDefLevels";
   int ilev;
   int size;
   double *vals;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   size = zaxisptr->size;
 
@@ -658,7 +652,6 @@ void zaxisDefLevels(int zaxisID, const double *levels)
     vals[ilev] = levels[ilev];
 }
 
-
 /*
 @Function  zaxisDefLevel
 @Title     Define one level of a Z-axis
@@ -676,18 +669,16 @@ The function @func{zaxisDefLevel} defines one level of a Z-axis.
 */
 void zaxisDefLevel(int zaxisID, int levelID, double level)
 {
-  static const char *func = "zaxisDefLevel";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   if ( levelID >= 0 && levelID < zaxisptr->size )
     zaxisptr->vals[levelID] = level;
 }
 
-
 /*
 @Function  zaxisInqLevel
 @Title     Get one level of a Z-axis
@@ -706,13 +697,12 @@ The function @func{zaxisInqLevel} returns one level of a Z-axis.
 */
 double zaxisInqLevel(int zaxisID, int levelID)
 {
-  static const char *func = "zaxisInqLevel";
   double level = 0;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   if ( levelID >= 0 && levelID < zaxisptr->size )
     level = zaxisptr->vals[levelID];
@@ -723,13 +713,12 @@ double zaxisInqLevel(int zaxisID, int levelID)
 
 double zaxisInqLbound(int zaxisID, int index)
 {
-  static const char *func = "zaxisInqLbound";
   double level = 0;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   if ( zaxisptr->lbounds )
     if ( index >= 0 && index < zaxisptr->size )
@@ -741,13 +730,12 @@ double zaxisInqLbound(int zaxisID, int index)
 
 double zaxisInqUbound(int zaxisID, int index)
 {
-  static const char *func = "zaxisInqUbound";
   double level = 0;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   if ( zaxisptr->ubounds )
     if ( index >= 0 && index < zaxisptr->size )
@@ -759,14 +747,15 @@ double zaxisInqUbound(int zaxisID, int index)
 
 const double *zaxisInqLevelsPtr(int zaxisID)
 {
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
+  zaxis_check_ptr(zaxisID, zaxisptr);
+
   return ( zaxisptr->vals );
 }
 
-
 /*
 @Function  zaxisInqLevels
 @Title     Get all levels of a Z-axis
@@ -785,14 +774,13 @@ The function @func{zaxisInqLevels} returns all levels of a Z-axis.
 */
 void zaxisInqLevels(int zaxisID, double *levels)
 {
-  static const char *func = "zaxisInqLevels";
   int size;
   int i;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   size = zaxisptr->size;
   for ( i = 0; i < size; i++ )
@@ -802,14 +790,13 @@ void zaxisInqLevels(int zaxisID, double *levels)
 
 int zaxisInqLbounds(int zaxisID, double *lbounds)
 {
-  static const char *func = "zaxisInqLbounds";
   int size = 0;
   int i;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   if ( zaxisptr->lbounds )
     {
@@ -826,14 +813,13 @@ int zaxisInqLbounds(int zaxisID, double *lbounds)
 
 int zaxisInqUbounds(int zaxisID, double *ubounds)
 {
-  static const char *func = "zaxisInqUbounds";
   int size = 0;
   int i;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   if ( zaxisptr->ubounds )
     {
@@ -850,14 +836,13 @@ int zaxisInqUbounds(int zaxisID, double *ubounds)
 
 int zaxisInqWeights(int zaxisID, double *weights)
 {
-  static const char *func = "zaxisInqWeights";
   int size = 0;
   int i;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   if ( zaxisptr->weights )
     {
@@ -874,15 +859,14 @@ int zaxisInqWeights(int zaxisID, double *weights)
 
 int zaxisInqLevelID(int zaxisID, double level)
 {
-  static const char *func = "zaxisInqLevelID";
   int size;
   int levelID = CDI_UNDEFID;
   int i;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   size = zaxisptr->size;
   for ( i = 0; i < size; i++ )
@@ -893,7 +877,6 @@ int zaxisInqLevelID(int zaxisID, double level)
   return (levelID);
 }
 
-
 /*
 @Function  zaxisInqType
 @Title     Get the type of a Z-axis
@@ -916,17 +899,15 @@ The valid CDI Z-axis types are @func{ZAXIS_GENERIC}, @func{ZAXIS_SURFACE},
 */
 int zaxisInqType(int zaxisID)
 {
-  static const char *func = "zaxisInqType";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   return (zaxisptr->type);
 }
 
-
 /*
 @Function  zaxisInqSize
 @Title     Get the size of a Z-axis
@@ -945,13 +926,12 @@ The function @func{zaxisInqSize} returns the size of a Z-axis.
 */
 int zaxisInqSize(int zaxisID)
 {
-  static const char *func = "zaxisInqSize";
   int size = 1;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   size = zaxisptr->size;
 
@@ -961,13 +941,12 @@ int zaxisInqSize(int zaxisID)
 
 void cdiCheckZaxis(int zaxisID)
 {
-  static const char *func = "cdiCheckZaxis";
   int size, i, found;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
   
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   if ( zaxisInqType(zaxisID) == ZAXIS_GENERIC )
     {
@@ -1000,7 +979,7 @@ void cdiCheckZaxis(int zaxisID)
 	  /* check consistent */
 	  if ( zaxisptr->direction == CDI_UNDEFID )
 	    {
-	      Warning(func, "direction undefined for zaxisID %d", zaxisID);
+	      Warning("direction undefined for zaxisID %d", zaxisID);
 	    }
 	}
     }
@@ -1009,12 +988,11 @@ void cdiCheckZaxis(int zaxisID)
 
 void zaxisDefVct(int zaxisID, int size, const double *vct)
 {
-  static const char *func = "zaxisDefVct";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   if ( zaxisptr->vct == 0 )
     {
@@ -1024,18 +1002,17 @@ void zaxisDefVct(int zaxisID, int size, const double *vct)
     }
   else
     if ( zaxisptr->vctsize != size )
-      Warning(func, "VCT was already defined");
+      Warning("VCT was already defined");
 }
 
 
 int zaxisInqVctSize(int zaxisID)
 {
-  static const char *func = "zaxisInqVctSize";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   return (zaxisptr->vctsize);
 }
@@ -1043,12 +1020,11 @@ int zaxisInqVctSize(int zaxisID)
 
 const double *zaxisInqVctPtr(int zaxisID)
 {
-  static const char *func = "zaxisInqVctPtr";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   return (zaxisptr->vct);
 }
@@ -1056,19 +1032,18 @@ const double *zaxisInqVctPtr(int zaxisID)
 
 void zaxisDefLbounds(int zaxisID, const double *lbounds)
 {
-  static const char *func = "zaxisDefLbounds";
   size_t size;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   size = zaxisptr->size;
   
   if ( CDI_Debug )
     if ( zaxisptr->lbounds != NULL )
-      Warning(func, "Lower bounds already defined for zaxisID = %d", zaxisID);
+      Warning("Lower bounds already defined for zaxisID = %d", zaxisID);
 
   if ( zaxisptr->lbounds == NULL )
     zaxisptr->lbounds = (double *) malloc(size*sizeof(double));
@@ -1079,19 +1054,18 @@ void zaxisDefLbounds(int zaxisID, const double *lbounds)
 
 void zaxisDefUbounds(int zaxisID, const double *ubounds)
 {
-  static const char *func = "zaxisDefUbounds";
   size_t size;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   size = zaxisptr->size;
 
   if ( CDI_Debug )
     if ( zaxisptr->ubounds != NULL )
-      Warning(func, "Upper bounds already defined for zaxisID = %d", zaxisID);
+      Warning("Upper bounds already defined for zaxisID = %d", zaxisID);
 
   if ( zaxisptr->ubounds == NULL )
     zaxisptr->ubounds = (double *) malloc(size*sizeof(double));
@@ -1102,19 +1076,18 @@ void zaxisDefUbounds(int zaxisID, const double *ubounds)
 
 void zaxisDefWeights(int zaxisID, const double *weights)
 {
-  static const char *func = "zaxisDefWeights";
   size_t size;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   size = zaxisptr->size;
 
   if ( CDI_Debug )
     if ( zaxisptr->weights != NULL )
-      Warning(func, "Weights already defined for zaxisID = %d", zaxisID);
+      Warning("Weights already defined for zaxisID = %d", zaxisID);
 
   if ( zaxisptr->weights == NULL )
     zaxisptr->weights = (double *) malloc(size*sizeof(double));
@@ -1125,16 +1098,11 @@ void zaxisDefWeights(int zaxisID, const double *weights)
 
 void zaxisChangeType(int zaxisID, int zaxistype)
 {
-  static const char *func = "zaxisChangeType";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
-
-  Message(func, "Changed zaxis type from %s to %s\n",
-	  zaxisNamePtr(zaxisptr->type),
-	  zaxisNamePtr(zaxistype));
+  zaxis_check_ptr(zaxisID, zaxisptr);
   
   zaxisptr->type = zaxistype;
 }
@@ -1142,12 +1110,11 @@ void zaxisChangeType(int zaxisID, int zaxistype)
 
 void zaxisResize(int zaxisID, int size)
 {
-  static const char *func = "zaxisResize";
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
-  zaxis_check_ptr(func, zaxisptr);
+  zaxis_check_ptr(zaxisID, zaxisptr);
 
   zaxisptr->size = size;
 
@@ -1158,14 +1125,15 @@ void zaxisResize(int zaxisID, int size)
 
 int zaxisDuplicate(int zaxisID)
 {
-  static const char *func = "zaxisDuplicate";
   int zaxisIDnew;
   int zaxistype, zaxissize;
   int size;
-  ZAXIS *zaxisptr, *zaxisptrnew;
+  zaxis_t *zaxisptr, *zaxisptrnew;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
+  zaxis_check_ptr(zaxisID, zaxisptr);
+
   zaxistype = zaxisInqType(zaxisID);
   zaxissize = zaxisInqSize(zaxisID);
 
@@ -1225,10 +1193,12 @@ void zaxisPrint(int zaxisID)
   int nlevels, levelID;
   int nbyte0, nbyte;
   double level;
-  ZAXIS *zaxisptr;
+  zaxis_t *zaxisptr;
 
   zaxisptr = zaxis_to_pointer(zaxisID);
 
+  zaxis_check_ptr(zaxisID, zaxisptr);
+
   type    = zaxisInqType(zaxisID);
   nlevels = zaxisInqSize(zaxisID);
 
@@ -1248,33 +1218,33 @@ void zaxisPrint(int zaxisID)
     {
       if ( nbyte > 80 )
 	{
-	  fprintf(stdout, "\n");
-	  fprintf(stdout, "%*s", nbyte0, "");
+	  fprintf(fp, "\n");
+	  fprintf(fp, "%*s", nbyte0, "");
 	  nbyte = nbyte0;
 	}
       level = zaxisInqLevel(zaxisID, levelID);
-      nbyte += fprintf(stdout, "%.9g ", level);
+      nbyte += fprintf(fp, "%.9g ", level);
     }
-  fprintf(stdout, "\n");
+  fprintf(fp, "\n");
 
   if ( zaxisptr->lbounds && zaxisptr->ubounds )
     {
       double level1, level2;
       nbyte = nbyte0;
-      nbyte0 = fprintf(stdout, "%32s = ", "bounds");
+      nbyte0 = fprintf(fp, "bounds    = ");
       for ( levelID = 0; levelID < nlevels; levelID++ )
 	{
 	  if ( nbyte > 80 )
 	    {
-	      fprintf(stdout, "\n");
-	      fprintf(stdout, "%*s", nbyte0, "");
+	      fprintf(fp, "\n");
+	      fprintf(fp, "%*s", nbyte0, "");
 	      nbyte = nbyte0;
 	    }
 	  level1 = zaxisInqLbound(zaxisID, levelID);
 	  level2 = zaxisInqUbound(zaxisID, levelID);
-	  nbyte += fprintf(stdout, "%.9g-%.9g ", level1, level2);
+	  nbyte += fprintf(fp, "%.9g-%.9g ", level1, level2);
 	}
-      fprintf(stdout, "\n");
+      fprintf(fp, "\n");
     }
 
   if ( type == ZAXIS_HYBRID || type == ZAXIS_HYBRID_HALF )
@@ -1285,34 +1255,34 @@ void zaxisPrint(int zaxisID)
 
       vctsize = zaxisInqVctSize(zaxisID);
       vct     = zaxisInqVctPtr(zaxisID);
-      fprintf(stdout, "vctsize   = %d\n", vctsize);
+      fprintf(fp, "vctsize   = %d\n", vctsize);
       if ( vctsize )
 	{
-	  nbyte0 = fprintf(stdout, "vct       = ");
+	  nbyte0 = fprintf(fp, "vct       = ");
 	  nbyte = nbyte0;
 	  for ( i = 0; i < vctsize; i++ )
 	    {
 	      if ( nbyte > 70 || i == vctsize/2 )
 		{
-		  fprintf(stdout, "\n%*s", nbyte0, "");
+		  fprintf(fp, "\n%*s", nbyte0, "");
 		  nbyte = nbyte0;
 		}
-	      nbyte += fprintf(stdout, "%.9g ", vct[i]);
+	      nbyte += fprintf(fp, "%.9g ", vct[i]);
 	    }
-	  fprintf(stdout, "\n");
+	  fprintf(fp, "\n");
 	  /*
-	  nbyte0 = fprintf(stdout, "vct_b     = ");
+	  nbyte0 = fprintf(fp, "vct_b     = ");
 	  nbyte  = nbyte0;
 	  for ( i = 0; i < vctsize/2; i++ )
 	    {
 	      if ( nbyte > 70 )
 		{
-		  fprintf(stdout, "\n%*s", nbyte0, "");
+		  fprintf(fp, "\n%*s", nbyte0, "");
 		  nbyte = nbyte0;
 		}
-	      nbyte += fprintf(stdout, "%.9g ", vct[vctsize/2+i]);
+	      nbyte += fprintf(fp, "%.9g ", vct[vctsize/2+i]);
 	    }
-	  fprintf(stdout, "\n");
+	  fprintf(fp, "\n");
 	  */
 	}
     }
