@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2008 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -21,30 +21,26 @@
       Copy       cat             Concatenate datasets
 */
 
-#if  defined  (HAVE_CONFIG_H)
-#  include "config.h" /* large file */
-#endif
-
 #include <cdi.h>
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
+#include "util.h"
 
 void    vlistDefVarTime(int vlistID, int varID, int timeID);
 
 void *Cat(void *argument)
 {
-  static const char *func = "Cat";
   int streamID1, streamID2 = CDI_UNDEFID;
   int nrecs;
   int tsID1, tsID2 = 0, recID, varID, levelID;
-  int vlistID1, vlistID2;
+  int vlistID1, vlistID2 = CDI_UNDEFID;
   int streamCnt, nfiles, indf;
   int taxisID1, taxisID2 = CDI_UNDEFID;
   int lcopy = FALSE;
   int gridsize;
   int nmiss;
-  int ntsteps;
+  int ntsteps, nvars;
   double *array = NULL;
 
   cdoInitialize(argument);
@@ -66,17 +62,7 @@ void *Cat(void *argument)
 
       if ( indf == 0 )
 	{
-	  int fileExist = FALSE;
-	  FILE *fp;
-
-	  fp = fopen(cdoStreamName(nfiles), "r");
-	  if ( fp )
-	    {
-	      fclose(fp);
-	      fileExist = TRUE;
-	    }
-
-	  if ( fileExist )
+	  if ( fileExist(cdoStreamName(nfiles)) )
 	    {
 	      streamID2 = streamOpenAppend(cdoStreamName(nfiles));
 	      if ( streamID2 < 0 )
@@ -88,7 +74,7 @@ void *Cat(void *argument)
 	      vlistCompare(vlistID1, vlistID2, CMP_SFT);
 
 	      tsID2 = vlistNtsteps(vlistID2);
-	      if ( tsID2 == 0 ) tsID2 = 1; /* bug fix for constant data only */
+	      if ( tsID2 == 0 ) tsID2 = 1; /* bug fix for time constant data only */
 	    }
 	  else
 	    {
@@ -104,10 +90,18 @@ void *Cat(void *argument)
 	      vlistDefTaxis(vlistID2, taxisID2);
 	  
 	      ntsteps = vlistNtsteps(vlistID1);
-	      if ( ntsteps == 0 && nfiles > 1 )
+	      nvars   = vlistNvars(vlistID1);
+	      
+	      if ( ntsteps == 1 )
 		{
-		  int nvars = vlistNvars(vlistID1);
+		  for ( varID = 0; varID < nvars; ++varID )
+		    if ( vlistInqVarTime(vlistID1, varID) == TIME_VARIABLE ) break;
 		  
+		  if ( varID == nvars ) ntsteps = 0;
+		}
+
+	      if ( ntsteps == 0 && nfiles > 1 )
+		{		  
 		  for ( varID = 0; varID < nvars; ++varID )
 		    vlistDefVarTime(vlistID2, varID, TIME_VARIABLE);
 		}
@@ -121,6 +115,10 @@ void *Cat(void *argument)
 	      array = (double *) malloc(gridsize*sizeof(double));
 	    }
 	}
+      else
+	{
+	  vlistCompare(vlistID1, vlistID2, CMP_SFT);
+	}
 
       tsID1 = 0;
       while ( (nrecs = streamInqTimestep(streamID1, tsID1)) )
