@@ -94,7 +94,7 @@ int com_help(char *arg)
 
   if ( !printed )
     {
-      printf ("No commands match %s. Possibilties are:\n", arg);
+      printf ("No commands match '%s'. Possibilties are:\n", arg);
       for (i = 0; commands[i].name; i++)
 	{
 	  /* Print in six columns. */
@@ -268,7 +268,6 @@ void readcmd(const char *prompt, char *line, int size)
 
 void *Command(void *argument)
 {
-  static const char *func = "Command";
   int nrecs;
   int recID, varID, levelID;
   int gridsize;
