@@ -25,11 +25,12 @@
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
+#include "grid.h"
 
 
-static void gen_index(int gridID1, int gridID2, int *index)
+static
+void gen_index(int gridID1, int gridID2, int *index)
 {
-  static const char *func = "gen_index";
   int nlat1, nlon1;
   int nlat2, nlon2;
   int gridtype1, gridtype2;
@@ -80,9 +81,27 @@ static void gen_index(int gridID1, int gridID2, int *index)
       gridInqXvals(gridID1, xvals1);
       gridInqYvals(gridID1, yvals1);
 
+      /* Convert lat/lon units if required */
+      {
+	char units[128];
+	gridInqXunits(gridID1, units);
+	gridToDegree(units, "grid1 center lon", nlon1, xvals1);
+	gridInqYunits(gridID1, units);
+	gridToDegree(units, "grid1 center lat", nlat1, yvals1);
+      }
+
       gridInqXvals(gridID2, xvals2);
       gridInqYvals(gridID2, yvals2);
 
+      /* Convert lat/lon units if required */
+      {
+	char units[128];
+	gridInqXunits(gridID2, units);
+	gridToDegree(units, "grid2 center lon", nlon2, xvals2);
+	gridInqYunits(gridID2, units);
+	gridToDegree(units, "grid2 center lat", nlat2, yvals2);
+      }
+
       for ( i2 = 0; i2 < nlat2; i2++ )
 	{
 	  for ( i1 = 0; i1 < nlat1; i1++ )
@@ -150,7 +169,6 @@ static void gen_index(int gridID1, int gridID2, int *index)
 
 void *Enlargegrid(void *argument)
 {
-  static const char *func = "Enlargegrid";
   int varID;
   int nrecs = 0;
   int tsID, recID, levelID;
