@@ -33,8 +33,7 @@ void    vlistDefVarTime(int vlistID, int varID, int timeID);
 
 void *Eofcoeff(void * argument)
 {
-  static const char *func = "Eofcoeff";
-  char eof_name[5], oname[1024], filesuffix[32];
+  char eof_name[8], oname[1024], filesuffix[32];
   double *w;
   double missval1=-999, missval2;
   double *xvals, *yvals;  
@@ -101,14 +100,7 @@ void *Eofcoeff(void * argument)
   nchars = strlen(oname);
   
   filesuffix[0] = 0;
-  if ( cdoDisableFilesuffix == FALSE )
-    {
-      strcat(filesuffix, streamFilesuffix(cdoDefaultFileType));
-      if ( cdoDefaultFileType == FILETYPE_GRB )
-        if ( vlistIsSzipped(vlistID1) || cdoZtype == COMPRESS_SZIP )
-          strcat(filesuffix, ".sz");
-    }
- 
+  cdoGenFileSuffix(filesuffix, sizeof(filesuffix), cdoDefaultFileType, vlistID1);
   
   eof = (field_t ***) malloc (nvars * sizeof(field_t**) );
   for ( varID=0; varID<nvars; varID++)
