@@ -57,9 +57,9 @@ double corr(double * restrict in0, double * restrict in1,
     }
 
   out = wsum0 ?
-        FDIV((sum01 * wsum0 - sum0 * sum1),
-	     FSQRT((sum00 * wsum0 - sum0 * sum0) *
-		   (sum11 * wsum0 - sum1 * sum1))) : missval;
+        DIV((sum01 * wsum0 - sum0 * sum1),
+	     SQRT((sum00 * wsum0 - sum0 * sum0) *
+	          (sum11 * wsum0 - sum1 * sum1))) : missval;
 
   return (out);
 }
@@ -67,7 +67,6 @@ double corr(double * restrict in0, double * restrict in1,
 
 void *Fldstat2(void *argument)
 {
-  static const char *func = "Fldstat2";
   int operatorID;
   int operfunc;
   int streamID1, streamID2, streamID3;
