@@ -36,12 +36,12 @@
 #include "cdo_int.h"
 #include "pstream.h"
 #include "functs.h"
+#include "grid.h"
 
 
 static
 int genBoxGrid(int gridID1, int xinc, int yinc)
 {
-  static const char *func = "genBoxGrid";
   int i, j, i1;
   int gridID2 = -1, gridtype;
   int gridsize1 = 0, nlon1 = 0, nlat1 = 0;
@@ -180,6 +180,15 @@ int genBoxGrid(int gridID1, int xinc, int yinc)
       yvals2 = (double *) malloc(nlon2*nlat2*sizeof(double));
       gridInqXvals(gridID1, xvals1);
       gridInqYvals(gridID1, yvals1);
+
+      /* Convert lat/lon units if required */
+      {
+	char units[128];
+	gridInqXunits(gridID1, units);
+	gridToDegree(units, "grid center lon", nlon1*nlat1, xvals1);
+	gridInqYunits(gridID1, units);
+	gridToDegree(units, "grid center lat", nlon1*nlat1, yvals1);
+      }
       
       if ( gridHasBounds )
         {
@@ -189,6 +198,15 @@ int genBoxGrid(int gridID1, int xinc, int yinc)
           grid2_corner_lat = (double *) malloc(4*nlon2*nlat2*sizeof(double));
           gridInqXbounds(gridID1, grid1_corner_lon);
           gridInqYbounds(gridID1, grid1_corner_lat);
+
+	  /* Convert lat/lon units if required */
+	  {
+	    char units[128];
+	    gridInqXunits(gridID1, units);
+	    gridToDegree(units, "grid corner lon", 4*nlon1*nlat1, grid1_corner_lon);
+	    gridInqYunits(gridID1, units);
+	    gridToDegree(units, "grid corner lat", 4*nlon1*nlat1, grid1_corner_lat);
+	  }
         }
       
       /* Process grid2 bounds */
@@ -327,7 +345,7 @@ int genBoxGrid(int gridID1, int xinc, int yinc)
                                           if ((IS_EQUAL(lon2, lon) && IS_EQUAL(lat2, lat))  ||
                                               (IS_EQUAL(lon3, lon) && IS_EQUAL(lat3, lat)) )
                                             c_flag[corner] = 1;
-                                        }                                                                                                                                                                      
+                                        }
                                     }
                                   for ( corner = 0; corner<4; corner++ )
                                     if ( !c_flag[corner] ) break;                                 
@@ -503,7 +521,6 @@ int genBoxGrid(int gridID1, int xinc, int yinc)
 static
 void gridboxstat(field_t *field1, field_t *field2, int xinc, int yinc, int statfunc)
 {
-  static const char *func = "gridboxstat";
   int nlon1, nlat1;
   int nlon2, nlat2;
   int ilat, ilon;
@@ -599,7 +616,6 @@ void gridboxstat(field_t *field1, field_t *field2, int xinc, int yinc, int statf
 
 void *Gridboxstat(void *argument)
 {
-  static const char *func = "Gridboxstat";
   int operatorID;
   int operfunc;
   int streamID1, streamID2;
