@@ -27,7 +27,6 @@ void init_vars(int vlistID, int gridID, int zaxisID, int nvars)
     }
 }
 
-
 static
 void init_data(int vlistID, int nvars, double *data[])
 {
@@ -46,7 +45,6 @@ void init_data(int vlistID, int nvars, double *data[])
     } 
 }
 
-
 static
 void write_data(int streamID, int vlistID, int nvars, double *data[])
 {
@@ -71,7 +69,6 @@ void write_data(int streamID, int vlistID, int nvars, double *data[])
     }
 }
 
-
 static
 int getDate(const char *name)
 {
@@ -92,7 +89,6 @@ int getDate(const char *name)
 
 void *Importobs(void *argument)
 {
-  static const char *func = "Importobs";
   int operatorID;
   char line[MAX_LINE_LEN];
   int streamID;
@@ -139,6 +135,15 @@ void *Importobs(void *argument)
   gridInqXvals(gridID, xvals);
   gridInqYvals(gridID, yvals);
 
+  /* Convert lat/lon units if required */
+  {
+    char units[128];
+    gridInqXunits(gridID, units);
+    gridToDegree(units, "grid center lon", gridsize, xvals);
+    gridInqYunits(gridID, units);
+    gridToDegree(units, "grid center lat", gridsize, yvals);
+  }
+
   fp = fopen(cdoStreamName(0), "r");
   if ( fp == NULL ) { perror(cdoStreamName(0)); exit(EXIT_FAILURE); }
 
