@@ -30,8 +30,9 @@
 #include "list.h"
 
 
-static void interp_lev(int gridsize, double missval, double *vardata1, double *vardata2,
-		       int nlev2, int *lev_idx1, int *lev_idx2, double *lev_wgt1, double *lev_wgt2)
+static
+void interp_lev(int gridsize, double missval, double *vardata1, double *vardata2,
+		int nlev2, int *lev_idx1, int *lev_idx2, double *lev_wgt1, double *lev_wgt2)
 {
   int i, ilev;
   int idx1, idx2;
@@ -85,8 +86,9 @@ static void interp_lev(int gridsize, double missval, double *vardata1, double *v
 }
 
 
-static void gen_weights(int expol, int nlev1, double *lev1, int nlev2, double *lev2,
-			int *lev_idx1, int *lev_idx2, double *lev_wgt1, double *lev_wgt2)
+static
+void gen_weights(int expol, int nlev1, double *lev1, int nlev2, double *lev2,
+		 int *lev_idx1, int *lev_idx2, double *lev_wgt1, double *lev_wgt2)
 {
   int i1, i2;
   double val1, val2 = 0;
@@ -156,7 +158,6 @@ static void gen_weights(int expol, int nlev1, double *lev1, int nlev2, double *l
 
 void *Intlevel(void *argument)
 {
-  static const char *func = "Intlevel";
   int INTLEVEL, INTLEVELX;
   int operatorID;
   int streamID1, streamID2;
