@@ -33,7 +33,6 @@
 
 void *Intyear(void *argument)
 {
-  static const char *func = "Intyear";
   int streamID1, streamID2;
   int nrecs;
   int i, iy;
@@ -97,13 +96,7 @@ void *Intyear(void *argument)
   nchars = strlen(filename);
 
   filesuffix[0] = 0;
-  if ( cdoDisableFilesuffix == FALSE )
-    {
-      strcat(filesuffix, streamFilesuffix(cdoDefaultFileType));
-      if ( cdoDefaultFileType == FILETYPE_GRB )
-	if ( vlistIsSzipped(vlistID1) || cdoZtype == COMPRESS_SZIP )
-	  strcat(filesuffix, ".sz");
-    }
+  cdoGenFileSuffix(filesuffix, sizeof(filesuffix), cdoDefaultFileType, vlistID1);
 
   for ( iy = 0; iy < nyears; iy++ )
     {
