@@ -29,10 +29,12 @@
 #include "cdo.h"
 #include "cdo_int.h"
 #include "pstream.h"
+#include "grid.h"
 
 #define MAX_LINE 256
 #define MAX_VALS 1048576
 
+static
 int ReadCoords(double *xvals, double *yvals, const char *polyfile, FILE *fp)
 {
   double xcoord, ycoord;
@@ -114,7 +116,6 @@ void genlonlatbox(double xlon1, double xlon2, double xlat1, double xlat2,
 static
 void genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int *lon21, int *lon22)
 {
-  static const char *func = "genlonlatgrid";  
   int nlon1, nlat1;
   double *xvals1, *yvals1;
   double xlon1, xlon2, xlat1, xlat2;
@@ -135,6 +136,15 @@ void genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, in
   gridInqXvals(gridID1, xvals1);
   gridInqYvals(gridID1, yvals1);
 
+  /* Convert lat/lon units if required */
+  {
+    char units[128];
+    gridInqXunits(gridID1, units);
+    gridToDegree(units, "grid center lon", nlon1, xvals1);
+    gridInqYunits(gridID1, units);
+    gridToDegree(units, "grid center lat", nlat1, yvals1);
+  }
+
   genlonlatbox(xlon1, xlon2, xlat1, xlat2,
 	       nlon1, nlat1, xvals1, yvals1,
 	       lat1, lat2, lon11, lon12, lon21, lon22);
@@ -144,7 +154,8 @@ void genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, in
 }
 
 
-static void genindexbox(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int *lon21, int *lon22)
+static
+void genindexbox(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int *lon21, int *lon22)
 {
   int nlon1, nlat1;
   int temp;
@@ -216,8 +227,9 @@ static void genindexbox(int gridID1, int *lat1, int *lat2, int *lon11, int *lon1
 }
 
 
-static void maskbox(int *mask, int gridID,
-		   int lat1, int lat2, int lon11, int lon12, int lon21, int lon22)
+static
+void maskbox(int *mask, int gridID,
+	     int lat1, int lat2, int lon11, int lon12, int lon21, int lon22)
 {
   int nlon, nlat;
   int ilat, ilon;
@@ -232,10 +244,9 @@ static void maskbox(int *mask, int gridID,
 	mask[nlon*ilat + ilon] = 0;
 }
 
-
-static void maskregion(int *mask, int gridID, double *xcoords, double *ycoords, int nofcoords)
+static
+void maskregion(int *mask, int gridID, double *xcoords, double *ycoords, int nofcoords)
 {
-  static const char *func = "maskregion";
   int i, j;
   int nlon, nlat;
   int ilat, ilon;
@@ -253,17 +264,30 @@ static void maskregion(int *mask, int gridID, double *xcoords, double *ycoords,
   gridInqXvals(gridID, xvals);
   gridInqYvals(gridID, yvals);  
 
+  /* Convert lat/lon units if required */
+  {
+    char units[128];
+    gridInqXunits(gridID, units);
+    gridToDegree(units, "grid center lon", nlon, xvals);
+    gridInqYunits(gridID, units);
+    gridToDegree(units, "grid center lat", nlat, yvals);
+  }
+
   xmin = xvals[0];
-  ymin = yvals[0];
   xmax = xvals[0];
+  ymin = yvals[0];
   ymax = yvals[0];
 
-  for ( i = 0; i < nofcoords; i++)
+  for ( i = 1; i < nlon; i++ )
     {
-      if(xvals[i] < xmin) xmin = xvals[i];
-      if(yvals[i] < ymin) ymin = yvals[i];
-      if(xvals[i] > xmax) xmax = xvals[i];
-      if(yvals[i] > ymax) ymax = yvals[i];
+      if ( xvals[i] < xmin ) xmin = xvals[i];
+      if ( xvals[i] > xmax ) xmax = xvals[i];
+    }
+
+  for ( i = 1; i < nlat; i++ )
+    {
+      if ( yvals[i] < ymin ) ymin = yvals[i];
+      if ( yvals[i] > ymax ) ymax = yvals[i];
     }
 
   for ( ilat = 0; ilat < nlat; ilat++ )
@@ -273,10 +297,9 @@ static void maskregion(int *mask, int gridID, double *xcoords, double *ycoords,
 	{
           c = 0;
 	  xval = xvals[ilon];
-	  if(!( ( ( xval > xmin ) || ( xval < xmax ) ) || ( (yval > ymin) || (yval < ymax) ) ) ) c = !c;
-	  
-	  
-          if ( c == 0)
+	  if (!( ( ( xval > xmin ) || ( xval < xmax ) ) || ( (yval > ymin) || (yval < ymax) ) ) ) c = !c;
+	  	  
+          if ( c == 0 )
 	    {
 	      for (i = 0, j = nofcoords-1; i < nofcoords; j = i++)
 	    
@@ -292,10 +315,10 @@ static void maskregion(int *mask, int gridID, double *xcoords, double *ycoords,
 		{
 		  if ( xvals[ilon] > 180 )
 		    {
-                         if ((((ycoords[i]<=yval) && (yval<ycoords[j])) ||
-	                      ((ycoords[j]<=yval) && (yval<ycoords[i]))) &&
-		              ((xval-360) < (xcoords[j] - (xcoords[i])) * (yval - ycoords[i]) / (ycoords[j] - ycoords[i]) +(xcoords[i])))
-			   c = !c;
+		      if ((((ycoords[i]<=yval) && (yval<ycoords[j])) ||
+			   ((ycoords[j]<=yval) && (yval<ycoords[i]))) &&
+			  ((xval-360) < (xcoords[j] - (xcoords[i])) * (yval - ycoords[i]) / (ycoords[j] - ycoords[i]) +(xcoords[i])))
+			c = !c;
 		    }
 		}
 	    }
@@ -320,13 +343,11 @@ static void maskregion(int *mask, int gridID, double *xcoords, double *ycoords,
       
   free(xvals);
   free(yvals);
-
 }
 
 
 void *Maskbox(void *argument)
 {
-  static const char *func = "Maskbox";
   int MASKLONLATBOX, MASKINDEXBOX, MASKREGION;
   int operatorID;
   int streamID1, streamID2;
