@@ -193,7 +193,6 @@ void p_to_uv_grid(int nlon, int nlat, double *grid1x, double *grid1y,
 
 void *Mrotuv(void *argument)
 {
-  static const char *func = "Mrotuv";
   int streamID1, streamID2, streamID3;
   int nrecs;
   int tsID, recID, levelID;
@@ -275,6 +274,15 @@ void *Mrotuv(void *argument)
   gridInqXvals(gridID1, grid1x);
   gridInqYvals(gridID1, grid1y);
 
+  /* Convert lat/lon units if required */
+  {
+    char units[128];
+    gridInqXunits(gridID1, units);
+    gridToDegree(units, "grid center lon", gridsize, grid1x);
+    gridInqYunits(gridID1, units);
+    gridToDegree(units, "grid center lat", gridsize, grid1y);
+  }
+
   p_to_uv_grid(nlon, nlat, grid1x, grid1y, gridux, griduy, gridvx, gridvy);
 
   gridIDu = gridCreate(GRID_CURVILINEAR, nlon*nlat);
