@@ -155,7 +155,6 @@ static
 void uv_to_p_grid(int nlon, int nlat, double *grid1x, double *grid1y, 
 		  double *grid2x, double *grid2y, double *grid3x, double *grid3y)
 {
-  static const char *func = "uv_to_p_grid";
   int gridsizex;
   int i, j;
   double gx, gy;
@@ -261,7 +260,6 @@ void uv_to_p_grid(int nlon, int nlat, double *grid1x, double *grid1y,
 
 void *Mrotuvb(void *argument)
 {
-  static const char *func = "Mrotuvb";
   int streamID1, streamID2, streamID3;
   int nrecs, nrecs2;
   int tsID, recID, levelID;
@@ -332,9 +330,27 @@ void *Mrotuvb(void *argument)
   gridInqXvals(gridID1, grid1x);
   gridInqYvals(gridID1, grid1y);
 
+  /* Convert lat/lon units if required */
+  {
+    char units[128];
+    gridInqXunits(gridID1, units);
+    gridToDegree(units, "grid1 center lon", gridsize, grid1x);
+    gridInqYunits(gridID1, units);
+    gridToDegree(units, "grid1 center lat", gridsize, grid1y);
+  }
+
   gridInqXvals(gridID2, grid2x);
   gridInqYvals(gridID2, grid2y);
 
+  /* Convert lat/lon units if required */
+  {
+    char units[128];
+    gridInqXunits(gridID2, units);
+    gridToDegree(units, "grid2 center lon", gridsize, grid2x);
+    gridInqYunits(gridID2, units);
+    gridToDegree(units, "grid2 center lat", gridsize, grid2y);
+  }
+
   uv_to_p_grid(nlon, nlat, grid1x, grid1y, grid2x, grid2y, grid3x, grid3y);
 
   if ( grid1x ) free(grid1x);
