@@ -33,8 +33,7 @@
 static
 void rot_uv_back(int gridID, double *us, double *vs)
 {
-  static const char *func = "rot_uv_back";
-  int i, ilat, ilon, nlat, nlon;
+  long i, ilat, ilon, nlat, nlon;
   double u, v;
   double xval, yval;
   double xpole, ypole, angle;
@@ -53,6 +52,17 @@ void rot_uv_back(int gridID, double *us, double *vs)
   gridInqXvals(gridID, xvals);
   gridInqYvals(gridID, yvals);
 
+  /* Convert lat/lon units if required */
+  {
+    char units[128];
+    gridInqXunits(gridID, units);
+    gridToDegree(units, "xpole", 1, &xpole);
+    gridToDegree(units, "grid center lon", nlon, xvals);
+    gridInqYunits(gridID, units);
+    gridToDegree(units, "ypole", 1, &ypole);
+    gridToDegree(units, "grid center lat", nlat, yvals);
+  }
+
   for ( ilat = 0; ilat < nlat; ilat++ )
     for ( ilon = 0; ilon < nlon; ilon++ )
       {
@@ -79,7 +89,6 @@ void rot_uv_back(int gridID, double *us, double *vs)
 
 void *Rotuv(void *argument)
 {
-  static const char *func = "Rotuv";
   int streamID1, streamID2;
   int nrecs;
   int tsID, recID, varID, levelID;
