@@ -77,7 +77,6 @@ void datetime_avg(int calendar, int ndates, datetime_t *datetime)
 
 void *Runstat(void *argument)
 {
-  static const char *func = "Runstat";
   int operatorID;
   int operfunc;
   int gridsize;
@@ -324,20 +323,21 @@ void *Runstat(void *argument)
 
       taxisDefVdate(taxisID2, datetime[ndates].date);
       taxisDefVtime(taxisID2, datetime[ndates].time);
-      streamDefTimestep(streamID2, otsID++);
+      streamDefTimestep(streamID2, otsID);
 
       for ( recID = 0; recID < nrecords; recID++ )
 	{
 	  varID    = recVarID[recID];
 	  levelID  = recLevelID[recID];
 
-	  if ( otsID == 1 || vlistInqVarTime(vlistID1, varID) == TIME_VARIABLE )
-	    {
-	      streamDefRecord(streamID2, varID, levelID);
-	      streamWriteRecord(streamID2, vars1[0][varID][levelID].ptr, vars1[0][varID][levelID].nmiss);
-	    }
+	  if ( otsID && vlistInqVarTime(vlistID1, varID) == TIME_CONSTANT ) continue;
+
+	  streamDefRecord(streamID2, varID, levelID);
+	  streamWriteRecord(streamID2, vars1[0][varID][levelID].ptr, vars1[0][varID][levelID].nmiss);
 	}
 
+      otsID++;
+
       datetime[ndates] = datetime[0];
       vars1[ndates] = vars1[0];
       samp1[ndates] = samp1[0];
