@@ -24,7 +24,6 @@ static
 void genGrids(int gridID1, int *gridIDs, int nxvals, int nyvals, int nsx, int nsy,
 	      int **gridindex, int nsplit, int gridsize2)
 {
-  static char *func = "genGrids";
   int gridID2;
   int gridtype;
   int gridsize, nx, ny;
@@ -100,7 +99,6 @@ typedef struct
 
 void *Scatter(void *argument)
 {
-  static const char *func = "Scatter";
   int nchars;
   int streamID1;
   int *vlistIDs = NULL, *streamIDs = NULL;
@@ -200,14 +198,7 @@ void *Scatter(void *argument)
   nchars = strlen(filename);
 
   filesuffix[0] = 0;
-  if ( cdoDisableFilesuffix == FALSE )
-    {
-      strcat(filesuffix, streamFilesuffix(cdoDefaultFileType));
-      if ( cdoDefaultFileType == FILETYPE_GRB )
-	if ( vlistIsSzipped(vlistID1) || cdoZtype == COMPRESS_SZIP )
-	  strcat(filesuffix, ".sz");
-    }
-
+  cdoGenFileSuffix(filesuffix, sizeof(filesuffix), cdoDefaultFileType, vlistID1);
 
   for ( index = 0; index < nsplit; index++ )
     {
