@@ -31,7 +31,6 @@
 static
 int gengrid(int gridID1, int lat1, int lat2, int lon11, int lon12, int lon21, int lon22)
 {
-  static const char *func = "gengrid";  
   int gridtype, gridID2;
   int nlon1, nlat1;
   int nlon2, nlat2;
@@ -227,7 +226,6 @@ int gengrid(int gridID1, int lat1, int lat2, int lon11, int lon12, int lon21, in
 static
 int gengridcell(int gridID1, int gridsize2, int *cellidx)
 {
-  static const char *func = "gengridcell";  
   int gridtype, gridID2;
   int gridsize1;
   int i, k, nv;
@@ -341,12 +339,13 @@ void genlonlatbox(double xlon1, double xlon2, double xlat1, double xlat2,
     {
       xlon2 += 0.00001;
     }
+
   xlon2 -= 360 * floor ((xlon1 - xvals1[0]) / 360);
   xlon1 -= 360 * floor ((xlon1 - xvals1[0]) / 360);
-  
+
   for ( *lon21 = 0; *lon21 < nlon1 && xvals1[*lon21] < xlon1; (*lon21)++ );
   for ( *lon22 = *lon21; *lon22 < nlon1 && xvals1[*lon22] < xlon2; (*lon22)++ );
-  
+
   if ( *lon22 >= nlon1 || xvals1[*lon22] > xlon2 ) (*lon22)--;
       
   xlon1 -= 360;
@@ -354,8 +353,9 @@ void genlonlatbox(double xlon1, double xlon2, double xlat1, double xlat2,
 
   for ( *lon11 = 0; xvals1[*lon11] < xlon1; (*lon11)++ );
   for ( *lon12 = *lon11; *lon12 < nlon1 && xvals1[*lon12] < xlon2; (*lon12)++ );
-
-  (*lon12)--;
+  
+  //(*lon12)--;
+  if ( *lon12 >= nlon1 || xvals1[*lon12] > xlon2 ) (*lon12)--;
   
   if ( *lon12 - *lon11 + 1 + *lon22 - *lon21 + 1 <= 0 )
     cdoAbort("Longitudinal dimension is too small!");
@@ -391,11 +391,9 @@ void genlonlatbox(double xlon1, double xlon2, double xlat1, double xlat2,
     cdoAbort("Latitudinal dimension is too small!");
 }
 
-
 static
 int genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int *lon21, int *lon22)
 {
-  static const char *func = "genlonlatgrid";  
   int ilon, ilat;
   int nlon1, nlat1;
   int gridtype, gridID2;
@@ -404,7 +402,7 @@ int genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int
   int grid_is_circular;
   char xunits[128];
   char yunits[128];
-  double xfact, yfact;
+  double xfact = 1, yfact = 1;
 
   operatorCheckArgc(4);
 
@@ -437,15 +435,8 @@ int genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int
   gridInqXunits(gridID1, xunits);
   gridInqYunits(gridID1, yunits);
 
-  if ( memcmp(xunits, "radian", 6) == 0 )
-    xfact = RAD2DEG;
-  else
-    xfact = 1;
-
-  if ( memcmp(yunits, "radian", 6) == 0 )
-    yfact = RAD2DEG;
-  else
-    yfact = 1;
+  if ( memcmp(xunits, "radian", 6) == 0 ) xfact = RAD2DEG;
+  if ( memcmp(yunits, "radian", 6) == 0 ) yfact = RAD2DEG;
 
   if ( gridtype == GRID_CURVILINEAR )
     {
@@ -455,9 +446,14 @@ int genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int
 
       if ( xlon1 > xlon2 ) 
 	cdoAbort("The second longitude have to be greater than the first one!");
-      if ( xlat1 > xlat2 )
-	cdoAbort("The second latitude have to be greater than the first one!");
 
+      if ( xlat1 > xlat2 )
+	{
+	  double xtemp = xlat1;
+	  xlat1 = xlat2;
+	  xlat2 = xtemp;
+	}
+	  
       *lat1 = nlat1-1;
       *lat2 = 0;
       *lon11 = 0;
@@ -564,7 +560,6 @@ int genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int
 static
 int gencellgrid(int gridID1, int *gridsize2, int **cellidx)
 {
-  static const char *func = "gencellgrid";  
   int gridtype, gridID2;
   double *xvals1, *yvals1;
   double xlon1, xlon2, xlat1, xlat2, x, xval, yval;
@@ -752,7 +747,6 @@ void window_cell(double *array1, int gridID1, double *array2, int gridsize2, int
 
 void *Selbox(void *argument)
 {
-  static const char *func = "Selbox";
   int SELLONLATBOX, SELINDEXBOX;
   int operatorID;
   int streamID1, streamID2;
@@ -772,8 +766,8 @@ void *Selbox(void *argument)
     int gridID1, gridID2;
     int *cellidx, nvals;
     int lat1, lat2, lon11, lon12, lon21, lon22; 
-  } SBOX;
-  SBOX *sbox = NULL;
+  } sbox_t;
+  sbox_t *sbox = NULL;
 
   cdoInitialize(argument);
 
@@ -799,7 +793,7 @@ void *Selbox(void *argument)
   for ( varID = 0; varID < nvars; varID++ ) vars[varID] = FALSE;
 
   ngrids = vlistNgrids(vlistID1);
-  sbox = (SBOX *) malloc(ngrids*sizeof(SBOX));
+  sbox = (sbox_t *) malloc(ngrids*sizeof(sbox_t));
 
   for ( index = 0; index < ngrids; index++ )
     {
