@@ -124,7 +124,6 @@ typedef struct
 static
 void pml_init(pml_t *pml, const char *name)
 {
-  static const char *func = "pml_init";
   pml->size = 0;
   pml->dis  = 1;
   pml->name = strdup(name);
@@ -133,7 +132,6 @@ void pml_init(pml_t *pml, const char *name)
 
 pml_t *pmlNew(const char *name)
 {
-  static const char *func = "pmlNew";
   pml_t *pml;
 
   pml = (pml_t *) malloc(sizeof(pml_t));
@@ -180,7 +178,6 @@ void pmlPrint(pml_t *pml)
 
 int pmlAdd(pml_t *pml, const char *name, int type, int dis, void *ptr, size_t size)
 {
-  static const char *func = "pmlAdd";
   pml_entry_t *pml_entry;
   int entry = 0;
 
@@ -233,7 +230,6 @@ int pmlNum(pml_t *pml, const char *name)
 
 int pml_add_entry(pml_entry_t *entry, char *arg)
 {
-  static const char *func = "pml_add_entry";
   int status = 0;
 
   if ( entry->type == PML_INT )
@@ -287,7 +283,6 @@ void pmlProcess(pml_entry_t *entry, int argc, char **argv)
 
 int pmlRead(pml_t *pml, int argc, char **argv)
 {
-  static const char *func = "pmlRead";
   pml_entry_t *entry = NULL;
   pml_entry_t *pentry[MAX_PML_ENTRY];
   int params[MAX_PML_ENTRY];
@@ -442,7 +437,6 @@ void par_check_word_flag(int npar, char **parlist, int *flaglist, const char *tx
 
 void *Select(void *argument)
 {
-  const char func[] = "Select";
   int SELECT;
   int operatorID;
   int streamID1, streamID2 = CDI_UNDEFID;
@@ -470,11 +464,13 @@ void *Select(void *argument)
   int *vars = NULL;
   pml_t *pml;
   PML_DEF_INT(code,    1024, "Code number");
+  PML_DEF_INT(ltype,   1024, "Level type");
   PML_DEF_FLT(level,   1024, "Level");
   PML_DEF_WORD(name,   1024, "Variable name");
   PML_DEF_WORD(param,  1024, "Parameter");
 
   PML_INIT_INT(code);
+  PML_INIT_INT(ltype);
   PML_INIT_FLT(level);
   PML_INIT_WORD(name);
   PML_INIT_WORD(param);
@@ -499,6 +495,7 @@ void *Select(void *argument)
   pml = pmlNew("SELECT");
 
   PML_ADD_INT(pml, code);
+  PML_ADD_INT(pml, ltype);
   PML_ADD_FLT(pml, level);
   PML_ADD_WORD(pml, name);
   PML_ADD_WORD(pml, param);
@@ -508,6 +505,7 @@ void *Select(void *argument)
   if ( cdoVerbose ) pmlPrint(pml);
 
   PML_NUM(pml, code);
+  PML_NUM(pml, ltype);
   PML_NUM(pml, level);
   PML_NUM(pml, name);
   PML_NUM(pml, param);
@@ -547,11 +545,23 @@ void *Select(void *argument)
 	      name  = varname;
 	      param = paramstr;
 
+	      zaxisID = vlistInqVarZaxis(vlistID1, varID);
+	      ltype   = zaxis2ltype(zaxisID);
+
 	      vars[varID] = FALSE;
 	      
-	      if ( npar_code  && PAR_CHECK_INT(code) )   vars[varID] = TRUE;
-	      if ( npar_name  && PAR_CHECK_WORD(name) )  vars[varID] = TRUE;
-	      if ( npar_param && PAR_CHECK_WORD(param) ) vars[varID] = TRUE;
+	      if ( npar_ltype )
+		{
+		  if ( npar_code  && PAR_CHECK_INT(ltype) && PAR_CHECK_INT(code) )   vars[varID] = TRUE;
+		  if ( npar_name  && PAR_CHECK_INT(ltype) && PAR_CHECK_WORD(name) )  vars[varID] = TRUE;
+		  if ( npar_param && PAR_CHECK_INT(ltype) && PAR_CHECK_WORD(param) ) vars[varID] = TRUE;
+		}
+	      else
+		{
+		  if ( npar_code  && PAR_CHECK_INT(code) )   vars[varID] = TRUE;
+		  if ( npar_name  && PAR_CHECK_WORD(name) )  vars[varID] = TRUE;
+		  if ( npar_param && PAR_CHECK_WORD(param) ) vars[varID] = TRUE;
+		}
 	    }
 
 	  for ( varID = 0; varID < nvars; varID++ )
@@ -586,6 +596,7 @@ void *Select(void *argument)
 	    }
 
 	  PAR_CHECK_INT_FLAG(code);
+	  PAR_CHECK_INT_FLAG(ltype);
 	  PAR_CHECK_FLT_FLAG(level);
 	  PAR_CHECK_WORD_FLAG(name);
 	  PAR_CHECK_WORD_FLAG(param);
@@ -629,6 +640,15 @@ void *Select(void *argument)
 	  vlistDefTaxis(vlistID2, taxisID2);
 
 	  ntsteps = vlistNtsteps(vlistID1);
+
+	  if ( ntsteps == 1 )
+	    {
+	      for ( varID = 0; varID < nvars; ++varID )
+		if ( vlistInqVarTime(vlistID1, varID) == TIME_VARIABLE ) break;
+	      
+	      if ( varID == nvars ) ntsteps = 0;
+	    }
+
 	  if ( ntsteps == 0 && nfiles > 1 )
 	    {	      
 	      for ( varID = 0; varID < nvars; ++varID )
