@@ -35,7 +35,6 @@
 
 void *Splittime(void *argument)
 {
-  static const char *func = "Splittime";
   int SPLITHOUR, SPLITDAY, SPLITMON, SPLITSEAS;
   int operatorID;
   int operfunc, operintval;
@@ -92,13 +91,7 @@ void *Splittime(void *argument)
   nchars = strlen(filename);
 
   filesuffix[0] = 0;
-  if ( cdoDisableFilesuffix == FALSE )
-    {
-      strcat(filesuffix, streamFilesuffix(cdoDefaultFileType));
-      if ( cdoDefaultFileType == FILETYPE_GRB )
-	if ( vlistIsSzipped(vlistID1) || cdoZtype == COMPRESS_SZIP )
-	  strcat(filesuffix, ".sz");
-    }
+  cdoGenFileSuffix(filesuffix, sizeof(filesuffix), cdoDefaultFileType, vlistID1);
 
   if ( ! lcopy )
     {
