@@ -28,6 +28,7 @@
 #include "pstream.h"
 #include "statistic.h"
 
+
 #define  NIN     2
 #define  NOUT    1
 #define  NFWORK  4
@@ -35,10 +36,10 @@
 
 void *Timstat3(void *argument)
 {
-  static const char *func = "Timstat3";
   int VARQUOT2TEST, MEANDIFF2TEST;
   int operatorID;
-  int *streamID, streamID3;
+  int streamID[NIN], streamID3;
+  int vlistID[NIN], vlistID2 = -1, vlistID3 = -1;
   int gridsize;
   int vdate = 0, vtime = 0;
   int nrecs, nrecs3, nvars, nlevs ;
@@ -47,17 +48,16 @@ void *Timstat3(void *argument)
   int varID, recID, levelID, gridID;
   int nmiss3;
   int *recVarID, *recLevelID;
-  int *vlistID, vlistID2 = -1, vlistID3 = -1;
   int taxisID1, taxisID3;
   double rconst, risk;
   double fnvals0, fnvals1;
   double missval, missval1, missval2;
   double fractil_1, fractil_2, statistic;
-  field_t **fwork[NFWORK];
   double temp0, temp1, temp2, temp3;
   int ***iwork[NIWORK];
-  field_t *in, *out;
-  int *reached_eof;
+  field_t **fwork[NFWORK];
+  field_t in[NIN], out[NOUT];
+  int reached_eof[NIN];
   int n_in = NIN;
 
 
@@ -82,9 +82,6 @@ void *Timstat3(void *argument)
 	cdoAbort("Risk must be greater than 0 and lower than 1!");
     }
 
-  streamID = (int *) malloc(NIN*sizeof(int));
-  vlistID  = (int *) malloc(NIN*sizeof(int));
-
   for ( is = 0; is < NIN; ++is )
     {
       streamID[is] = streamOpenRead(cdoStreamName(is));
@@ -115,14 +112,11 @@ void *Timstat3(void *argument)
 
   streamDefVlist(streamID3, vlistID3);
 
-  reached_eof = (int *) malloc(NIN*sizeof(int));
-  memset(reached_eof, 0, NIN*sizeof(int));
+  for ( i = 0; i < NIN; ++i ) reached_eof[i] = 0;
 
-  in = (field_t *) malloc(NIN*sizeof(field_t));
   for ( i = 0; i < NIN; ++i )
     in[i].ptr = (double *) malloc(gridsize*sizeof(double));
   				 
-  out = (field_t *) malloc(NOUT*sizeof(field_t));
   for ( i = 0; i < NOUT; ++i )
     out[i].ptr = (double *) malloc(gridsize*sizeof(double));
   				 
@@ -250,7 +244,7 @@ void *Timstat3(void *argument)
 	      else
 		beta_distr_constants((fnvals0 - 1) / 2,
 				     (fnvals1 - 1) / 2, 1 - risk,
-				     &fractil_1, &fractil_2, func);
+				     &fractil_1, &fractil_2, __func__);
 	      out[0].ptr[i] = DBL_IS_EQUAL(statistic, missval1) ? missval1 : 
 	       	              statistic <= fractil_1 || statistic >= fractil_2 ? 1 : 0;
 	    }
@@ -305,7 +299,7 @@ void *Timstat3(void *argument)
 	      
 	      temp2 = DIV(DIV(mean_estimator, norm), stddev_estimator);
 	      fractil = deg_of_freedom < 1 ? missval1 :
-		student_t_inv (deg_of_freedom, 1 - risk/2, func);
+		student_t_inv (deg_of_freedom, 1 - risk/2, __func__);
 
 	      out[0].ptr[i] = DBL_IS_EQUAL(temp2, missval1)|| DBL_IS_EQUAL(fractil, missval1) ? 
 		              missval1 : fabs(temp2) >= fractil;
@@ -343,14 +337,8 @@ void *Timstat3(void *argument)
   for ( is = 0; is < NIN; ++is )
     streamClose(streamID[is]);
 
-  free(streamID);
-  free(vlistID);
-  free(reached_eof);
-
   for ( i = 0; i < NIN; ++i ) free(in[i].ptr);
-  free(in);
   for ( i = 0; i < NOUT; ++i ) free(out[i].ptr);
-  free(out);
 
   free(recVarID);
   free(recLevelID);
