@@ -49,7 +49,6 @@ static int NumFunc = sizeof(fun_sym_tbl) / sizeof(fun_sym_tbl[0]);
 static
 nodeType *expr_con_con(int oper, nodeType *p1, nodeType *p2)
 {
-  static const char *func = "expr_con_con";
   nodeType *p;
 
   p = (nodeType *) malloc(sizeof(nodeType));
@@ -63,7 +62,7 @@ nodeType *expr_con_con(int oper, nodeType *p1, nodeType *p2)
     case '*':  p->u.con.value = p1->u.con.value * p2->u.con.value; break;
     case '/':  p->u.con.value = p1->u.con.value / p2->u.con.value; break;
     case '^':  p->u.con.value = pow(p1->u.con.value, p2->u.con.value); break;
-    default:   cdoAbort("%s: operator %c unsupported!", func, oper);
+    default:   cdoAbort("%s: operator %c unsupported!", __func__, oper);
     }
 
   return (p);
@@ -72,7 +71,6 @@ nodeType *expr_con_con(int oper, nodeType *p1, nodeType *p2)
 static
 nodeType *expr_con_var(int oper, nodeType *p1, nodeType *p2)
 {
-  static const char *func = "expr_con_var";
   nodeType *p;
   long ngp, i;
   long nlev;
@@ -157,7 +155,7 @@ nodeType *expr_con_var(int oper, nodeType *p1, nodeType *p2)
 	}
       break;
     default:
-      cdoAbort("%s: operator %c unsupported!", func, oper);
+      cdoAbort("%s: operator %c unsupported!", __func__, oper);
     }
 
   nmiss = 0;
@@ -174,7 +172,6 @@ nodeType *expr_con_var(int oper, nodeType *p1, nodeType *p2)
 static
 nodeType *expr_var_con(int oper, nodeType *p1, nodeType *p2)
 {
-  static const char *func = "expr_var_con";
   nodeType *p;
   long ngp, i;
   long nlev;
@@ -265,7 +262,7 @@ nodeType *expr_var_con(int oper, nodeType *p1, nodeType *p2)
 	}
       break;
     default:
-      cdoAbort("%s: operator %c unsupported!", func, oper);
+      cdoAbort("%s: operator %c unsupported!", __func__, oper);
     }
 
   nmiss = 0;
@@ -282,7 +279,6 @@ nodeType *expr_var_con(int oper, nodeType *p1, nodeType *p2)
 static
 nodeType *expr_var_var(int oper, nodeType *p1, nodeType *p2)
 {
-  static const char *func = "expr_var_var";
   nodeType *p;
   long ngp, ngp1, ngp2, i;
   long nlev, nlev1, nlev2, k;
@@ -409,7 +405,7 @@ nodeType *expr_var_var(int oper, nodeType *p1, nodeType *p2)
 	    }
 	  break;
 	default:
-	  cdoAbort("%s: operator %c unsupported!", func, oper);
+	  cdoAbort("%s: operator %c unsupported!", __func__, oper);
 	}
     }
 
@@ -485,7 +481,6 @@ nodeType *expr(int oper, nodeType *p1, nodeType *p2)
 static
 nodeType *ex_fun_con(char *fun, nodeType *p1)
 {
-  static const char *func = "ex_fun_con";
   nodeType *p;
   int i;
   int funcID = -1;
@@ -513,7 +508,6 @@ nodeType *ex_fun_con(char *fun, nodeType *p1)
 static
 nodeType *ex_fun_var(char *fun, nodeType *p1)
 {
-  static const char *func = "ex_fun_var";
   nodeType *p;
   long ngp, i;
   long nlev;
@@ -605,7 +599,6 @@ nodeType *ex_fun(char *fun, nodeType *p1)
 static
 nodeType *ex_uminus_var(nodeType *p1)
 {
-  static const char *func = "ex_uminus_var";
   nodeType *p;
   long ngp, i;
   long nlev;
@@ -651,7 +644,6 @@ nodeType *ex_uminus_var(nodeType *p1)
 static
 nodeType *ex_uminus_con(nodeType *p1)
 {
-  static const char *func = "ex_uminus_con";
   nodeType *p;
 
   p = (nodeType *) malloc(sizeof(nodeType));
@@ -709,7 +701,6 @@ int exNode(nodeType *p, parse_parm_t *parse_arg)
 
 nodeType *ex(nodeType *p, parse_parm_t *parse_arg)
 {
-  static const char *func = "ex";
   int gridID1 = -1, zaxisID1 = -1, timeID1 = -1;
   double missval = 0;
   char varname[256];
