@@ -8,7 +8,6 @@
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.
-
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -33,10 +32,6 @@
 #include "grid.h"
 
 
-#define  deg2rad  (M_PI/180.)   /* conversion for deg to rad */
-#define  rad2deg  (180./M_PI)   /* conversion for rad to deg */
-
-
 void gridToDegree(const char *units, const char *string, int gridsize, double *array)
 {
   long i;
@@ -45,20 +40,19 @@ void gridToDegree(const char *units, const char *string, int gridsize, double *a
     {
       for ( i = 0; i < gridsize; i++ ) array[i] *= rad2deg;
     }
-  else if ( memcmp(units, "degrees", 7) == 0 )
+  else if ( memcmp(units, "degree", 6) == 0 )
     {
       /* No conversion necessary */
     }
   else
     {
-      cdoWarning("Unknown units supplied for %s: %s", string, "proceeding assuming degrees");
+      cdoWarning("Unknown units supplied for %s: %s", string, "proceeding assuming degrees!");
     }
 }
 
 
 int gridToZonal(int gridID1)
 {
-  static const char *func = "gridToZonal";
   int gridID2;
   int gridtype, gridsize;
   double  xval = 0;
@@ -89,7 +83,7 @@ int gridToZonal(int gridID1)
     }
   else
     {
-      Error(func, "Gridtype %s unsupported!", gridNamePtr(gridtype));
+      Error("Gridtype %s unsupported!", gridNamePtr(gridtype));
     }
 
   return (gridID2);
@@ -98,7 +92,6 @@ int gridToZonal(int gridID1)
 
 int gridToMeridional(int gridID1)
 {
-  static const char *func = "gridToMeridional";
   int gridID2;
   int gridtype, gridsize;
   double *xvals;
@@ -129,7 +122,7 @@ int gridToMeridional(int gridID1)
     }
   else
     {
-      Error(func, "Gridtype %s unsupported!", gridNamePtr(gridtype));
+      Error("Gridtype %s unsupported!", gridNamePtr(gridtype));
     }
 
   return (gridID2);
@@ -301,7 +294,6 @@ void gridGenYbounds2D(int nx, int ny, const double * restrict ybounds, double *
 static
 char *gen_param(const char *fmt, ...)
 {
-  static const char *func = "get_param";
   va_list args;
   char str[256];
   char *rstr;
@@ -323,7 +315,6 @@ char *gen_param(const char *fmt, ...)
 static
 void lcc_to_geo(int gridID, int gridsize, double *xvals, double *yvals)
 {
-  static const char *func = "lcc_to_geo";
   double originLon, originLat, lonParY, lat1, lat2, xincm, yincm;
   double zlat, zlon;
   double xi, xj;
@@ -339,11 +330,11 @@ void lcc_to_geo(int gridID, int gridsize, double *xvals, double *yvals)
     while ( lonParY   < 0 ) lonParY   += 360;
   */
   if ( IS_NOT_EQUAL(xincm, yincm) )
-    Warning(func, "X and Y increment must be equal on Lambert Conformal grid (Xinc = %g, Yinc = %g)\n", 
+    Warning("X and Y increment must be equal on Lambert Conformal grid (Xinc = %g, Yinc = %g)\n", 
 	    xincm, yincm);
   /*
   if ( IS_NOT_EQUAL(lat1, lat2) )
-    Warning(func, "Lat1 and Lat2 must be equal on Lambert Conformal grid (Lat1 = %g, Lat2 = %g)\n", 
+    Warning("Lat1 and Lat2 must be equal on Lambert Conformal grid (Lat1 = %g, Lat2 = %g)\n", 
 	    lat1, lat2);
   */
   map_set(PROJ_LC, originLat, originLon, xincm, lonParY, lat1, lat2, &proj);
@@ -400,7 +391,6 @@ static
 void laea_to_geo(int gridID, int gridsize, double *xvals, double *yvals)
 {
 #if defined (HAVE_LIBPROJ)
-  static const char *func = "laea_to_geo";
   PJ   *libProj;
   char *params[20];
   int nbpar=0;
@@ -445,7 +435,6 @@ static
 void lcc2_to_geo(int gridID, int gridsize, double *xvals, double *yvals)
 {
 #if defined (HAVE_LIBPROJ)
-  static const char *func = "lcc2_to_geo";
   PJ   *libProj;
   char *params[20];
   int nbpar=0;
@@ -493,7 +482,6 @@ int    qu2reg3(double *pfield, int *kpoint, int klat, int klon,
 
 void field2regular(int gridID1, int gridID2, double missval, double *array, int nmiss)
 {
-  static const char *func = "field2regular";
   int nlon, nlat;
   int gridtype;
   int lmiss, lperio, lveggy;
@@ -502,14 +490,14 @@ void field2regular(int gridID1, int gridID2, double missval, double *array, int
 
   gridtype = gridInqType(gridID1);
 
-  if ( gridtype != GRID_GAUSSIAN_REDUCED ) Error(func, "Not a reduced gaussian grid!");
+  if ( gridtype != GRID_GAUSSIAN_REDUCED ) Error("Not a reduced gaussian grid!");
 
   nlat = gridInqYsize(gridID1);
   nlon = 2*nlat;
 
   rowlonptr = (int *) malloc(nlat*sizeof(int));
 
-  if ( gridInqSize(gridID2) != nlon*nlat ) Error(func, "Gridsize differ!");
+  if ( gridInqSize(gridID2) != nlon*nlat ) Error("Gridsize differ!");
 
   gridInqRowlon(gridID1, rowlonptr);
 
@@ -525,7 +513,6 @@ void field2regular(int gridID1, int gridID2, double missval, double *array, int
 
 int gridToRegular(int gridID1)
 {
-  static const char *func = "gridToRegular";
   int gridID2;
   int gridtype, gridsize;
   int nx, ny;
@@ -534,7 +521,7 @@ int gridToRegular(int gridID1)
 
   gridtype = gridInqType(gridID1);
 
-  if ( gridtype != GRID_GAUSSIAN_REDUCED ) Error(func, "Not a reduced gaussian grid!");
+  if ( gridtype != GRID_GAUSSIAN_REDUCED ) Error("Not a reduced gaussian grid!");
 
   ny = gridInqYsize(gridID1);
   nx = 2*ny;
@@ -563,8 +550,6 @@ int gridToRegular(int gridID1)
 static
 void gridCopyMask(int gridID1, int gridID2, long gridsize)
 {
-  static const char *func = "gridCopyMask";
-
   if ( gridInqMask(gridID1, NULL) )
     {
       int *mask;
@@ -578,7 +563,6 @@ void gridCopyMask(int gridID1, int gridID2, long gridsize)
 
 int gridToCurvilinear(int gridID1)
 {
-  static const char *func = "gridToCurvilinear";
   int gridID2;
   int gridtype, gridsize;
   long index;
@@ -636,7 +620,7 @@ int gridToCurvilinear(int gridID1)
 	else
 	  {
 	    if ( ! (gridInqXvals(gridID1, NULL) && gridInqYvals(gridID1, NULL)) )
-	      Error(func, "Grid has no values");
+	      Error("Grid has no values");
 
 	    xvals = (double *) malloc(nx*sizeof(double));
 	    yvals = (double *) malloc(ny*sizeof(double));
@@ -824,7 +808,7 @@ int gridToCurvilinear(int gridID1)
       }
     default:
       {
-	Error(func, "Grid type >%s< unsupported!", gridNamePtr(gridtype));
+	Error("Grid type >%s< unsupported!", gridNamePtr(gridtype));
 	break;
       }
     }
@@ -835,11 +819,9 @@ int gridToCurvilinear(int gridID1)
 
 int gridToCell(int gridID1)
 {
-  static const char *func = "gridToCell";
   int gridID2;
   int gridtype, gridsize;
 
-
   gridtype = gridInqType(gridID1);
   gridsize = gridInqSize(gridID1);
   gridID2  = gridCreate(GRID_CELL, gridsize);
@@ -1016,7 +998,7 @@ int gridToCell(int gridID1)
       }
     default:
       {
-	Error(func, "Grid type %s unsupported!", gridNamePtr(gridtype));
+	Error("Grid type %s unsupported!", gridNamePtr(gridtype));
 	break;
       }
     }
@@ -1117,6 +1099,7 @@ double cell_area(long i, long nv, double *grid_center_lon, double *grid_center_l
   long k;
   double xa;
   double area;
+  double lim = 179*deg2rad;
   struct geo p1, p2, p3;
   struct cart c1, c2, c3;
 
@@ -1136,19 +1119,10 @@ double cell_area(long i, long nv, double *grid_center_lon, double *grid_center_l
       c2 = gc2cc(&p2);
 
       xa = areas(&c1, &c2, &c3);
-      /*
-	if ( (fabs(p1.lon*rad2deg - p2.lon*rad2deg) > 179) ||
-	(fabs(p2.lon*rad2deg - p3.lon*rad2deg) > 179) ||
-	(fabs(p3.lon*rad2deg - p1.lon*rad2deg) > 179) )
-	{
-	printf("area: %d %g %g %g %g %g %g %g %g\n", i, xa, area[i], 
-	p1.lon*rad2deg, p1.lat*rad2deg, p2.lon*rad2deg, p2.lat*rad2deg, p3.lon*rad2deg, p3.lat*rad2deg);
-	}
-      */
       if ( xa > 0.001 )
-	if ( (fabs(p1.lon*rad2deg - p2.lon*rad2deg) > 179) ||
-	     (fabs(p2.lon*rad2deg - p3.lon*rad2deg) > 179) ||
-	     (fabs(p3.lon*rad2deg - p1.lon*rad2deg) > 179) ) return(2);
+	if ( (fabs(p1.lon - p2.lon) > lim) ||
+	     (fabs(p2.lon - p3.lon) > lim) ||
+	     (fabs(p3.lon - p1.lon) > lim) ) return(2);
       
       area += xa;
     }
@@ -1161,19 +1135,10 @@ double cell_area(long i, long nv, double *grid_center_lon, double *grid_center_l
   c2 = gc2cc(&p2);
 
   xa = areas(&c1, &c2, &c3);
-  /*
-    if ( (fabs(p1.lon*rad2deg - p2.lon*rad2deg) > 179) ||
-    (fabs(p2.lon*rad2deg - p3.lon*rad2deg) > 179) ||
-    (fabs(p3.lon*rad2deg - p1.lon*rad2deg) > 179) )
-    {
-    printf("area: %d %g %g %g %g %g %g %g %g\n", i, xa, area[i],
-    p1.lon*rad2deg, p1.lat*rad2deg, p2.lon*rad2deg, p2.lat*rad2deg, p3.lon*rad2deg, p3.lat*rad2deg);
-    }
-  */
   if ( xa > 0.001 )
-    if ( (fabs(p1.lon*rad2deg - p2.lon*rad2deg) > 179) ||
-	 (fabs(p2.lon*rad2deg - p3.lon*rad2deg) > 179) ||
-	 (fabs(p3.lon*rad2deg - p1.lon*rad2deg) > 179) ) return(2);
+    if ( (fabs(p1.lon - p2.lon) > lim) ||
+	 (fabs(p2.lon - p3.lon) > lim) ||
+	 (fabs(p3.lon - p1.lon) > lim) ) return(2);
   
   area += xa;
 
@@ -1183,7 +1148,6 @@ double cell_area(long i, long nv, double *grid_center_lon, double *grid_center_l
 
 int gridGenArea(int gridID, double *area)
 {
-  static const char *func = "gridGenArea";
   int status = 0;
   int gridtype;
   int lgrid_gen_bounds = FALSE;
@@ -1271,9 +1235,38 @@ int gridGenArea(int gridID, double *area)
 	  return (status);
 	}
     }
+  
+  /* Convert lat/lon units if required */
+  {
+    char units[128];
+
+    gridInqXunits(gridID, units);
+
+    if ( memcmp(units, "degree", 6) == 0 )
+      {
+	/* No conversion necessary */
+      }
+    else if ( memcmp(units, "radian", 6) == 0 )
+      {
+	for ( i = 0; i < gridsize; ++i )
+	  {
+	    grid_center_lon[i] *= rad2deg;
+	    grid_center_lat[i] *= rad2deg;
+	  }
+	for ( i = 0; i < gridsize*nv; ++i )
+	  {
+	    grid_corner_lon[i] *= rad2deg;
+	    grid_corner_lat[i] *= rad2deg;
+	  }
+      }
+    else
+      {
+	cdoWarning("Unknown units supplied for grid1 center lat/lon: proceeding assuming radians");
+      }
+  }
 
   if ( lgriddestroy ) gridDestroy(gridID);
-  
+
   total_area = 0;
 #if defined (_OPENMP)
 #pragma omp parallel for default(none)        \
@@ -1300,7 +1293,6 @@ int gridGenArea(int gridID, double *area)
 
 int gridGenWeights(int gridID, double *grid_area, double *grid_wgts)
 {
-  static const char *func = "gridGenWeights";
   int i, nvals, gridsize, gridtype;
   int status = 0;
   int *grid_mask = NULL;
@@ -1349,7 +1341,6 @@ int gridGenWeights(int gridID, double *grid_area, double *grid_wgts)
 static
 int gridWeightsOld(int gridID, double *weights)
 {
-  static const char *func = "gridWeightsOld";
   int status = FALSE;
   long i, j;
   int len;
@@ -1437,7 +1428,6 @@ int gridWeightsOld(int gridID, double *weights)
 
 int gridWeights(int gridID, double *grid_wgts)
 {
-  static const char *func = "gridWeights";
   int i, gridsize, gridtype;
   int a_status, w_status;
   double *grid_area;
