@@ -163,7 +163,6 @@ int getoptname(char *optname, const char *optstring, int nopt)
 
 int gridDefine(grid_t grid)
 {
-  static const char *func = "gridDefine";
   int gridID = UNDEFID;
   int i;
 
@@ -176,8 +175,8 @@ int gridDefine(grid_t grid)
       {
 	if ( grid.size != 1 )
 	  {
-	    if ( grid.xsize == 0 ) Error(func, "xsize undefined!");
-	    if ( grid.ysize == 0 ) Error(func, "ysize undefined!");
+	    if ( grid.xsize == 0 ) Error("xsize undefined!");
+	    if ( grid.ysize == 0 ) Error("ysize undefined!");
 	  }
 
 	if ( grid.size == 0 ) grid.size = grid.xsize*grid.ysize;
@@ -291,8 +290,8 @@ int gridDefine(grid_t grid)
 
 	if ( grid.type == GRID_CURVILINEAR )
 	  {
-	    if ( grid.xsize == 0 ) Error(func, "xsize undefined!");
-	    if ( grid.ysize == 0 ) Error(func, "ysize undefined!");
+	    if ( grid.xsize == 0 ) Error("xsize undefined!");
+	    if ( grid.ysize == 0 ) Error("ysize undefined!");
 	    gridDefXsize(gridID, grid.xsize);
 	    gridDefYsize(gridID, grid.ysize);
 	  }
@@ -341,8 +340,8 @@ int gridDefine(grid_t grid)
       }
     case GRID_LCC:
       {
-	if ( grid.xsize == 0 ) Error(func, "xsize undefined!");
-	if ( grid.ysize == 0 ) Error(func, "ysize undefined!");
+	if ( grid.xsize == 0 ) Error("xsize undefined!");
+	if ( grid.ysize == 0 ) Error("ysize undefined!");
 
 	if ( grid.size == 0 ) grid.size = grid.xsize*grid.ysize;
 
@@ -353,13 +352,13 @@ int gridDefine(grid_t grid)
 	gridDefXsize(gridID, grid.xsize);
 	gridDefYsize(gridID, grid.ysize);
 
-	if ( grid.def_originLon == FALSE ) Error(func, "originLon undefined!");
-	if ( grid.def_originLat == FALSE ) Error(func, "originLat undefined!");
-	if ( grid.def_lonParY   == FALSE ) Error(func, "lonParY undefined!");
-	if ( grid.def_lat1      == FALSE ) Error(func, "lat1 undefined!");
-	if ( grid.def_lat2      == FALSE ) Error(func, "lat2 undefined!");
-	if ( grid.def_xinc      == FALSE ) Error(func, "xinc undefined!");
-	if ( grid.def_yinc      == FALSE ) Error(func, "yinc undefined!");
+	if ( grid.def_originLon == FALSE ) Error("originLon undefined!");
+	if ( grid.def_originLat == FALSE ) Error("originLat undefined!");
+	if ( grid.def_lonParY   == FALSE ) Error("lonParY undefined!");
+	if ( grid.def_lat1      == FALSE ) Error("lat1 undefined!");
+	if ( grid.def_lat2      == FALSE ) Error("lat2 undefined!");
+	if ( grid.def_xinc      == FALSE ) Error("xinc undefined!");
+	if ( grid.def_yinc      == FALSE ) Error("yinc undefined!");
 
 	gridDefLCC(gridID, grid.originLon, grid.originLat, grid.lonParY,
 		   grid.lat1, grid.lat2, grid.xinc, grid.yinc, grid.projflag, grid.scanflag);
@@ -374,8 +373,8 @@ int gridDefine(grid_t grid)
       }
     case GRID_LCC2:
       {
-	if ( grid.xsize == 0 ) Error(func, "xsize undefined!");
-	if ( grid.ysize == 0 ) Error(func, "ysize undefined!");
+	if ( grid.xsize == 0 ) Error("xsize undefined!");
+	if ( grid.ysize == 0 ) Error("ysize undefined!");
 
 	if ( grid.size == 0 ) grid.size = grid.xsize*grid.ysize;
 
@@ -412,9 +411,9 @@ int gridDefine(grid_t grid)
 	    free(grid.yvals);
 	  }	
 
-	if ( grid.def_lon_0     == FALSE ) Error(func, "lon_0 undefined!");
-	if ( grid.def_lat_0     == FALSE ) Error(func, "lat_0 undefined!");
-	if ( grid.def_lat_1     == FALSE ) Error(func, "lat_1 undefined!");
+	if ( grid.def_lon_0     == FALSE ) Error("lon_0 undefined!");
+	if ( grid.def_lat_0     == FALSE ) Error("lat_0 undefined!");
+	if ( grid.def_lat_1     == FALSE ) Error("lat_1 undefined!");
 	if ( grid.def_lat_2     == FALSE ) grid.def_lat_2 = grid.def_lat_1;
 
 	gridDefLcc2(gridID, grid.a, grid.lon_0, grid.lat_0, grid.lat_1, grid.lat_2);
@@ -430,7 +429,7 @@ int gridDefine(grid_t grid)
     case GRID_SPECTRAL:
       {
 	if ( grid.ntr == 0 )
-	  Error(func, "truncation undefined!");
+	  Error("truncation undefined!");
 	if ( grid.size == 0 )
 	  grid.size = (grid.ntr+1) * (grid.ntr+2);
 
@@ -446,9 +445,9 @@ int gridDefine(grid_t grid)
       }
     case GRID_GME:
       {
-	if ( grid.nd   == 0 ) Error(func, "nd undefined!");
-	if ( grid.ni   == 0 ) Error(func, "ni undefined!");
-	if ( grid.size == 0 ) Error(func, "size undefined!");
+	if ( grid.nd   == 0 ) Error("nd undefined!");
+	if ( grid.ni   == 0 ) Error("ni undefined!");
+	if ( grid.size == 0 ) Error("size undefined!");
 
 	gridID = gridCreate(grid.type, grid.size);
 
@@ -470,9 +469,9 @@ int gridDefine(grid_t grid)
     default:
       {
 	if ( grid.type == -1 )
-	  Error(func, "Undefined grid type!");
+	  Error("Undefined grid type!");
 	else
-	  Error(func, "Unsupported grid type: %s", gridNamePtr(grid.type));
+	  Error("Unsupported grid type: %s", gridNamePtr(grid.type));
       }
     }
 
@@ -556,13 +555,12 @@ void fnmexp2(char *out, char *in1, const char *in2)
 /*
 double *readfield(grid_t *grid, int record, char *format, char *filename)
 {
-  static const char *func = "readfield";
   int fileID, rxysize, ierr, irec;
   double *vals;
 
-  if ( grid->size == 0 )  Error(func, "grid size = 0!");
-  if ( format == NULL )   Error(func, "format undefined!");
-  if ( filename == NULL ) Error(func, "file name undefined!");
+  if ( grid->size == 0 )  Error("grid size = 0!");
+  if ( format == NULL )   Error("format undefined!");
+  if ( filename == NULL ) Error("file name undefined!");
 
   vals = (double *) malloc(grid->size*sizeof(double));
 
@@ -570,21 +568,21 @@ double *readfield(grid_t *grid, int record, char *format, char *filename)
     {
       int header[4];
       fileID = extOpen(filename, "r");
-      if ( fileID == UNDEFID ) SysError(func, filename);
+      if ( fileID == UNDEFID ) SysError(filename);
 
       for ( irec = 0; irec < record; irec++ )
 	{
 	  ierr = extReadHeader(fileID, header);
-	  if ( ierr <= 0 ) Error(func, "Record %d unexpected EOF in file %s", irec+1, filename);
+	  if ( ierr <= 0 ) Error("Record %d unexpected EOF in file %s", irec+1, filename);
 	}
       grid->prec   = extInqPrec(fileID);
       rxysize = header[3];
-      if ( rxysize != (int) grid->size ) Error(func, "unexpected record size of %d!", rxysize);
+      if ( rxysize != (int) grid->size ) Error("unexpected record size of %d!", rxysize);
       ierr = extReadDataDP(fileID, vals);
       extClose(fileID);
     }
   else
-    Error(func, "format %s unsupported!", format);
+    Error("format %s unsupported!", format);
 
   return (vals);
 }
@@ -592,13 +590,12 @@ double *readfield(grid_t *grid, int record, char *format, char *filename)
 /*
 double *readfield4(grid_t *grid, int record, char *format, char *filename)
 {
-  static const char *func = "readfield4";
   int fileID, rxysize, ierr, irec;
   double *vals;
 
-  if ( grid->size == 0 )  Error(func, "grid size = 0!");
-  if ( format == NULL )   Error(func, "format undefined!");
-  if ( filename == NULL ) Error(func, "file name undefined!");
+  if ( grid->size == 0 )  Error("grid size = 0!");
+  if ( format == NULL )   Error("format undefined!");
+  if ( filename == NULL ) Error("file name undefined!");
 
   vals  = (double *) malloc(4*grid->size*sizeof(double));
 
@@ -606,22 +603,22 @@ double *readfield4(grid_t *grid, int record, char *format, char *filename)
     {
       int header[4];
       fileID = extOpen(filename, "r");
-      if ( fileID == UNDEFID ) SysError(func, filename);
+      if ( fileID == UNDEFID ) SysError(filename);
 
       for ( irec = 0; irec < record; irec++ )
 	{
 	  ierr = extReadHeader(fileID, header);
-	  if ( ierr <= 0 ) Error(func, "Record %d unexpected EOF in file %s", irec+1, filename);
+	  if ( ierr <= 0 ) Error("Record %d unexpected EOF in file %s", irec+1, filename);
 	}
       grid->prec   = extInqPrec(fileID);
       rxysize = header[3];
-      if ( rxysize != (int) (4*grid->size) ) Error(func, "unexpected record size of %d!", rxysize);
+      if ( rxysize != (int) (4*grid->size) ) Error("unexpected record size of %d!", rxysize);
       ierr = extReadDataDP(fileID, vals);
 
       extClose(fileID);
     }
   else
-    Error(func, "format %s unsupported!", format);
+    Error("format %s unsupported!", format);
 
   return (vals);
 }
@@ -629,13 +626,12 @@ double *readfield4(grid_t *grid, int record, char *format, char *filename)
 
 double readflt(const char *name, const char *pline)
 {
-  const char func[] = "readflt";
   double val;
   char *endptr;
 
   val = strtod(pline, &endptr);
   if ( pline == endptr )
-    Warning(func, "Couldn't read value for %s, set to zero!", name);
+    Warning("Couldn't read value for %s, set to zero!", name);
 
   return (val);
 }
@@ -643,7 +639,6 @@ double readflt(const char *name, const char *pline)
 
 int gridFromFile(FILE *gfp, const char *dname)
 {
-  static const char *func = "gridFromFile";
   char line[MAX_LINE_LEN], *pline;
   int gridID = -1;
   int size;
@@ -695,7 +690,7 @@ int gridFromFile(FILE *gfp, const char *dname)
 	  else if ( cmpstr(pline, "laea", len)  == 0 )
 	    grid.type = GRID_LAEA;
 	  else
-	    Warning(func, "Invalid grid name : %s", pline);
+	    Warning("Invalid grid name : %s", pline);
 	}
       else if ( cmpstr(pline, "gridprec", len)  == 0 )
 	{
@@ -861,7 +856,7 @@ int gridFromFile(FILE *gfp, const char *dname)
 	      grid.scanflag = 64;
 	    }
 	  else
-	    Warning(func, "Invalid projection : %s", pline);
+	    Warning("Invalid projection : %s", pline);
 	}
       else if ( cmpstr(pline, "a", len)  == 0 )
 	{
@@ -919,7 +914,7 @@ int gridFromFile(FILE *gfp, const char *dname)
 	    {
 	      if ( ! readline(gfp, line, MAX_LINE_LEN) )
 		{
-		  Warning(func, "Incomplete command: >gridlatlon<");
+		  Warning("Incomplete command: >gridlatlon<");
 		  break;
 		}
 	      sscanf(line, "%lg %lg", &flat, &flon);
@@ -949,7 +944,7 @@ int gridFromFile(FILE *gfp, const char *dname)
 		    {
 		      if ( ! readline(gfp, line, MAX_LINE_LEN) )
 			{
-			  Warning(func, "Incomplete command: >mask<");
+			  Warning("Incomplete command: >mask<");
 			  break;
 			}
 		      pline = line;
@@ -967,7 +962,7 @@ int gridFromFile(FILE *gfp, const char *dname)
 		}
 	    }
 	  else
-	    Warning(func, "gridsize undefined!");
+	    Warning("gridsize undefined!");
 	}
       else if ( cmpstr(pline, "xvals", len)  == 0 )
 	{
@@ -993,7 +988,7 @@ int gridFromFile(FILE *gfp, const char *dname)
 		    {
 		      if ( ! readline(gfp, line, MAX_LINE_LEN) )
 			{
-			  Warning(func, "Incomplete command: >xvals<");
+			  Warning("Incomplete command: >xvals<");
 			  break;
 			}
 		      pline = line;
@@ -1004,7 +999,7 @@ int gridFromFile(FILE *gfp, const char *dname)
 		}
 	    }
 	  else
-	    Warning(func, "xsize or gridsize undefined!");
+	    Warning("xsize or gridsize undefined!");
 	}
       else if ( cmpstr(pline, "yvals", len)  == 0 )
 	{
@@ -1030,7 +1025,7 @@ int gridFromFile(FILE *gfp, const char *dname)
 		    {
 		      if ( ! readline(gfp, line, MAX_LINE_LEN) )
 			{
-			  Warning(func, "Incomplete command: >yvals<");
+			  Warning("Incomplete command: >yvals<");
 			  break;
 			}
 		      pline = line;
@@ -1041,7 +1036,7 @@ int gridFromFile(FILE *gfp, const char *dname)
 		}
 	    }
 	  else
-	    Warning(func, "ysize or gridsize undefined!");
+	    Warning("ysize or gridsize undefined!");
 	}
       else if ( cmpstr(pline, "xbounds", len)  == 0 )
 	{
@@ -1072,7 +1067,7 @@ int gridFromFile(FILE *gfp, const char *dname)
 		    {
 		      if ( ! readline(gfp, line, MAX_LINE_LEN) )
 			{
-			  Warning(func, "Incomplete command: >xbounds<");
+			  Warning("Incomplete command: >xbounds<");
 			  break;
 			}
 		      pline = line;
@@ -1084,8 +1079,8 @@ int gridFromFile(FILE *gfp, const char *dname)
 	    }
 	  else
 	    {
-	      if ( size         == 0 ) Warning(func, "xsize or gridsize undefined!");
-	      if ( grid.nvertex == 0 ) Warning(func, "nvertex undefined!");
+	      if ( size         == 0 ) Warning("xsize or gridsize undefined!");
+	      if ( grid.nvertex == 0 ) Warning("nvertex undefined!");
 	    }
 	}
       else if ( cmpstr(pline, "ybounds", len)  == 0 )
@@ -1117,7 +1112,7 @@ int gridFromFile(FILE *gfp, const char *dname)
 		    {
 		      if ( ! readline(gfp, line, MAX_LINE_LEN) )
 			{
-			  Warning(func, "Incomplete command: >ybounds<");
+			  Warning("Incomplete command: >ybounds<");
 			  break;
 			}
 		      pline = line;
@@ -1129,14 +1124,14 @@ int gridFromFile(FILE *gfp, const char *dname)
 	    }
 	  else
 	    {
-	      if ( grid.ysize   == 0 ) Warning(func, "ysize or gridsize undefined!");
-	      if ( grid.nvertex == 0 ) Warning(func, "nvertex undefined!");
+	      if ( grid.ysize   == 0 ) Warning("ysize or gridsize undefined!");
+	      if ( grid.nvertex == 0 ) Warning("nvertex undefined!");
 	    }
 	}
       else
 	{
 	  if ( grid.type != UNDEFID )
-	    Warning(func, "Invalid grid command : >%s<", pline);
+	    Warning("Invalid grid command : >%s<", pline);
 	}
     }
   /*
@@ -1213,7 +1208,6 @@ int input_darray(FILE *gfp, int n_values, double *array)
 
 int gridFromPingo(FILE *gfp, const char *dname)
 {
-  static const char *func = "gridFromPingo";
   int gridID = -1;
   int i;
   int nlon, nlat;
@@ -1257,7 +1251,7 @@ int gridFromPingo(FILE *gfp, const char *dname)
 	      grid.xvals[i] += 360;
 	      if ( i < nlon - 1 && grid.xvals[i+1] + 360 <= grid.xvals[i] )
 		{
-		  Message(func, "Longitudes are not in ascending order!");
+		  Message("Longitudes are not in ascending order!");
 		  return (gridID);
 		}
 	    }
@@ -1284,7 +1278,7 @@ int gridFromPingo(FILE *gfp, const char *dname)
 	   grid.yvals[0]      < -90.001  || 
 	   grid.yvals[nlat-1] < -90.001 )
 	{
-	  Message(func, "Latitudes must be between 90 and -90!");
+	  Message("Latitudes must be between 90 and -90!");
 	  return (gridID);
 	}
 
@@ -1292,7 +1286,7 @@ int gridFromPingo(FILE *gfp, const char *dname)
 	if ( IS_EQUAL(grid.yvals[i+1], grid.yvals[i]) || (i < nlat - 2 &&
 	    ((grid.yvals[i+1] > grid.yvals[i]) != (grid.yvals[i+2] > grid.yvals[i+1]))) )
 	  {
-	    Message(func, "Latitudes must be in descending or ascending order!");
+	    Message("Latitudes must be in descending or ascending order!");
 	    return (gridID);
 	  }
 		    
@@ -1348,7 +1342,6 @@ int nlat2ntr_linear(int nlat)
 
 int ntr2nlat(int ntr)
 {
-  static const char *func = "ntr2nlat";
   int nlat, nlat2;
 
   nlat = NINT((ntr*3.+1.)/2.);
@@ -1358,7 +1351,7 @@ int ntr2nlat(int ntr)
       nlat2 = NINT(((ntr+1)*3.+1.)/2.);
       /*
       if ( nlat == nlat2 )
-	Error(func, "Computation of latitudes failed for truncation %d", ntr);
+	Error("Computation of latitudes failed for truncation %d", ntr);
       */
     }
 
@@ -1368,7 +1361,6 @@ int ntr2nlat(int ntr)
 
 int ntr2nlat_linear(int ntr)
 {
-  static const char *func = "ntr2nlat_linear";
   int nlat, nlat2;
 
   nlat = NINT((ntr*2.+1.)/2.);
@@ -1378,7 +1370,7 @@ int ntr2nlat_linear(int ntr)
       nlat2 = NINT(((ntr+1)*2.+1.)/2.);
       /*
       if ( nlat == nlat2 )
-	Error(func, "Computation of latitudes failed for truncation %d", ntr);
+	Error("Computation of latitudes failed for truncation %d", ntr);
       */
     }
 
@@ -1421,7 +1413,6 @@ int compNlon(int nlat)
 
 void gen_grid_lonlat(grid_t *grid, const char *pline, double inc, double lon1, double lon2, double lat1, double lat2)
 {
-  static const char *func = "gen_grid_lonlat";
   int nlon, nlat, i;
 
   grid->type = GRID_LONLAT;
@@ -1449,7 +1440,6 @@ void gen_grid_lonlat(grid_t *grid, const char *pline, double inc, double lon1, d
 
 int gridFromName(const char *gridname)
 {
-  static const char *func = "gridFromName";
   const char *pline;
   int gridID = UNDEFID;
   grid_t grid;
@@ -1652,7 +1642,6 @@ int gridFromName(const char *gridname)
 
 int cdoDefineGrid(const char *gridfile)
 {
-  static const char *func = "cdoDefineGrid";
   FILE *gfp;
   char buffer[4];
   int gridID = -1;
@@ -1668,7 +1657,7 @@ int cdoDefineGrid(const char *gridfile)
   else
     {
       if ( fread(buffer, 1, 4, gfp) != 4 )
-	SysError(func, "Read grid from %s failed!", gridfile);
+	SysError("Read grid from %s failed!", gridfile);
 
       fclose(gfp);
 
