@@ -45,7 +45,6 @@ int cdf_openread(const char *filename)
 
 int gridFromNCfile(const char *gridfile)
 {
-  static const char *func = "gridFromNCfile";
   int gridID = -1;
 #if  defined  (HAVE_LIBNETCDF)
   int nc_file_id;      /* netCDF grid file id           */
@@ -98,7 +97,7 @@ int gridFromNCfile(const char *gridfile)
 	{
 	  grid.type = GRID_CURVILINEAR;
 	  if ( grid.nvertex != 4 )
-	    Error(func, "curvilinear grid with %d corners unsupported", grid.nvertex);
+	    Error("curvilinear grid with %d corners unsupported", grid.nvertex);
 
 	  grid.xsize = grid_dims[0];
 	  grid.ysize = grid_dims[1];
@@ -158,7 +157,6 @@ int gridFromNCfile(const char *gridfile)
 
 void writeNCgrid(const char *gridfile, int gridID, int *grid_imask)
 {
-  static const char *func = "writeNCgrid";
 #if  defined  (HAVE_LIBNETCDF)
   int nc_file_id;      /* netCDF grid file id           */
   int nc_gridsize_id;  /* netCDF grid size dim id       */
@@ -327,6 +325,6 @@ void writeNCgrid(const char *gridfile, int gridID, int *grid_imask)
   nce(nc_close(nc_file_id));
 
 #else
-  Error(func, "netCDF support not compiled in!");
+  Error("netCDF support not compiled in!");
 #endif
 }
