@@ -37,12 +37,11 @@ static void listInit(LIST *list, int type)
 
 LIST *listNew(int type)
 {
-  static const char *func = "listNew";
   LIST *list = NULL;
 
   if ( type != INT_LIST && type != FLT_LIST )
     {
-      fprintf(stderr, "%s: type %d unsupported!\n", func, type);
+      fprintf(stderr, "%s: type %d unsupported!\n", __func__, type);
     }
   else
     {
@@ -56,8 +55,6 @@ LIST *listNew(int type)
 
 void listDelete(LIST *list)
 {
-  static const char *func = "listDelete";
-
   if ( list )
     {
       if ( list->array ) free(list->array);
@@ -74,8 +71,6 @@ void *listArrayPtr(LIST *list)
 
 static void listCheck(LIST *list, int num)
 {
-  static const char *func = "listCheck";
-
   while ( list->nalloc < (num+1) )
     {
       list->nalloc += list->allinc;
