@@ -63,8 +63,11 @@ void *Echam5ini(void *argument);
 void *Enlarge(void *argument);
 void *Enlargegrid(void *argument);
 void *Ensstat(void *argument);
+void *Ensstat3(void *argument);
 void *Eofcoeff(void *argument);
+void *Eofcoeff3d(void *argument);
 void *EOFs(void *argument);
+void *EOF3d(void *argument);
 void *Expr(void *argument);
 void *Filedes(void *argument);
 void *Fillmiss(void *argument);
@@ -217,8 +220,7 @@ void *EcaTx90p(void *argument);
 void *EcaCdd(void *argument);
 void *EcaCwd(void *argument);
 void *EcaRr1(void *argument);
-void *EcaR10mm(void *argument);
-void *EcaR20mm(void *argument);
+void *EcaPd(void *argument);
 void *EcaR75p(void *argument);
 void *EcaR75ptot(void *argument);
 void *EcaR90p(void *argument);
@@ -267,8 +269,12 @@ void *Wct(void *argument);
 #define  EnlargeOperators       {"enlarge"}
 #define  EnlargegridOperators   {"enlargegrid"}
 #define  EnsstatOperators       {"ensmin", "ensmax", "enssum", "ensmean", "ensavg", "ensvar", "ensstd", "enspctl"}
+#define  Ensstat2Operators      {"ensbrs", "enscrps"}
+#define  Ensstat3Operators      {"ensrkhist_space","ensrkhist_time","ensroc"}
 #define  EofcoeffOperators      {"eofcoeff"}
+#define  Eofcoeff3dOperators    {"eofcoeff3d"}
 #define  EOFsOperators          {"eof", "eofspatial", "eoftime"}
+#define  EOF3dOperators         {"eof3d","eof3dspatial","eof3dtime"}
 #define  ExprOperators          {"expr", "exprf", "aexpr", "aexprf"}
 #define  FiledesOperators       {"filedes", "griddes", "griddes2", "zaxisdes", "vct", "vct2", "pardes", \
                                  "vlist", "partab", "partab2"}
@@ -283,7 +289,7 @@ void *Wct(void *argument);
 #define  GradsdesOperators      {"gradsdes1", "gradsdes2", "dumpmap"}
 #define  GridboxstatOperators   {"gridboxmin", "gridboxmax", "gridboxsum", "gridboxmean", "gridboxavg", \
                                  "gridboxvar", "gridboxstd"}
-#define  GridcellOperators      {"gridarea", "gridweights", "gridmask"}
+#define  GridcellOperators      {"gridarea", "gridweights", "gridmask", "griddx", "griddy"}
 #define  HarmonicOperators      {"harmonic"}
 #define  HistogramOperators     {"histcount", "histsum", "histmean", "histfreq"}
 #define  IFS2ICONOperators      {"ifs2icon"}
@@ -293,7 +299,7 @@ void *Wct(void *argument);
 #define  ImportobsOperators     {"import_obs"}
 #define  InfoOperators          {"info", "infov", "infop", "map"}
 #define  InputOperators         {"input", "inputsrv", "inputext"}
-#define  IntgridOperators       {"intgridbil", "intpoint", "interpolate", "intarea", "boxavg", "thinout"}
+#define  IntgridOperators       {"intgridbil", "intpoint", "interpolate", "boxavg", "thinout"}
 #define  IntgridtrajOperators   {"intgridtraj"}
 #define  IntlevelOperators      {"intlevel", "intlevelx"}
 #define  InttimeOperators       {"inttime"}
@@ -404,7 +410,7 @@ void *Wct(void *argument);
 #define  TrmsOperators          {"trms"}
 #define  TstepcountOperators    {"tstepcount"}
 #define  VardupOperators        {"pardup", "parmul"}
-#define  VargenOperators        {"random", "const", "topo", "for"}
+#define  VargenOperators        {"random", "const", "for", "topo", "temp", "mask"}
 #define  VarrmsOperators        {"varrms"}
 #define  VertintOperators       {"ml2pl", "ml2hl", "ml2plx", "ml2hlx", \
                                  "ml2pl_lp", "ml2hl_lp", "ml2plx_lp", "ml2hlx_lp"}
@@ -449,8 +455,7 @@ void *Wct(void *argument);
 #define  EcaCddOperators        {"eca_cdd"}
 #define  EcaCwdOperators        {"eca_cwd"}
 #define  EcaRr1Operators        {"eca_rr1"}
-#define  EcaR10mmOperators      {"eca_r10mm"}
-#define  EcaR20mmOperators      {"eca_r20mm"}
+#define  EcaPdOperators         {"eca_pd", "eca_r10mm", "eca_r20mm"}
 #define  EcaR75pOperators       {"eca_r75p"}
 #define  EcaR75ptotOperators    {"eca_r75ptot"}
 #define  EcaR90pOperators       {"eca_r90p"}
@@ -476,6 +481,7 @@ void *Wct(void *argument);
 
 static modules_t Modules[] =
 {
+  /* stream out -1 means usage of obase */
   /*
     function        help function      operator names          number     num streams
                                                                type       in  out
@@ -505,8 +511,12 @@ static modules_t Modules[] =
   { Enlarge,        EnlargeHelp,       EnlargeOperators,       CDI_REAL,  1,  1 },
   { Enlargegrid,    NULL,              EnlargegridOperators,   CDI_REAL,  1,  1 },
   { Ensstat,        EnsstatHelp,       EnsstatOperators,       CDI_REAL, -1,  1 },
-  { Eofcoeff,       EofcoeffHelp,      EofcoeffOperators,      CDI_REAL,  2,  1 },
+  { Ensstat,        Ensstat2Help,      Ensstat2Operators,      CDI_REAL, -1,  1 },
+  { Ensstat3,       Ensstat2Help,      Ensstat3Operators,      CDI_REAL, -1,  1 },
+  { Eofcoeff,       EofcoeffHelp,      EofcoeffOperators,      CDI_REAL,  2, -1 },
+  { Eofcoeff3d,     EofcoeffHelp,      Eofcoeff3dOperators,    CDI_REAL,  2, -1 },
   { EOFs,           EOFsHelp,          EOFsOperators,          CDI_REAL,  1,  2 },
+  { EOF3d,          NULL,              EOF3dOperators,         CDI_REAL,  1,  2 },
   { Expr,           ExprHelp,          ExprOperators,          CDI_REAL,  1,  1 },
   { Filedes,        FiledesHelp,       FiledesOperators,       CDI_BOTH,  1,  0 },
   { Fillmiss,       NULL,              FillmissOperators,      CDI_REAL,  1,  1 },
@@ -534,7 +544,7 @@ static modules_t Modules[] =
   { Intlevel,       IntlevelHelp,      IntlevelOperators,      CDI_REAL,  1,  1 },
   { Inttime,        InttimeHelp,       InttimeOperators,       CDI_REAL,  1,  1 },
   { Intntime,       InttimeHelp,       IntntimeOperators,      CDI_REAL,  1,  1 },
-  { Intyear,        IntyearHelp,       IntyearOperators,       CDI_REAL,  2,  1 },
+  { Intyear,        IntyearHelp,       IntyearOperators,       CDI_REAL,  2, -1 },
   { Invert,         InvertHelp,        InvertOperators,        CDI_REAL,  1,  1 },
   { Invertlev,      InvertlevHelp,     InvertlevOperators,     CDI_REAL,  1,  1 },
   { Log,            NULL,              LogOperators,           CDI_REAL,  1,  0 },
@@ -592,11 +602,11 @@ static modules_t Modules[] =
   { Specinfo,       NULL,              SpecinfoOperators,      CDI_REAL,  0,  0 },
   { Spectral,       SpectralHelp,      SpectralOperators,      CDI_REAL,  1,  1 },
   { Spectrum,       NULL,              SpectrumOperators,      CDI_REAL,  1,  1 },
-  { Split,          SplitHelp,         SplitOperators,         CDI_BOTH,  1,  1 },
-  { Splitrec,       SplitHelp,         SplitrecOperators,      CDI_BOTH,  1,  1 },
-  { Splitsel,       SplitselHelp,      SplitselOperators,      CDI_BOTH,  1,  1 },
-  { Splittime,      SplittimeHelp,     SplittimeOperators,     CDI_BOTH,  1,  1 },
-  { Splityear,      SplittimeHelp,     SplityearOperators,     CDI_BOTH,  1,  1 },
+  { Split,          SplitHelp,         SplitOperators,         CDI_BOTH,  1, -1 },
+  { Splitrec,       SplitHelp,         SplitrecOperators,      CDI_BOTH,  1, -1 },
+  { Splitsel,       SplitselHelp,      SplitselOperators,      CDI_BOTH,  1, -1 },
+  { Splittime,      SplittimeHelp,     SplittimeOperators,     CDI_BOTH,  1, -1 },
+  { Splityear,      SplittimeHelp,     SplityearOperators,     CDI_BOTH,  1, -1 },
   { Subtrend,       SubtrendHelp,      SubtrendOperators,      CDI_REAL,  3,  1 },
   { Template1,      NULL,              Template1Operators,     CDI_REAL,  1,  1 },
   { Template2,      NULL,              Template2Operators,     CDI_REAL,  1,  1 },
@@ -640,7 +650,7 @@ static modules_t Modules[] =
   { Writegrid,      NULL,              WritegridOperators,     CDI_REAL,  1,  1 },  /* no cdi output */
   { Writerandom,    NULL,              WriterandomOperators,   CDI_REAL,  1,  1 },
   { Yhourstat,      YhourstatHelp,     YhourstatOperators,     CDI_REAL,  1,  1 },
-  { Ydayarith,      NULL,              YdayarithOperators,     CDI_REAL,  2,  1 },
+  { Ydayarith,      YdayarithHelp,     YdayarithOperators,     CDI_REAL,  2,  1 },
   { Ydaypctl,       YdaypctlHelp,      YdaypctlOperators,      CDI_REAL,  3,  1 },
   { Ydaystat,       YdaystatHelp,      YdaystatOperators,      CDI_REAL,  1,  1 },
   { Ydrunpctl,      YdrunpctlHelp,     YdrunpctlOperators,     CDI_REAL,  3,  1 },
@@ -673,8 +683,7 @@ static modules_t Modules[] =
   { EcaCdd,         EcaCddHelp,        EcaCddOperators,        CDI_REAL,  1,  1 },
   { EcaCwd,         EcaCwdHelp,        EcaCwdOperators,        CDI_REAL,  1,  1 },
   { EcaRr1,         EcaRr1Help,        EcaRr1Operators,        CDI_REAL,  1,  1 },
-  { EcaR10mm,       EcaR10mmHelp,      EcaR10mmOperators,      CDI_REAL,  1,  1 },
-  { EcaR20mm,       EcaR20mmHelp,      EcaR20mmOperators,      CDI_REAL,  1,  1 },
+  { EcaPd,          EcaPdHelp,         EcaPdOperators,         CDI_REAL,  1,  1 },
   { EcaR75p,        EcaR75pHelp,       EcaR75pOperators,       CDI_REAL,  2,  1 },
   { EcaR75ptot,     EcaR75ptotHelp,    EcaR75ptotOperators,    CDI_REAL,  2,  1 },
   { EcaR90p,        EcaR90pHelp,       EcaR90pOperators,       CDI_REAL,  2,  1 },
@@ -734,6 +743,8 @@ static char *opalias[][2] =
   {"eca_r1mm",            "eca_rr1"    },
   {"fpressure",           "pressure_fl"},
   {"hpressure",           "pressure_hl"},
+  {"ensrkhistspace",      "ensrkhist_space"},
+  {"ensrkhisttime",       "ensrkhist_time"}
 };
 
 static int nopalias = sizeof(opalias) / (2*sizeof(opalias[0][0]));
@@ -790,7 +801,6 @@ char *operatorAlias(char *operatorName)
 static
 int operatorInqModID(char *operatorName)
 {
-  static const char *func = "operatorInqModID";
   int i, j, modID = -1;
 
   if ( operatorName )
@@ -825,7 +835,7 @@ int operatorInqModID(char *operatorName)
 	{
 	  fclose(fp);
 	  fprintf(stderr, "Use commandline option -h for help.");
-	  Error(func, "operator missing! %s is a file on disk!", operatorName);
+	  Error("operator missing! %s is a file on disk!", operatorName);
 	}
       fprintf(stderr, "Operator >%s< not found!\n", operatorName);
       fprintf(stderr, "Similar operators are:\n");
@@ -861,7 +871,7 @@ int operatorInqModID(char *operatorName)
 
   if ( modID != -1 )
     if ( ! Modules[modID].func )
-      Error(func, "Module for operator >%s< not installed!", operatorName);
+      Error("Module for operator >%s< not installed!", operatorName);
 
   return (modID);
 }
@@ -929,7 +939,7 @@ void operatorPrintAll(void)
   nbyte = fprintf(stderr, "   ");
   for ( i = 0; i < nop; i++ )
     {
-      if ( nbyte > 65 )
+      if ( nbyte > 75 )
 	{
 	  fprintf(stdout, "\n");
 	  nbyte = fprintf(stderr, "   ");
