@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2006 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -33,9 +33,9 @@
 
 static int PipeDebug = 0;
 
-static void pipe_init(PIPE *pipe)
+static
+void pipe_init(pipe_t *pipe)
 {
-  static const char *func = "pipe_init";
   pthread_mutexattr_t m_attr;
   pthread_condattr_t c_attr;
 
@@ -45,8 +45,8 @@ static void pipe_init(PIPE *pipe)
 #if defined (_POSIX_THREAD_PROCESS_SHARED)
   if ( PipeDebug )
     {
-      Message(func, "setpshared mutexattr to PTHREAD_PROCESS_SHARED");
-      Message(func, "setpshared condattr to PTHREAD_PROCESS_SHARED");
+      Message("setpshared mutexattr to PTHREAD_PROCESS_SHARED");
+      Message("setpshared condattr to PTHREAD_PROCESS_SHARED");
     }
 
   pthread_mutexattr_setpshared(&m_attr, PTHREAD_PROCESS_SHARED);
@@ -57,19 +57,19 @@ static void pipe_init(PIPE *pipe)
       int pshared;
       pthread_mutexattr_getpshared(&m_attr, &pshared);
       if ( pshared == PTHREAD_PROCESS_SHARED )
-	Message(func, "getpshared mutexattr is PTHREAD_PROCESS_SHARED");
+	Message("getpshared mutexattr is PTHREAD_PROCESS_SHARED");
       else if ( pshared == PTHREAD_PROCESS_PRIVATE )
-	Message(func, "getpshared mutexattr is PTHREAD_PROCESS_PRIVATE");
+	Message("getpshared mutexattr is PTHREAD_PROCESS_PRIVATE");
 
       pthread_condattr_getpshared(&c_attr, &pshared);
       if ( pshared == PTHREAD_PROCESS_SHARED )
-	Message(func, "getpshared condattr is PTHREAD_PROCESS_SHARED");
+	Message("getpshared condattr is PTHREAD_PROCESS_SHARED");
       else if ( pshared == PTHREAD_PROCESS_PRIVATE )
-	Message(func, "getpshared condattr is PTHREAD_PROCESS_PRIVATE");
+	Message("getpshared condattr is PTHREAD_PROCESS_PRIVATE");
     }
 #else
   if ( PipeDebug )
-    Message(func, "_POSIX_THREAD_PROCESS_SHARED undefined");
+    Message("_POSIX_THREAD_PROCESS_SHARED undefined");
 #endif
   */
   pipe->EOP     = 0;
@@ -115,12 +115,11 @@ static void pipe_init(PIPE *pipe)
 }
 
 
-PIPE *pipeNew()
+pipe_t *pipeNew()
 {
-  static const char *func = "pipeNew";  
-  PIPE *pipe;
+  pipe_t *pipe;
 
-  pipe = (PIPE *) malloc(sizeof(PIPE));
+  pipe = (pipe_t *) malloc(sizeof(pipe_t));
 
   pipe_init(pipe);
 
@@ -128,10 +127,8 @@ PIPE *pipeNew()
 }
 
 
-void pipeDelete(PIPE *pipe)
+void pipeDelete(pipe_t *pipe)
 {
-  static const char *func = "pipeDelete";  
-
   if ( pipe )
     {
       if ( pipe->mutex )     free(pipe->mutex);
@@ -148,14 +145,13 @@ void pipeDelete(PIPE *pipe)
 }
 
 
-void pipeDefVlist(PSTREAM *pstreamptr, int vlistID)
+void pipeDefVlist(pstream_t *pstreamptr, int vlistID)
 {
-  static const char *func = "pipeDefVlist";
   char *pname = pstreamptr->name;
-  PIPE *pipe;
+  pipe_t *pipe;
 
   if ( PipeDebug )
-    Message(func, "%s pstreamID %d", pname, pstreamptr->self);
+    Message("%s pstreamID %d", pname, pstreamptr->self);
 
   pipe = pstreamptr->pipe;
 
@@ -167,22 +163,21 @@ void pipeDefVlist(PSTREAM *pstreamptr, int vlistID)
 }
 
 
-int pipeInqVlist(PSTREAM *pstreamptr)
+int pipeInqVlist(pstream_t *pstreamptr)
 {
-  static const char *func = "pipeInqVlist";
   char *pname = pstreamptr->name;
-  PIPE *pipe;
+  pipe_t *pipe;
   int vlistID;
 
   if ( PipeDebug )
-    Message(func, "%s pstreamID %d", pname, pstreamptr->self);
+    Message("%s pstreamID %d", pname, pstreamptr->self);
 
   pipe = pstreamptr->pipe;
 
   pthread_mutex_lock(pipe->mutex);
   while ( pstreamptr->vlistID == -1 )
     {
-      if ( PipeDebug ) Message(func, "%s wait of vlist", pname);
+      if ( PipeDebug ) Message("%s wait of vlist", pname);
       pthread_cond_wait(pipe->vlistDef, pipe->mutex);
     }
   vlistID = pstreamptr->vlistID;
@@ -192,15 +187,14 @@ int pipeInqVlist(PSTREAM *pstreamptr)
 }
 
 
-int pipeInqTimestep(PSTREAM *pstreamptr, int tsID)
+int pipeInqTimestep(pstream_t *pstreamptr, int tsID)
 {
-  static const char *func = "pipeInqTimestep";
   char *pname = pstreamptr->name;
-  PIPE *pipe;
+  pipe_t *pipe;
   int nrecs;
 
   if ( PipeDebug )
-    Message(func, "%s pstreamID %d", pname, pstreamptr->self);
+    Message("%s pstreamID %d", pname, pstreamptr->self);
 
   pipe = pstreamptr->pipe;
 
@@ -210,7 +204,7 @@ int pipeInqTimestep(PSTREAM *pstreamptr, int tsID)
   if ( tsID != pipe->tsIDr+1 )
     {
       if ( ! (tsID == pipe->tsIDr && pipe->tsIDr == pipe->tsIDw && pipe->recIDr == -1) ) 
-	Error(func, "%s unexpected tsID %d %d %d", pname, tsID, pipe->tsIDr+1, pipe->tsIDw);
+	Error("%s unexpected tsID %d %d %d", pname, tsID, pipe->tsIDr+1, pipe->tsIDw);
     }
   
   pipe->tsIDr = tsID;
@@ -218,22 +212,22 @@ int pipeInqTimestep(PSTREAM *pstreamptr, int tsID)
     {
       if ( pipe->EOP == TRUE )
 	{
-	  if ( PipeDebug ) Message(func, "%s EOP", pname);
+	  if ( PipeDebug ) Message("%s EOP", pname);
 	  break;
 	}
       if ( pipe->hasdata )
 	{
-	  if ( PipeDebug ) Message(func, "%s has data", pname);
+	  if ( PipeDebug ) Message("%s has data", pname);
 	  pipe->hasdata = 0;
 	  pipe->data = NULL;
 	  pthread_cond_signal(pipe->readCond);
 	}
       else
-	if ( PipeDebug ) Message(func, "%s has no data", pname);
+	if ( PipeDebug ) Message("%s has no data", pname);
 
       pthread_cond_signal(pipe->recInq); /* o.k. ??? */
 
-      if ( PipeDebug ) Message(func, "%s wait of tsDef", pname);
+      if ( PipeDebug ) Message("%s wait of tsDef", pname);
       pthread_cond_wait(pipe->tsDef, pipe->mutex);
     }
 
@@ -250,15 +244,14 @@ int pipeInqTimestep(PSTREAM *pstreamptr, int tsID)
 }
 
 
-void pipeDefTimestep(PSTREAM *pstreamptr, int tsID)
+void pipeDefTimestep(pstream_t *pstreamptr, int tsID)
 {
-  static const char *func = "pipeDefTimestep";
   char *pname = pstreamptr->name;
   int nrecs;
-  PIPE *pipe;
+  pipe_t *pipe;
 
   if ( PipeDebug )
-    Message(func, "%s pstreamID %d", pname, pstreamptr->self);
+    Message("%s pstreamID %d", pname, pstreamptr->self);
 
   pipe = pstreamptr->pipe;
 
@@ -266,7 +259,7 @@ void pipeDefTimestep(PSTREAM *pstreamptr, int tsID)
   pipe->recIDw = -1;
   pipe->tsIDw++;
   if ( tsID != pipe->tsIDw )
-    Error(func, "unexpected tsID %d(%d) for %s", tsID, pipe->tsIDw, pname);
+    Error("unexpected tsID %d(%d) for %s", tsID, pipe->tsIDw, pname);
 
   if ( tsID == 0 )
     nrecs = vlistNrecs(pstreamptr->vlistID);
@@ -291,32 +284,31 @@ sleep(1);
     {
       if ( pipe->EOP == TRUE )
 	{
-	  if ( PipeDebug ) Message(func, "EOP");
+	  if ( PipeDebug ) Message("EOP");
 	  break;
 	}
-      if ( PipeDebug ) Message(func, "%s wait of tsInq", pname);
+      if ( PipeDebug ) Message("%s wait of tsInq", pname);
       pthread_cond_wait(pipe->tsInq, pipe->mutex);
     }
   pthread_mutex_unlock(pipe->mutex);
 }
 
 
-int pipeInqRecord(PSTREAM *pstreamptr, int *varID, int *levelID)
+int pipeInqRecord(pstream_t *pstreamptr, int *varID, int *levelID)
 {
-  static const char *func = "pipeInqRecord";
   char *pname = pstreamptr->name;
-  PIPE *pipe;
+  pipe_t *pipe;
   int condSignal = FALSE;
 
   if ( PipeDebug )
-    Message(func, "%s pstreamID %d", pname, pstreamptr->self);
+    Message("%s pstreamID %d", pname, pstreamptr->self);
  
   pipe = pstreamptr->pipe;
 
   pthread_mutex_lock(pipe->mutex);
 
   if ( PipeDebug )
-    Message(func, "%s has no data %d %d", pname, pipe->recIDr, pipe->recIDw);
+    Message("%s has no data %d %d", pname, pipe->recIDr, pipe->recIDw);
 
   if ( pipe->hasdata || pipe->usedata )
     {
@@ -336,16 +328,16 @@ int pipeInqRecord(PSTREAM *pstreamptr, int *varID, int *levelID)
   pipe->recIDr++;
   
   if ( PipeDebug )
-    Message(func, "%s recID %d %d", pname, pipe->recIDr, pipe->recIDw);  
+    Message("%s recID %d %d", pname, pipe->recIDr, pipe->recIDw);  
 
   while ( pipe->recIDw != pipe->recIDr )
     {
       if ( pipe->EOP == TRUE )
 	{
-	  if ( PipeDebug ) Message(func, "EOP");
+	  if ( PipeDebug ) Message("EOP");
 	  break;
 	}
-      if ( PipeDebug ) Message(func, "%s wait of recDef", pname);
+      if ( PipeDebug ) Message("%s wait of recDef", pname);
       pthread_cond_wait(pipe->recDef, pipe->mutex);
     }
 
@@ -368,22 +360,21 @@ int pipeInqRecord(PSTREAM *pstreamptr, int *varID, int *levelID)
 }
 
 
-void pipeDefRecord(PSTREAM *pstreamptr, int varID, int levelID)
+void pipeDefRecord(pstream_t *pstreamptr, int varID, int levelID)
 {
-  static const char *func = "pipeDefRecord";
   char *pname = pstreamptr->name;
-  PIPE *pipe;
+  pipe_t *pipe;
   int condSignal = FALSE;
 
   if ( PipeDebug )
-    Message(func, "%s pstreamID %d", pname, pstreamptr->self);
+    Message("%s pstreamID %d", pname, pstreamptr->self);
 
   pipe = pstreamptr->pipe;
 
   pthread_mutex_lock(pipe->mutex);
 
   if ( PipeDebug )
-    Message(func, "%s has data %d %d", pname, pipe->recIDr, pipe->recIDw);
+    Message("%s has data %d %d", pname, pipe->recIDr, pipe->recIDw);
 	  
   if ( pipe->hasdata )
     {
@@ -400,7 +391,7 @@ void pipeDefRecord(PSTREAM *pstreamptr, int varID, int levelID)
   pipe->recIDw++;
 
   if ( PipeDebug )
-    Message(func, "%s recID %d %d", pname, pipe->recIDr, pipe->recIDw);  
+    Message("%s recID %d %d", pname, pipe->recIDr, pipe->recIDw);  
 
   pipe->varID = varID;
   pipe->levelID = levelID;
@@ -412,24 +403,23 @@ void pipeDefRecord(PSTREAM *pstreamptr, int varID, int levelID)
     {
       if ( pipe->tsIDw != pipe->tsIDr ) break;
       if ( pipe->EOP == TRUE ) break;
-      if ( PipeDebug ) Message(func, "%s wait of recInq %d", pname, pipe->recIDr);
+      if ( PipeDebug ) Message("%s wait of recInq %d", pname, pipe->recIDr);
       pthread_cond_wait(pipe->recInq, pipe->mutex);
     }
   pthread_mutex_unlock(pipe->mutex);
 }
 
 
-void pipeCopyRecord(PSTREAM *pstreamptr_out, PSTREAM *pstreamptr_in)
+void pipeCopyRecord(pstream_t *pstreamptr_out, pstream_t *pstreamptr_in)
 {
-  static const char *func = "pipeCopyRecord";
   char *ipname = pstreamptr_in->name;
   char *opname = pstreamptr_out->name;
-  PIPE *pipe;
+  pipe_t *pipe;
 
   if ( PipeDebug )
-    Message(func, "%s pstreamIDin %d", ipname, pstreamptr_in->self);
+    Message("%s pstreamIDin %d", ipname, pstreamptr_in->self);
   if ( PipeDebug )
-    Message(func, "%s pstreamIDout %d", opname, pstreamptr_out->self);
+    Message("%s pstreamIDout %d", opname, pstreamptr_out->self);
 
   pipe = pstreamptr_out->pipe;
 
@@ -449,38 +439,37 @@ void pipeCopyRecord(PSTREAM *pstreamptr_out, PSTREAM *pstreamptr_in)
 
       if ( pipe->EOP == TRUE )
 	{
-	  if ( PipeDebug ) Message(func, "EOP");
+	  if ( PipeDebug ) Message("EOP");
 	  break;
 	}
-      if ( PipeDebug ) Message(func, "%s wait of read record", opname);
+      if ( PipeDebug ) Message("%s wait of read record", opname);
       pthread_cond_wait(pipe->readCond, pipe->mutex);
     }
   pthread_mutex_unlock(pipe->mutex);
 }
 
 
-void pipeReadRecord(PSTREAM *pstreamptr, double *data, int *nmiss)
+void pipeReadRecord(pstream_t *pstreamptr, double *data, int *nmiss)
 {
-  static const char *func = "pipeReadRecord";
   char *pname = pstreamptr->name;
-  PIPE *pipe;
+  pipe_t *pipe;
 
   *nmiss = 0;
   if ( PipeDebug )
-    Message(func, "%s pstreamID %d", pname, pstreamptr->self);
+    Message("%s pstreamID %d", pname, pstreamptr->self);
 
   pipe = pstreamptr->pipe;
 
   pthread_mutex_lock(pipe->mutex);
   while ( pipe->hasdata == 0 )
     {
-      if ( PipeDebug ) Message(func, "%s wait of writeCond", pname);
+      if ( PipeDebug ) Message("%s wait of writeCond", pname);
       pthread_cond_wait(pipe->writeCond, pipe->mutex);
     }
 
   if ( pipe->hasdata == 2 )
     {
-      PSTREAM *pstreamptr_in;
+      pstream_t *pstreamptr_in;
 
       pstreamptr_in = pipe->pstreamptr_in;
       /*
@@ -488,13 +477,13 @@ void pipeReadRecord(PSTREAM *pstreamptr, double *data, int *nmiss)
 	{
 	  pstreamptr_in = pstreamptr_in->pipe->pstreamptr_in;
 	  if ( pstreamptr_in->ispipe )
-	    Error(func, "istream is pipe");
+	    Error("istream is pipe");
 	}
       */
       pstreamptr = pstreamptr_in;
       while ( pstreamptr_in->ispipe )
 	{
-	  if ( PipeDebug ) fprintf(stderr, "%s: istream %d is pipe\n", func, pstreamptr_in->self);
+	  if ( PipeDebug ) fprintf(stderr, "%s: istream %d is pipe\n", __func__, pstreamptr_in->self);
 	  pstreamptr    = pstreamptr_in;
 	  pstreamptr_in = pstreamptr_in->pipe->pstreamptr_in;
 	  if ( pstreamptr_in == 0 ) break;
@@ -508,7 +497,7 @@ void pipeReadRecord(PSTREAM *pstreamptr, double *data, int *nmiss)
 	      int vlistID, datasize;
 
 	      if ( ! pstreamptr->pipe->data )
-		Error(func, "No data pointer for %s", pname);
+		Error("No data pointer for %s", pname);
 
 	      vlistID = pstreamptr->vlistID;
 	      datasize = gridInqSize(vlistInqVarGrid(vlistID, pstreamptr->pipe->varID));
@@ -517,11 +506,11 @@ void pipeReadRecord(PSTREAM *pstreamptr, double *data, int *nmiss)
 	      *nmiss = pstreamptr->pipe->nmiss;
 	    }
 	  else
-	    Error(func, "Internal problem! istream undefined");
+	    Error("Internal problem! istream undefined");
 	}
       else
 	{
-	  if ( PipeDebug ) fprintf(stderr, "%s: istream %d is file\n", func, pstreamptr_in->self);
+	  if ( PipeDebug ) fprintf(stderr, "%s: istream %d is file\n", __func__, pstreamptr_in->self);
 	  streamReadRecord(pstreamptr_in->fileID, data, nmiss);
 	}
     }
@@ -530,7 +519,7 @@ void pipeReadRecord(PSTREAM *pstreamptr, double *data, int *nmiss)
       int vlistID, datasize;
 
       if ( ! pipe->data )
-	Error(func, "No data pointer for %s", pname);
+	Error("No data pointer for %s", pname);
 
       vlistID = pstreamptr->vlistID;
       datasize = gridInqSize(vlistInqVarGrid(vlistID, pipe->varID));
@@ -541,10 +530,10 @@ void pipeReadRecord(PSTREAM *pstreamptr, double *data, int *nmiss)
     }
   else
     {
-      Error(func, "data type %d not implemented", pipe->hasdata);
+      Error("data type %d not implemented", pipe->hasdata);
     }
 
-  if ( PipeDebug ) Message(func, "%s read record %d", pname, pipe->recIDr);
+  if ( PipeDebug ) Message("%s read record %d", pname, pipe->recIDr);
  
 
   pipe->hasdata = 0;
@@ -555,14 +544,13 @@ void pipeReadRecord(PSTREAM *pstreamptr, double *data, int *nmiss)
 }
 
 
-void pipeWriteRecord(PSTREAM *pstreamptr, double *data, int nmiss)
+void pipeWriteRecord(pstream_t *pstreamptr, double *data, int nmiss)
 {
-  static const char *func = "pipeWriteRecord";
   char *pname = pstreamptr->name;
-  PIPE *pipe;
+  pipe_t *pipe;
 
   if ( PipeDebug )
-    Message(func, "%s pstreamID %d", pname, pstreamptr->self);
+    Message("%s pstreamID %d", pname, pstreamptr->self);
 
   pipe = pstreamptr->pipe;
   /*
@@ -575,7 +563,7 @@ void pipeWriteRecord(PSTREAM *pstreamptr, double *data, int nmiss)
   pthread_mutex_unlock(pipe->mutex);
   pthread_cond_signal(pipe->writeCond);
 
-  if ( PipeDebug ) Message(func, "%s write record %d", pname, pipe->recIDw);
+  if ( PipeDebug ) Message("%s write record %d", pname, pipe->recIDw);
 
   pthread_mutex_lock(pipe->mutex);
   while ( pipe->hasdata )
@@ -589,10 +577,10 @@ void pipeWriteRecord(PSTREAM *pstreamptr, double *data, int nmiss)
 
       if ( pipe->EOP == TRUE )
 	{
-	  if ( PipeDebug ) Message(func, "EOP");
+	  if ( PipeDebug ) Message("EOP");
 	  break;
 	}
-      if ( PipeDebug ) Message(func, "%s wait of readCond", pname);
+      if ( PipeDebug ) Message("%s wait of readCond", pname);
       pthread_cond_wait(pipe->readCond, pipe->mutex);
     }
   pthread_mutex_unlock(pipe->mutex);
