@@ -14,20 +14,23 @@
 #define PI_QU 1*atan(1)
 #define PI_HA 2*atan(1)
 #define PI    4*atan(1)
-#define FNORM_PRECISION 1e-12
+#define FNORM_PRECISION 1e-05
+#define MAX_JACOBI_ITER 5
 
 int jacobi_1side(double **M, double *A, int n);
 void annihilate_1side(double **M, int i, int j, int k, int n);
 
 int n_finished;
 
+// global variables to handle environment settings 
+double fnorm_precision;
+int max_jacobi_iter;
+
 /* **************************************** */
 /* ENDOF HEADER FOR PARALLEL EIGEN SOLUTION */
 /*  -->SEE END OF ROUTINE                   */
 /* **************************************** */
 
-
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <float.h>
@@ -65,7 +68,6 @@ void eigen_solution_of_symmetric_matrix (double **a, double *eig_val,
 					 int n, int n_eig, const char *prompt)
 /* After return the rows (!!!) of a are the eigenvectors */
 {
-  static const char *func = "eigen_solution_of_symmetric_matrix";
   double *e;
   int i, j;
   double temp;
@@ -269,14 +271,14 @@ double pythagoras (double a, double b)
     return M_SQRT2 * abs_a;
 }
 
-#define MAX_ITER 10000
+#define MAX_ITER 1000
 
 void eigen_solution_of_triangular_matrix (double *d, double *e, int n,
 					  double **a, int n_eig, const char *prompt)
 {
   int i, k, l, m, iter;
   double b, c, f, g, p, r, s;
-  static const double eps = 1e-20;
+  static const double eps = 1e-6;
   
   for (i = 1; i < n; i++)
     e[i - 1] = e[i];
@@ -359,7 +361,6 @@ void eigen_solution_of_triangular_matrix (double *d, double *e, int n,
 
 int solution_of_linear_equation (double **a, double *b, int n)
 {
-  static const char *func = "solution_of_linear_equation";
   int *index;
   int sign;
   int not_singular;
@@ -379,7 +380,6 @@ int solution_of_linear_equation (double **a, double *b, int n)
 
 int inverse_of_matrix (double **a, double **b, int n)
 {
-  static const char *func = "inverse_of_matrix";
   int *index;
   int sign;
   int i, j;
@@ -412,7 +412,6 @@ int inverse_of_matrix (double **a, double **b, int n)
 
 int lu_decomposition (double **a, int n, int *index, int *sign)
 {
-  static const char *func = "decomposition";
   int i, imax = 0, j, k;
   double big, sum, temp;
   double *v;
@@ -567,7 +566,6 @@ void fft (double *real, double *imag, int n, int sign)
 
 void ft (double *real, double *imag, int n, int sign)
 {				/* sign should be 1 (FT) or -1 (reverse FT) */
-  static const char *func = "ft";
   int j, k;
   static double *work_r = 0, *work_i = 0;
   double sum_r, sum_i, norm;
@@ -1251,6 +1249,29 @@ double fisher(double m, double n, double x, const char *prompt)
 
 void parallel_eigen_solution_of_symmetric_matrix(double **M, double *A, int n1, int n2, const char func[])
 {
+  func = "statistics-module";
+
+  char *envstr;
+  /* Get Environment variables if set */
+  envstr = getenv("MAX_JACOBI_ITER");
+  if ( envstr ) 
+    max_jacobi_iter = atoi(envstr);
+  else
+    max_jacobi_iter = MAX_JACOBI_ITER;
+  if ( cdoVerbose )
+    cdoPrint("Using MAX_JACOBI_ITER %i from %s",
+	     max_jacobi_iter, envstr?"Environment":"default");
+
+   
+  envstr = getenv("FNORM_PRECISION");
+  if ( envstr ) 
+    fnorm_precision = strtod(envstr,NULL);
+  else
+    fnorm_precision = FNORM_PRECISION;
+
+  if ( cdoVerbose ) 
+    cdoPrint("Using FNORM_PRECISION %g from %s",
+	     fnorm_precision,envstr?"Environment":"default");
 
   if ( n1 != n2 )
     {
@@ -1279,8 +1300,7 @@ void annihilate_1side(double **M, int i, int j, int k, int n)
 
   double tk, ck, sk, alpha=0, beta=0, gamma=0, zeta=0;
   double tmp, *mi=NULL, *mj=NULL;
-  const char func[] = "annihilate_1side";
-  int first_annihilation = 0;
+  //  int first_annihilation = 0;
   int r;
 
   i--; j--;
@@ -1303,7 +1323,7 @@ void annihilate_1side(double **M, int i, int j, int k, int n)
 
   tmp = fabs(gamma/sqrt(alpha/beta));
 
-  if ( tmp < FNORM_PRECISION ) {
+  if ( tmp < fnorm_precision ) {
 #if defined (_OPENMP)
     #pragma omp critical 
 #endif
@@ -1338,10 +1358,9 @@ void annihilate_1side(double **M, int i, int j, int k, int n)
   return;
 }
 
+
 int jacobi_1side(double **M, double *A, int n)
-{
-  const char func[] = "jacobi_1side";
-  
+{  
   int i,j,k,m,r,i_ann,j_ann;
   int n_iter = 0;
   int idx;
@@ -1388,7 +1407,7 @@ int jacobi_1side(double **M, double *A, int n)
   //  override global openmp settings works
   //  omp_set_num_threads(2);
 
-  while ( n_iter < MAX_ITER && n_finished < count ) {
+  while ( n_iter < max_jacobi_iter && n_finished < count ) {
     n_finished = 0;
     if ( n%2 == 1 ) {
       for(m=0;m<n;m++) {
@@ -1422,18 +1441,28 @@ int jacobi_1side(double **M, double *A, int n)
     n_iter++;
   }
 
+  if ( cdoVerbose ) 
+    cdoPrint("Finished one-sided jacobi scheme for eigenvalue computation after %i iterations",n_iter);
+
   //  fprintf(stderr,"finished after %i sweeps (n_finished %i)\n",n_iter,n_finished);
 
-  if ( n_iter == MAX_ITER )
+  if ( n_iter == max_jacobi_iter && n_finished < count)
     {
       fprintf(stderr, 
-	      "WARNING: Eigenvalue computation with one-sided jacobi scheme\n"
-	      "         Did not converge properly. %i pairs of columns did\n"
-	      "         not achieve requested orthogonality of %10.6g\n",
-	      count-n_finished, FNORM_PRECISION);
-      for ( i=0; i<n; i++ )
-	memset(M[i],0,n*sizeof(double));
-      memset(A,0,n*sizeof(double));
+	      "statistics-module (Warning): Eigenvalue computation with one-sided jacobi scheme\n"
+	      "                             Did not converge properly. %i of %i pairs of columns did\n"
+	      "                             not achieve requested orthogonality of %10.6g\n",
+	      count-n_finished,count, fnorm_precision);
+
+      if ( n_finished == 0 ) {
+	//	Do not overwrite results in case of insufficient convergence
+	cdoWarning("Setting Matrix and Eigenvalues to 0 before return");
+	for ( i=0; i<n; i++ ) {
+	  memset(M[i],0,n*sizeof(double));
+	  memset(A,0,n*sizeof(double));
+	}
+	return -1;
+      }
     }
   // calculate  eigen values as sqrt(||m_i||)
   for ( i=0; i<n; i++ )
@@ -1447,10 +1476,10 @@ int jacobi_1side(double **M, double *A, int n)
     }
 
   heap_sort(A,M,n);
-
+  
   free(annihilations);
   free(annihilations_buff);
-   
+  
   return n_iter;
 }
 
