@@ -43,7 +43,6 @@ char *getProgname(char *string)
 
 char *getOperator(const char *argument)
 {
-  static const char *func = "getOperator";
   char *operatorArg = NULL;
   char *blankpos;
   size_t len;
@@ -70,7 +69,6 @@ char *operatorAlias(char *operatorName);
 
 char *getOperatorName(const char *operatorArg)
 {
-  static const char *func = "getOperatorName";
   char *commapos;
   char *operatorName = NULL;
   size_t len;
@@ -99,7 +97,6 @@ char *getOperatorName(const char *operatorArg)
 
 char *makeArgument(int argc, char *argv[])
 {
-  static const char *func = "makeArgument";
   char *argument = NULL;
   int iarg;
   size_t len, pos = 0, off = 0;
@@ -124,7 +121,6 @@ char *makeArgument(int argc, char *argv[])
 
 char *getFileArg(char *argument)
 {
-  static const char *func = "getFileArg";
   char *fileArg = NULL;
   char *parg;
   char *blankpos;
@@ -245,3 +241,56 @@ int userFileOverwrite(const char *filename)
 
   return (status);
 }
+
+int stdin_is_tty  = 0;
+int stdout_is_tty = 0;
+
+void init_is_tty(void)
+{
+  struct stat statbuf;
+  fstat(0, &statbuf);
+  if ( S_ISCHR(statbuf.st_mode) ) stdin_is_tty = 1;  
+  fstat(1, &statbuf);
+  if ( S_ISCHR(statbuf.st_mode) ) stdout_is_tty = 1;  
+}
+
+
+void progressStatus(double offset, double refval, double curval)
+{
+  static int lhead = FALSE;
+  static int nch = 0;;
+  static int cval = -1;
+  int ival;
+
+  if ( !stdout_is_tty ) return;
+
+  offset = offset < 0 ? 0: offset;
+  offset = offset > 1 ? 1: offset;
+  refval = refval < 0 ? 0: refval;
+  refval = refval > 1 ? 1: refval;
+  curval = curval < 0 ? 0: curval;
+  curval = curval > 1 ? 1: curval;
+
+  ival = (offset + refval*curval)*100;
+
+  if ( cval == -1 )
+    {
+      nch = fprintf(stdout, "%s: %3d%%", processInqPrompt(), 0);
+      fflush(stdout);
+      lhead = TRUE;
+    }
+
+  if ( ival != cval )
+    {
+      cval = ival;
+      fprintf(stdout, "\b\b\b\b%3d%%", cval);
+      fflush(stdout);
+    }
+
+  if ( cval == 100 && lhead )
+    {
+      lhead = FALSE;
+      while ( nch-- ) fprintf(stdout, "\b");
+      fflush(stdout);
+    }
+}
