@@ -29,6 +29,8 @@ enum {START_DEC, START_JAN};
 int get_season_start(void);
 void get_season_name(const char *seas_name[4]);
 
+void init_is_tty(void);
+void progressStatus(double offset, double refval, double curval);
 
 int fileExist(const char *filename);
 int userFileOverwrite(const char *filename);
